/////////////////////////////////////////////////////////////
//                                                         //
//            SIEMENS C65 COLOR LCD driver v1.0            //
//                  (S6B33B2 controller)                   //
//               by Oroszfji Szabolcs 2008                //
//                                                         //
//            ..: LCDHype by ViRuSTriNiTy :..              //
//                                                         //
/////////////////////////////////////////////////////////////

unit Controller_C65;

interface
uses
  SysUtils, Windows, inifiles;

const ID = 'SIEMENS C65 COLOR LCD driver v1.0  (S6B33B2)'; //ID sets the description of the dll
      MAX_RESPIXELS = 130*130;

Type TArrayType = array[0..MAX_RESPIXELS-1] of byte;

type TCharData = record
                  position : byte;
                  data : array[0..7,0..7] of byte;
                 End;
     TDLLInfo = record
                 IDArray : array[0..255] of byte; //holds identifier of DLL
                 SupportGfxLCD : Boolean;         //does this driver support graphical LCDs?
                 SupportTxtLCD : Boolean;         //does this driver support text
                 SupportLightSlider : Boolean;    //does this driver support the light control slider
                 SupportContrastSlider : Boolean; //does this driver support the contrast slider
                 SupportOutports : Boolean;       //does this driver support outports for controlling external circuits
                 CCharWidth : Byte;               //custom char width in pixels
                 CCharHeight : Byte;              //custom char height in pixels
                 FontPitch : Byte;                //fontpitch of LCD in pixels
                End;
     TSymbolInfo = record
                    SymbolData : array[0..19] of boolean;
                   End;

var
  Light : INTEGER;
  Once : boolean = true; // for BootLogo
  LCD_Width : integer = 130;
  LCD_Height : integer = 130;
  LCD_Port : integer = $378;
  LCD_ExectimeGfx : integer = 0;
  ContrastValue : byte;
  Contrast_ON : boolean;

Procedure BootLogo;stdcall; forward
//Sends Data to the Controller Chip
procedure LCD_SendToController(Value : Byte); stdcall;

//Sends Data to the integrated LCD Memory
//on adress specified by LCD_SetOutputAdress
procedure LCD_SendToMemory(Value : Byte); stdcall;

//Sends Data to LCD Gfx Memory
procedure LCD_SendToGfxMemory(Pixels : TArrayType; X1,Y1,X2,Y2 : Word; inverted : boolean); stdcall;

//Sets the LCD RAM Adress for Outputs
procedure LCD_SetOutputAddress(x,y : Cardinal); stdcall;

//Sets a LCD Custom Char specified in cdata
procedure LCD_SetCGRAMChar(cdata : TCharData); stdcall;

//Returns the Custom Char bytecode for the current display
//Based on the HD44780 eg. the input for the first Custom Char
//is position=0 and the return value is the equivalent bytecode
//to the HD44780 Custom Char bytecode
function LCD_GetCGRAMChar(position : Byte) : Byte; stdcall;

//Initialize the LCD
procedure LCD_Init; stdcall;

//Called when DLL released
procedure LCD_CleanUp; stdcall;

//Sets the Port Adress where the LCD are connected and
//the lcd execution time for processing sended data

procedure LCD_SetIOPropertys(Port : pchar;
                             Exectime : Cardinal;
                             ExectimeGfx : Cardinal;
                             X : Cardinal;
                             Y : Cardinal;
                             gX : Cardinal;
                             gY : Cardinal;
                             LightOn : Boolean;
                             LightSliderValue : Byte;
                             ContrastOn : Boolean;
                             ContrastSliderValue : Byte;
                             Outports : Cardinal;
                             UnderlineMode : Boolean;
                             UnderlineOutput : Boolean); stdcall;

//This is a routine for customizing output,
//by default only used by m50530 symbol lcd
procedure LCD_Customize(SymData : TSymbolInfo); stdcall;

//Caller of this function gets some info about the DLL
function DLL_GetInfo : TDLLInfo; stdcall;

function LCD_HasColorDisplay : boolean; stdcall;

//Signals if the write sequence to LCD is ended or not
function LCD_IsReadyToReceive : boolean; stdcall;


implementation

//Imported DLL Routine from DriverLinx PortIO DLL Driver
function DlPortReadPortUchar(Port:longint):byte;stdcall;external 'DLPORTIO.DLL';
procedure DlPortWritePortUchar(Port:longint;Value:byte);stdcall;external 'DLPORTIO.DLL';

{-------------------------------------------------------}

Procedure Wait(x : Integer);

var c : Integer;
Begin
     for c:=0 to x do  ;
      DlPortReadPortUchar($220); //read = 1 microsecond delay
End;

{-------------------------------------------------------}

Procedure Command (Value: Byte; LCD_ExectimeGfx : Cardinal);

Var i : Byte;
    j : integer;
Begin
DlPortWritePortUchar(LCD_Port,26+Light);

For i := 7 downto 0 do
if (Value AND (1 shl i))>0 then
  Begin
    DlPortWritePortUchar(LCD_Port+2,2);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
    DlPortWritePortUchar(LCD_Port+2,0);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
  End
else
  Begin
    DlPortWritePortUchar(LCD_Port+2,3);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
    DlPortWritePortUchar(LCD_Port+2,1);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
  End;

End;

{-------------------------------------------------------}

Procedure Command16 (Value: Word; LCD_ExectimeGfx : Cardinal);

Var i : Byte;
    j : integer;
Begin
DlPortWritePortUchar(LCD_Port,26+Light);

For i := 7 downto 0 do
if ((Value SHR 8)  AND (1 shl i))>0 then
  Begin
    DlPortWritePortUchar(LCD_Port+2,2);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
    DlPortWritePortUchar(LCD_Port+2,0);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
  End
else
  Begin
    DlPortWritePortUchar(LCD_Port+2,3);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
    DlPortWritePortUchar(LCD_Port+2,1);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
  End;

For i := 7 downto 0 do
if (Value AND (1 shl i))>0 then
  Begin
    DlPortWritePortUchar(LCD_Port+2,2);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
    DlPortWritePortUchar(LCD_Port+2,0);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
  End
else
  Begin
    DlPortWritePortUchar(LCD_Port+2,3);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
    DlPortWritePortUchar(LCD_Port+2,1);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
  End;

End;

{-------------------------------------------------------}

Procedure Raw (Value: Byte; LCD_ExectimeGfx : Cardinal);

Var i : Byte;
    j : integer;
Begin

For i := 7 downto 0 do
if (Value AND (1 shl i))>0 then
  Begin
    DlPortWritePortUchar(LCD_Port+2,2);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
    DlPortWritePortUchar(LCD_Port+2,0);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
  End
else
  Begin
    DlPortWritePortUchar(LCD_Port+2,3);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
    DlPortWritePortUchar(LCD_Port+2,1);
      for j := 1 to LCD_ExectimeGfx do  DLPortReadPortUChar($220);
  End;

End;

{-------------------------------------------------------}

Procedure LCD_SetIOPropertys(Port : pchar;
                             Exectime : Cardinal;
                             ExectimeGfx : Cardinal;
                             X : Cardinal;
                             Y : Cardinal;
                             gX : Cardinal;
                             gY : Cardinal;
                             LightOn : Boolean;
                             LightSliderValue : Byte;
                             ContrastOn : Boolean;
                             ContrastSliderValue : Byte;
                             Outports : Cardinal;
                             UnderlineMode : Boolean;
                             UnderlineOutput : Boolean);
Begin
LCD_Port:=StrToInt('$'+Port);
LCD_ExectimeGfx := ExectimeGfx;
//LCD_Exectime := Exectime;
if LightOn then Light:=4
           else Light:=0;

if (gX>0)AND(gX<=130) then LCD_Width:=gX else LCD_Width:=130;
if (gY>0)AND(gY<=130) then LCD_Height:=gY else LCD_Height:=130;

if Contrast_ON then Command16($2A00 + 128 + ContrastValue div 2, LCD_ExectimeGfx) // Contrast
               else Command16($2A00, LCD_ExectimeGfx); // Set contrast OFF

ContrastValue:=ContrastSliderValue;
Contrast_ON:=ContrastOn;
End;

{-------------------------------------------------------}

Function DLL_GetInfo : TDLLInfo;

var c : integer; x : TDLLInfo;
Begin
     for c:=0 to 255 do x.IDArray[c] := 0;
     for c:=1 to length(ID) do
      Begin
       x.IDArray[c-1] := ord(ID[c]);
      End;

     x.SupportGfxLCD := true;
     x.SupportTxtLCD := false;
     x.SupportLightSlider := false;
     x.SupportContrastSlider := true;
     x.SupportOutports := false;
     x.CCharWidth := 6;
     x.CCharHeight := 8;
     x.FontPitch := 6;

     result := x;
End;

{---------------------------------------------------------}

Function LCD_IsReadyToReceive : boolean;
Begin
result:=true;
End;

{---------------------------------------------------------}

Function LCD_HasColorDisplay : boolean;
begin
result:=true;
end;

{---------------------------------------------------------}

Procedure LCD_SendToController(Value : Byte);
Begin
End;

{---------------------------------------------------------}

Procedure LCD_SEndToGfxMemory(Pixels : TArrayType; X1,Y1,X2,Y2 : Word; inverted : boolean);

Var
i,j: word;

Begin

if inverted then Command16($5301, LCD_ExectimeGfx)  // Inverse
            else Command16($5300, LCD_ExectimeGfx); // Normal

DlPortWritePortUchar(LCD_Port,26+Light); 
Raw ($43, LCD_ExectimeGfx); // X
Raw (2+X1, LCD_ExectimeGfx);
Raw (2+X2, LCD_ExectimeGfx);

Raw ($42, LCD_ExectimeGfx); // Y
Raw (2+Y1, LCD_ExectimeGfx);
Raw (2+Y2, LCD_ExectimeGfx);

DlPortWritePortUchar(LCD_Port,27+Light); // write data
for j := Y1 to Y2 do
 Begin
   for i := X1 to X2 do
    Raw (Pixels[j*LCD_Width+i], LCD_ExectimeGfx);
 End;
End;

{---------------------------------------------------------}

Procedure LCD_SendToMemory(Value : Byte);
Begin
End;

{---------------------------------------------------------}

procedure LCD_SetOutputAddress(x,y : Cardinal);
Begin
End;

{---------------------------------------------------------}

Procedure LCD_SetCGRAMChar(cdata : TCharData);
Begin
End;

{---------------------------------------------------------}

Function LCD_GetCGRAMChar(position : Byte) : Byte;
Begin result := position;
End;

{---------------------------------------------------------}

Procedure LCD_Init;stdcall;

var xx : integer;
Begin

DlPortWritePortUchar(LCD_Port,24); // Reset Low
Sleep(1);
DlPortWritePortUchar(LCD_Port,26); // Reset High
Sleep(1);

{------------------------INIT------------------------------}

Command($2C, LCD_ExectimeGfx);     // Standby Mode OFF
Command16($0201, LCD_ExectimeGfx); // Oscillation Mode Set
Command16($260F, LCD_ExectimeGfx); // DCDC and AMP ON/OFF set
Command16($1030, LCD_ExectimeGfx); // Driver Output Mode Set
Command16($2001, LCD_ExectimeGfx); // DC-DC Select
Command16($2201, LCD_ExectimeGfx); // Bias Set
Command16($2401, LCD_ExectimeGfx); // DCDC Clock Division Set
Command16($2800, LCD_ExectimeGfx); // Temperature Compensation Set
Command16($3040, LCD_ExectimeGfx); // Addressing Mode Set
Command16($3201, LCD_ExectimeGfx); // ROW Vector Mode Set
Command16($3482, LCD_ExectimeGfx); // N-line Inversion Set
Command16($4000, LCD_ExectimeGfx); // Entry Mode Set


if Contrast_ON then Command16($2A00 + 128 + ContrastValue div 2, LCD_ExectimeGfx) // Contrast
               else Command16($2A00, LCD_ExectimeGfx); // Set contrast OFF

{-----------------------Init END-----------------------------}

if Once then
Begin
 BootLogo;
 Once:=false;

 DlPortWritePortUchar(LCD_Port,26+Light);
 Raw ($43, LCD_ExectimeGfx); // X
 Raw (2, LCD_ExectimeGfx);
 Raw (131, LCD_ExectimeGfx);

 Raw ($42, LCD_ExectimeGfx); // Y
 Raw (2, LCD_ExectimeGfx);
 Raw (131, LCD_ExectimeGfx);

{-------------CLRSCR---------------}

 DlPortWritePortUchar(LCD_Port,27+Light); // write data
 for xx := 1 to 130*130*2 do Raw (0, LCD_ExectimeGfx);
End;

Command($51, LCD_ExectimeGfx); // Display ON
End;

{------------------------------------------------------------}

Procedure LCD_CleanUp;

Begin
Command ($50, LCD_ExectimeGfx);    // Display OFF
Command ($2D, LCD_ExectimeGfx);    // Standby Mode ON
Command16($2600, LCD_ExectimeGfx); // DCDC and AMP ON/OFF set
Command16($0200, LCD_ExectimeGfx); // Oscillation Mode Set
Sleep(400);

DlPortWritePortUchar(LCD_Port+2,3);
DlPortWritePortUchar(LCD_Port,Light);
End;

{-------------------------------------------------------}

Procedure BootLogo;

Const LogoData : array [1..132*130*2] of byte =(
    $FF, $FF, $00, $10, $00, $10, $00, $08, $00, $08, $00, $08, $00, $08, $00, $08,
    $00, $08, $00, $10, $00, $10, $00, $10, $00, $10, $00, $10, $00, $18, $00, $20,
    $21, $28, $62, $38, $C4, $48, $66, $61, $C8, $71, $49, $7A, $69, $82, $AA, $8A,
    $EA, $8A, $EB, $92, $0A, $93, $0B, $93, $2B, $9B, $2C, $9B, $4C, $9B, $4D, $9B,
    $6D, $9B, $6D, $9B, $8E, $9B, $6E, $9B, $8E, $93, $8F, $9B, $8F, $93, $90, $93,
    $91, $93, $91, $93, $B2, $8B, $D2, $8B, $D2, $8B, $F2, $8B, $D3, $8B, $D2, $83,
    $D3, $83, $92, $7B, $72, $7B, $51, $73, $51, $6B, $51, $6B, $71, $6B, $92, $73,
    $92, $73, $B3, $7B, $D3, $73, $D3, $73, $F5, $7B, $14, $7C, $F4, $7B, $15, $7C,
    $15, $7C, $14, $7C, $15, $7C, $15, $7C, $35, $7C, $35, $7C, $35, $7C, $15, $7C,
    $14, $74, $F3, $6B, $B2, $6B, $92, $6B, $92, $63, $B2, $6B, $F4, $6B, $35, $74,
    $35, $74, $55, $74, $14, $74, $D2, $63, $91, $63, $70, $63, $50, $5B, $50, $5B,
    $91, $5B, $B1, $63, $D2, $63, $34, $6C, $34, $6C, $55, $6C, $95, $74, $D6, $74,
    $D6, $7C, $F7, $84, $F7, $84, $17, $85, $17, $7D, $F7, $7C, $17, $7D, $17, $7D,
    $17, $7D, $17, $7D, $17, $7D, $F7, $7C, $F7, $7C, $17, $7D, $17, $7D, $16, $7D,
    $16, $7D, $36, $75, $36, $7D, $36, $7D, $F5, $74, $D4, $6C, $73, $64, $52, $64,
    $12, $5C, $11, $5C, $32, $64, $73, $64, $B3, $6C, $F4, $6C, $F5, $6C, $15, $6D,
    $15, $6D, $14, $6D, $35, $6D, $FF, $FF, $FF, $FF, $00, $10, $00, $10, $00, $08,
    $00, $08, $00, $08, $00, $08, $00, $08, $00, $08, $00, $10, $00, $10, $00, $10,
    $00, $10, $00, $10, $00, $18, $00, $20, $00, $20, $00, $28, $01, $30, $01, $38,
    $83, $48, $05, $59, $86, $61, $07, $72, $68, $7A, $A9, $82, $C9, $8A, $CA, $92,
    $EA, $92, $0B, $93, $0B, $93, $2C, $93, $4C, $93, $4D, $9B, $4D, $93, $6D, $93,
    $6E, $93, $8F, $93, $8F, $93, $90, $93, $91, $93, $91, $93, $B2, $8B, $D2, $8B,
    $D2, $8B, $B2, $8B, $D1, $8B, $92, $83, $71, $73, $50, $73, $30, $6B, $EF, $6A,
    $0F, $63, $0F, $6B, $30, $6B, $51, $73, $72, $6B, $72, $73, $B3, $73, $B3, $73,
    $D4, $7B, $F4, $73, $D4, $73, $F4, $7B, $F4, $7B, $F4, $73, $F4, $7B, $F4, $7B,
    $F4, $7B, $F4, $7B, $14, $7C, $14, $74, $B3, $6B, $89, $94, $51, $63, $71, $5B,
    $51, $5B, $92, $63, $D3, $6B, $34, $6C, $14, $6C, $F3, $6B, $D3, $6B, $70, $63,
    $30, $5B, $0E, $53, $EE, $52, $0F, $53, $50, $5B, $91, $5B, $B2, $5B, $13, $64,
    $33, $6C, $54, $74, $95, $74, $95, $74, $D6, $7C, $D6, $7C, $D6, $7C, $D6, $7C,
    $F6, $7C, $D6, $7C, $D6, $74, $F6, $74, $F6, $74, $F6, $74, $F6, $74, $D6, $74,
    $D6, $7C, $F6, $7C, $F6, $7C, $F6, $74, $F6, $74, $16, $75, $16, $75, $16, $75,
    $B5, $6C, $93, $64, $32, $64, $12, $5C, $F0, $5B, $F1, $53, $11, $5C, $72, $5C,
    $B4, $6C, $F4, $6C, $F5, $6C, $14, $6D, $14, $6D, $F4, $6C, $15, $6D, $FF, $FF,
    $FF, $FF, $00, $18, $00, $18, $20, $00, $20, $00, $00, $08, $00, $08, $00, $10,
    $00, $10, $00, $10, $00, $10, $00, $10, $00, $10, $00, $10, $20, $10, $20, $10,
    $20, $10, $00, $10, $00, $18, $01, $20, $02, $20, $23, $20, $65, $28, $E8, $38,
    $4A, $51, $AB, $61, $0C, $72, $6C, $82, $8C, $82, $AC, $8A, $CD, $8A, $EE, $8A,
    $EF, $92, $F0, $92, $F0, $92, $51, $8B, $51, $8B, $51, $8B, $71, $8B, $72, $8B,
    $92, $8B, $92, $8B, $92, $83, $92, $83, $92, $83, $71, $83, $51, $7B, $31, $73,
    $10, $73, $EF, $6A, $AA, $83, $28, $94, $09, $8C, $A5, $AC, $31, $6B, $51, $6B,
    $72, $6B, $72, $73, $93, $6B, $B4, $6B, $B4, $73, $B5, $73, $D5, $73, $F5, $73,
    $F5, $73, $D5, $73, $D5, $73, $F6, $73, $F6, $73, $16, $74, $16, $7C, $D5, $73,
    $88, $9C, $03, $B5, $11, $53, $11, $53, $32, $53, $53, $5B, $B4, $63, $15, $6C,
    $F4, $6B, $4C, $8C, $22, $BD, $8C, $6B, $AE, $42, $8D, $42, $4A, $63, $27, $8C,
    $09, $84, $C5, $A4, $72, $53, $B3, $5B, $D3, $5B, $F4, $63, $36, $64, $56, $64,
    $76, $6C, $76, $74, $97, $6C, $97, $6C, $97, $6C, $97, $6C, $97, $6C, $97, $6C,
    $97, $6C, $97, $6C, $B7, $6C, $B7, $6C, $B7, $6C, $B7, $6C, $B7, $6C, $B7, $6C,
    $B7, $6C, $B7, $6C, $D7, $74, $B6, $74, $55, $64, $C9, $9C, $42, $BD, $B0, $5B,
    $91, $53, $B1, $53, $F2, $5B, $33, $5C, $54, $64, $95, $6C, $B6, $6C, $B6, $6C,
    $B6, $6C, $B6, $6C, $D6, $6C, $FF, $FF, $FF, $FF, $01, $18, $01, $18, $41, $00,
    $20, $00, $00, $08, $00, $08, $00, $10, $00, $10, $00, $10, $00, $10, $00, $10,
    $00, $10, $00, $10, $00, $10, $00, $10, $20, $10, $21, $18, $21, $18, $01, $20,
    $01, $18, $02, $18, $03, $18, $04, $20, $25, $28, $A7, $40, $E8, $48, $89, $61,
    $E9, $69, $4A, $7A, $8B, $7A, $8C, $7A, $AD, $82, $CF, $8A, $EF, $8A, $2F, $83,
    $2F, $7B, $30, $83, $50, $83, $50, $83, $50, $7B, $30, $7B, $50, $7B, $50, $73,
    $70, $73, $31, $73, $30, $6B, $F0, $6A, $C9, $8B, $03, $B5, $A9, $83, $8E, $5A,
    $AA, $83, $28, $94, $10, $6B, $32, $6B, $72, $6B, $52, $73, $93, $6B, $73, $6B,
    $93, $6B, $94, $6B, $B4, $6B, $B4, $6B, $B4, $6B, $B4, $6B, $B4, $6B, $B4, $6B,
    $D4, $73, $F5, $7B, $14, $7C, $2E, $84, $41, $C5, $09, $84, $F0, $52, $F1, $52,
    $11, $53, $73, $63, $D4, $6B, $15, $74, $8B, $94, $0B, $84, $41, $C5, $4B, $6B,
    $0B, $5B, $C4, $AC, $E7, $83, $AE, $42, $4D, $63, $A6, $9C, $72, $53, $73, $5B,
    $B3, $5B, $D4, $63, $D4, $63, $15, $64, $15, $64, $15, $64, $15, $5C, $36, $5C,
    $36, $5C, $56, $64, $56, $64, $55, $64, $55, $64, $55, $64, $55, $64, $56, $64,
    $56, $64, $76, $64, $76, $64, $55, $64, $56, $64, $76, $6C, $97, $74, $75, $6C,
    $AB, $8C, $42, $BD, $E4, $AC, $50, $4B, $50, $4B, $71, $4B, $B2, $53, $F2, $5B,
    $13, $5C, $34, $5C, $54, $64, $54, $64, $75, $64, $75, $64, $96, $64, $FF, $FF,
    $FF, $FF, $00, $08, $00, $08, $00, $18, $00, $18, $00, $10, $00, $10, $00, $10,
    $00, $10, $00, $10, $00, $10, $00, $10, $00, $10, $00, $18, $00, $18, $00, $18,
    $00, $20, $00, $20, $00, $20, $03, $10, $04, $10, $04, $18, $04, $18, $04, $10,
    $04, $10, $25, $10, $66, $18, $87, $28, $C9, $40, $0A, $61, $6C, $61, $AC, $69,
    $EC, $69, $8C, $62, $AD, $62, $CF, $6A, $CF, $6A, $EF, $72, $F0, $6A, $F0, $72,
    $10, $6B, $10, $6B, $10, $6B, $30, $73, $30, $6B, $10, $6B, $EE, $62, $A5, $A4,
    $03, $B5, $CC, $62, $6D, $52, $6A, $7B, $28, $94, $D0, $62, $11, $6B, $31, $6B,
    $52, $63, $53, $6B, $73, $6B, $53, $6B, $53, $6B, $73, $6B, $93, $6B, $75, $6B,
    $75, $6B, $75, $6B, $74, $6B, $94, $63, $B4, $6B, $F5, $73, $F3, $7B, $03, $B5,
    $03, $B5, $B0, $4A, $B0, $4A, $D0, $52, $11, $5B, $93, $63, $D4, $6B, $6F, $8C,
    $4D, $8C, $03, $B5, $C4, $AC, $E7, $83, $22, $BD, $29, $6B, $4D, $42, $0C, $5B,
    $47, $94, $10, $5B, $32, $53, $53, $53, $74, $53, $94, $53, $94, $5B, $B4, $5B,
    $B4, $5B, $94, $5B, $B4, $5B, $D5, $5B, $D5, $5B, $D5, $5B, $F5, $5B, $F6, $5B,
    $F6, $5B, $F5, $5B, $F5, $5B, $F4, $5B, $F4, $5B, $F5, $5B, $F5, $5B, $F6, $5B,
    $35, $64, $55, $6C, $55, $6C, $8F, $7C, $23, $B5, $41, $C5, $6C, $5B, $EF, $42,
    $F0, $42, $31, $43, $72, $4B, $93, $4B, $B4, $53, $D4, $53, $F4, $53, $F4, $53,
    $14, $5C, $36, $5C, $36, $5C, $FF, $FF, $FF, $FF, $00, $08, $00, $08, $00, $10,
    $00, $10, $00, $10, $00, $10, $00, $10, $00, $10, $00, $10, $00, $10, $00, $10,
    $20, $18, $20, $18, $21, $20, $21, $20, $01, $20, $01, $18, $00, $18, $03, $10,
    $03, $10, $03, $18, $03, $18, $04, $18, $04, $10, $04, $10, $04, $10, $05, $18,
    $05, $28, $27, $38, $87, $48, $E8, $50, $6A, $59, $EB, $51, $0B, $52, $2C, $5A,
    $4D, $5A, $6D, $62, $8D, $62, $8E, $62, $CE, $6A, $AE, $62, $EF, $62, $30, $73,
    $30, $6B, $4D, $6B, $03, $B5, $03, $B5, $AC, $5A, $AC, $52, $07, $8C, $6B, $7B,
    $AF, $62, $D0, $62, $11, $63, $11, $6B, $31, $63, $32, $63, $32, $63, $32, $63,
    $52, $63, $52, $63, $53, $63, $54, $6B, $54, $6B, $54, $63, $53, $6B, $53, $63,
    $93, $6B, $B3, $6B, $A7, $A4, $41, $C5, $2C, $63, $8F, $4A, $8F, $4A, $AF, $4A,
    $11, $53, $72, $63, $D3, $6B, $C9, $A4, $6A, $94, $41, $C5, $22, $BD, $22, $BD,
    $0A, $63, $2D, $3A, $C8, $7B, $AA, $7B, $D0, $4A, $F1, $52, $12, $4B, $32, $53,
    $53, $53, $53, $53, $53, $53, $73, $53, $53, $53, $53, $53, $53, $53, $73, $53,
    $93, $53, $94, $53, $93, $5B, $B4, $5B, $B4, $5B, $D4, $5B, $D4, $5B, $93, $53,
    $93, $5B, $B3, $5B, $B3, $5B, $D4, $5B, $F5, $63, $35, $64, $52, $74, $E6, $A4,
    $41, $C5, $E9, $7B, $AE, $3A, $AE, $3A, $CF, $42, $EF, $42, $30, $4B, $51, $4B,
    $72, $4B, $92, $4B, $93, $53, $B3, $53, $B4, $4B, $F4, $5B, $15, $5C, $FF, $FF,
    $FF, $FF, $00, $48, $00, $48, $00, $48, $00, $40, $00, $40, $00, $38, $00, $38,
    $00, $30, $00, $30, $00, $30, $00, $30, $00, $30, $01, $38, $02, $28, $03, $28,
    $02, $28, $02, $20, $03, $20, $04, $18, $04, $10, $04, $08, $04, $08, $04, $08,
    $04, $08, $04, $10, $05, $10, $05, $10, $06, $10, $27, $18, $47, $20, $88, $20,
    $E9, $30, $49, $39, $8A, $41, $AB, $41, $CC, $49, $0D, $52, $2D, $52, $2D, $52,
    $4E, $52, $6E, $5A, $AF, $5A, $30, $6B, $8E, $73, $22, $BD, $E3, $B4, $CC, $5A,
    $89, $7B, $C8, $83, $AD, $5A, $8F, $52, $AF, $52, $B0, $5A, $D0, $5A, $F1, $5A,
    $F1, $5A, $F1, $5A, $F1, $5A, $F2, $5A, $F2, $5A, $12, $5B, $13, $63, $53, $63,
    $53, $63, $13, $63, $32, $63, $32, $63, $52, $6B, $0B, $8C, $41, $C5, $C8, $83,
    $6E, $4A, $6E, $42, $6E, $42, $6E, $42, $D0, $52, $52, $63, $2D, $8C, $6A, $94,
    $41, $C5, $66, $9C, $41, $C5, $0A, $63, $0A, $63, $A8, $7B, $CD, $52, $8F, $4A,
    $B0, $4A, $D1, $4A, $D1, $52, $F2, $4A, $F2, $4A, $F1, $4A, $F2, $4A, $F2, $4A,
    $F1, $4A, $F1, $4A, $F1, $4A, $F1, $4A, $12, $4B, $32, $4B, $53, $53, $73, $53,
    $74, $53, $94, $53, $73, $53, $33, $53, $33, $53, $53, $53, $73, $53, $B4, $5B,
    $F5, $6B, $14, $74, $A9, $9C, $22, $BD, $86, $94, $AF, $3A, $8E, $3A, $8E, $3A,
    $8F, $3A, $B0, $42, $D1, $42, $F1, $42, $11, $4B, $32, $4B, $32, $4B, $53, $4B,
    $94, $4B, $B5, $53, $D6, $5B, $FF, $FF, $FF, $FF, $E3, $68, $C3, $68, $C2, $60,
    $C1, $58, $C2, $58, $C2, $50, $A2, $50, $A2, $48, $81, $40, $61, $40, $21, $40,
    $01, $38, $01, $38, $02, $30, $03, $28, $02, $28, $03, $20, $03, $20, $05, $18,
    $04, $18, $04, $10, $04, $10, $03, $08, $03, $08, $04, $10, $25, $18, $05, $10,
    $06, $10, $06, $18, $26, $18, $26, $18, $67, $18, $C7, $28, $29, $31, $49, $39,
    $6A, $39, $AB, $41, $CC, $41, $EC, $49, $2D, $4A, $4D, $52, $4D, $4A, $EF, $62,
    $A6, $A4, $41, $C5, $E7, $8B, $89, $7B, $8D, $52, $6D, $4A, $AE, $4A, $6E, $52,
    $8F, $52, $AF, $52, $B0, $5A, $D0, $5A, $D0, $5A, $D0, $5A, $10, $63, $D0, $5A,
    $F1, $5A, $F2, $5A, $12, $5B, $12, $63, $12, $63, $F2, $5A, $F1, $5A, $11, $63,
    $AD, $7B, $22, $BD, $85, $A4, $6E, $4A, $6E, $42, $6E, $42, $4E, $42, $4E, $42,
    $6E, $4A, $31, $63, $69, $9C, $E4, $B4, $41, $C5, $41, $C5, $84, $A4, $89, $73,
    $AD, $52, $6F, $42, $8F, $4A, $B0, $4A, $B1, $4A, $D1, $4A, $D1, $4A, $D1, $4A,
    $D1, $4A, $D1, $4A, $D1, $4A, $D1, $4A, $D0, $4A, $D0, $42, $D0, $4A, $D0, $4A,
    $D0, $4A, $F1, $4A, $12, $4B, $12, $4B, $33, $53, $33, $53, $32, $53, $12, $4B,
    $F1, $42, $F1, $42, $32, $4B, $93, $5B, $D4, $63, $8A, $94, $03, $B5, $E4, $AC,
    $EF, $4A, $8F, $3A, $6E, $3A, $6E, $3A, $8E, $3A, $8E, $3A, $8F, $3A, $AF, $42,
    $B0, $42, $D1, $42, $12, $43, $33, $4B, $74, $4B, $95, $4B, $B6, $53, $FF, $FF,
    $FF, $FF, $E2, $90, $E2, $90, $E2, $90, $E2, $90, $C2, $88, $A1, $88, $81, $88,
    $81, $88, $62, $88, $42, $88, $01, $80, $02, $78, $03, $70, $04, $60, $05, $48,
    $06, $30, $06, $28, $06, $20, $26, $08, $26, $08, $26, $18, $25, $18, $05, $18,
    $04, $18, $04, $18, $04, $18, $25, $18, $25, $10, $25, $10, $26, $10, $27, $10,
    $47, $10, $48, $18, $89, $20, $E9, $28, $2A, $31, $6B, $39, $8C, $41, $CD, $49,
    $0E, $4A, $0D, $4A, $2D, $4A, $6E, $52, $41, $C5, $84, $A4, $AD, $52, $CC, $5A,
    $6E, $4A, $6D, $4A, $8E, $4A, $6E, $4A, $6E, $4A, $8F, $52, $8F, $52, $B0, $52,
    $B1, $5A, $D1, $5A, $0A, $8C, $D1, $52, $D1, $52, $F2, $5A, $F2, $5A, $F2, $62,
    $F2, $5A, $D1, $5A, $B1, $5A, $8D, $73, $22, $BD, $22, $BD, $CD, $5A, $6F, $4A,
    $6F, $4A, $4E, $4A, $4E, $42, $4E, $42, $2E, $42, $EE, $5A, $22, $BD, $41, $C5,
    $03, $B5, $41, $C5, $EC, $62, $CD, $5A, $8F, $4A, $90, $4A, $90, $4A, $D1, $4A,
    $D1, $4A, $D1, $4A, $D1, $4A, $D1, $4A, $D1, $4A, $B0, $4A, $B0, $4A, $B0, $4A,
    $B0, $4A, $B0, $4A, $B0, $4A, $B0, $4A, $90, $42, $B1, $4A, $D1, $4A, $D2, $4A,
    $D2, $4A, $D2, $4A, $D1, $42, $B1, $42, $B0, $42, $B0, $42, $11, $53, $93, $5B,
    $6B, $8C, $C6, $A4, $22, $BD, $2F, $53, $B0, $3A, $6F, $3A, $6F, $32, $6E, $32,
    $4E, $32, $6F, $32, $6F, $32, $6F, $3A, $90, $3A, $B1, $3A, $F2, $42, $33, $4B,
    $54, $4B, $76, $4B, $97, $53, $FF, $FF, $FF, $FF, $84, $A9, $64, $A1, $64, $A1,
    $43, $A1, $23, $99, $03, $91, $E2, $90, $C3, $90, $04, $99, $25, $99, $A4, $A1,
    $A2, $B3, $A2, $BC, $E3, $9A, $03, $A4, $45, $72, $84, $7A, $02, $B5, $03, $94,
    $66, $10, $44, $5A, $01, $B5, $02, $94, $A4, $49, $E4, $59, $43, $83, $A4, $6A,
    $01, $B5, $05, $4A, $66, $39, $A3, $8B, $A3, $8B, $44, $83, $62, $A4, $62, $A4,
    $E9, $28, $26, $73, $41, $C5, $25, $9C, $88, $83, $41, $C5, $06, $94, $A8, $83,
    $66, $9C, $C4, $AC, $08, $8C, $A9, $7B, $8F, $4A, $6E, $4A, $EB, $62, $E7, $8B,
    $C8, $83, $89, $7B, $AA, $7B, $C9, $83, $A5, $A4, $C4, $AC, $F0, $5A, $D1, $52,
    $F1, $5A, $53, $63, $ED, $83, $04, $B5, $04, $B5, $D2, $52, $6D, $73, $C4, $AC,
    $41, $C5, $6B, $73, $C9, $83, $41, $C5, $66, $9C, $C9, $83, $41, $C5, $E7, $8B,
    $0A, $63, $66, $9C, $41, $C5, $29, $8C, $08, $8C, $22, $BD, $28, $8C, $29, $8C,
    $2F, $63, $48, $94, $03, $B5, $29, $8C, $A6, $A4, $AD, $6B, $EB, $7B, $86, $9C,
    $09, $84, $22, $BD, $8B, $73, $6C, $6B, $22, $BD, $47, $94, $D1, $4A, $AA, $7B,
    $B0, $4A, $EF, $4A, $E9, $7B, $CA, $73, $66, $9C, $08, $8C, $66, $94, $CE, $4A,
    $6F, $42, $8F, $3A, $52, $53, $4C, $84, $A9, $9C, $41, $C5, $0A, $7C, $0A, $7C,
    $41, $C5, $66, $94, $90, $3A, $0C, $53, $C8, $7B, $E3, $B4, $85, $9C, $4E, $32,
    $6F, $32, $B0, $3A, $D1, $3A, $13, $43, $34, $43, $75, $4B, $76, $4B, $FF, $FF,
    $FF, $FF, $45, $D1, $45, $C9, $46, $C1, $25, $B9, $05, $B9, $E4, $B8, $C4, $B8,
    $E4, $B8, $45, $C1, $E5, $C2, $84, $C3, $41, $C5, $83, $BA, $84, $B2, $41, $C5,
    $68, $78, $C8, $78, $41, $C5, $02, $BD, $86, $62, $C7, $49, $41, $C5, $41, $C5,
    $64, $7B, $41, $C5, $87, $41, $65, $62, $41, $C5, $A3, $8B, $02, $B5, $03, $94,
    $67, $18, $63, $A4, $41, $C5, $66, $39, $C5, $6A, $C7, $6A, $41, $C5, $87, $83,
    $EA, $72, $41, $C5, $41, $C5, $6B, $83, $66, $A4, $E9, $8B, $EE, $62, $4C, $73,
    $AE, $5A, $85, $A4, $22, $BD, $4A, $73, $E8, $8B, $AA, $7B, $47, $94, $87, $A4,
    $4E, $6B, $41, $C5, $29, $94, $F2, $5A, $12, $5B, $4E, $94, $4E, $94, $41, $C5,
    $A6, $A4, $AC, $7B, $09, $94, $41, $C5, $86, $9C, $E9, $8B, $AA, $83, $41, $C5,
    $08, $8C, $6B, $73, $41, $C5, $41, $C5, $4A, $73, $22, $BD, $41, $C5, $AD, $7B,
    $68, $9C, $48, $94, $4F, $6B, $0B, $8C, $0C, $8C, $41, $C5, $A7, $A4, $EC, $83,
    $41, $C5, $68, $9C, $41, $C5, $71, $6B, $2B, $8C, $41, $C5, $22, $BD, $EC, $83,
    $41, $C5, $68, $94, $AC, $73, $30, $5B, $0A, $84, $A5, $A4, $0F, $5B, $12, $5B,
    $87, $9C, $B0, $4A, $41, $C5, $66, $94, $8F, $42, $90, $42, $6C, $8C, $AC, $94,
    $41, $C5, $04, $B5, $ED, $73, $87, $9C, $41, $C5, $29, $84, $E9, $7B, $C9, $7B,
    $8E, $3A, $22, $BD, $22, $BD, $8E, $3A, $90, $32, $B1, $3A, $B2, $3A, $F3, $42,
    $14, $43, $35, $4B, $36, $4B, $FF, $FF, $FF, $FF, $65, $D1, $45, $D1, $66, $C1,
    $66, $C1, $25, $C1, $05, $C1, $E4, $C0, $25, $C1, $A7, $C9, $69, $D2, $08, $D3,
    $41, $C5, $E4, $C2, $E8, $B1, $44, $BC, $A9, $A2, $24, $B4, $41, $C5, $47, $83,
    $AB, $41, $05, $94, $41, $C5, $E4, $8B, $02, $B5, $A5, $8B, $48, $5A, $41, $C5,
    $E3, $B4, $A5, $8B, $41, $C5, $A7, $41, $25, $7B, $41, $C5, $66, $62, $28, $39,
    $EA, $49, $E3, $B4, $64, $A4, $6B, $62, $22, $BD, $E3, $B4, $EB, $8B, $41, $C5,
    $22, $BD, $22, $BD, $E9, $8B, $CF, $62, $03, $B5, $41, $C5, $2B, $6B, $85, $A4,
    $AE, $5A, $2D, $6B, $CC, $83, $0F, $8C, $93, $73, $41, $C5, $0B, $8C, $F3, $62,
    $93, $73, $72, $94, $25, $B5, $41, $C5, $C6, $AC, $CD, $83, $22, $BD, $E5, $AC,
    $2B, $94, $B1, $7B, $24, $B5, $C6, $AC, $8F, $73, $22, $BD, $41, $C5, $AD, $5A,
    $E3, $B4, $03, $B5, $8E, $73, $42, $BD, $42, $BD, $41, $C5, $A7, $A4, $D4, $7B,
    $35, $84, $43, $BD, $C8, $AC, $30, $84, $34, $84, $43, $BD, $A9, $A4, $2F, $8C,
    $41, $C5, $24, $B5, $6D, $94, $8A, $9C, $E5, $AC, $ED, $7B, $AE, $73, $49, $94,
    $C6, $A4, $31, $5B, $12, $53, $B1, $73, $C6, $AC, $6C, $6B, $41, $C5, $A5, $A4,
    $90, $42, $12, $53, $54, $7C, $43, $BD, $41, $C5, $50, $7C, $6F, $84, $41, $C5,
    $22, $BD, $8D, $63, $C4, $A4, $0D, $53, $66, $94, $22, $BD, $8A, $6B, $70, $3A,
    $91, $3A, $B2, $3A, $F3, $42, $13, $43, $34, $4B, $34, $4B, $56, $4B, $FF, $FF,
    $FF, $FF, $45, $D1, $25, $D1, $48, $C9, $27, $C9, $27, $C9, $06, $C9, $E6, $C8,
    $E5, $C8, $87, $D1, $29, $DA, $66, $D3, $23, $CC, $47, $D1, $89, $D9, $A3, $C4,
    $25, $C4, $05, $C4, $EA, $B9, $ED, $A8, $A9, $A2, $41, $C5, $E7, $93, $30, $32,
    $28, $8C, $09, $84, $04, $B5, $09, $94, $11, $63, $47, $9C, $41, $C5, $A5, $83,
    $02, $B5, $02, $BD, $C5, $72, $CA, $49, $E6, $93, $E3, $B4, $07, $94, $A4, $AC,
    $C8, $93, $B0, $6A, $F2, $72, $34, $7B, $94, $83, $0E, $94, $72, $7B, $68, $A4,
    $41, $C5, $27, $9C, $AF, $5A, $22, $BD, $AB, $83, $4F, $73, $54, $6B, $B5, $7B,
    $A9, $A4, $C6, $AC, $14, $63, $F4, $62, $B6, $7B, $CD, $A4, $43, $BD, $C9, $AC,
    $D4, $83, $05, $B5, $22, $BD, $2B, $94, $95, $73, $C9, $AC, $24, $BD, $A9, $A4,
    $05, $B5, $69, $9C, $F0, $62, $C4, $AC, $22, $BD, $8F, $5A, $12, $6B, $D3, $7B,
    $D5, $7B, $10, $8C, $B3, $7B, $D7, $7B, $73, $94, $06, $B5, $D6, $83, $D8, $83,
    $58, $8C, $0A, $AD, $CC, $A4, $24, $BD, $AB, $A4, $36, $84, $57, $84, $26, $B5,
    $C8, $AC, $EE, $83, $B0, $7B, $04, $B5, $32, $63, $F3, $52, $53, $63, $C6, $AC,
    $CE, $7B, $03, $B5, $41, $C5, $8C, $6B, $B1, $4A, $74, $63, $EB, $A4, $41, $C5,
    $AE, $94, $16, $74, $25, $B5, $24, $B5, $30, $7C, $54, $5B, $22, $BD, $85, $9C,
    $41, $C5, $85, $9C, $AB, $73, $92, $3A, $B2, $42, $D3, $42, $F3, $42, $14, $4B,
    $F4, $4A, $15, $4B, $35, $4B, $FF, $FF, $FF, $FF, $45, $D1, $25, $D1, $48, $C9,
    $48, $C9, $48, $C9, $47, $C9, $27, $D1, $E5, $D0, $67, $D9, $C8, $D9, $66, $D2,
    $26, $D9, $06, $D1, $69, $D1, $CB, $D1, $AC, $C9, $6C, $C1, $0A, $BA, $86, $BB,
    $41, $C5, $45, $AC, $F0, $59, $B3, $42, $D3, $4A, $B3, $4A, $B3, $4A, $93, $52,
    $12, $63, $0B, $8C, $E9, $83, $22, $BD, $02, $BD, $29, $41, $0A, $31, $C6, $93,
    $EE, $51, $0F, $52, $EF, $51, $CF, $49, $AF, $51, $D0, $49, $31, $5A, $D2, $6A,
    $54, $73, $94, $7B, $B1, $83, $41, $C5, $41, $C5, $09, $94, $CB, $8B, $8E, $7B,
    $0A, $94, $0C, $8C, $2C, $94, $8A, $A4, $4D, $94, $55, $73, $35, $6B, $75, $73,
    $D6, $7B, $F6, $83, $F6, $83, $16, $84, $8D, $9C, $C8, $AC, $74, $73, $54, $73,
    $B5, $7B, $F5, $83, $D5, $83, $94, $7B, $73, $6B, $CC, $83, $22, $BD, $22, $BD,
    $ED, $62, $91, $52, $F2, $5A, $74, $6B, $B5, $73, $95, $73, $96, $7B, $B7, $7B,
    $15, $8C, $D6, $7B, $97, $73, $B7, $73, $18, $84, $58, $8C, $38, $84, $D7, $7B,
    $B7, $7B, $17, $7C, $58, $8C, $94, $94, $24, $BD, $F4, $83, $6B, $9C, $CE, $7B,
    $F4, $52, $13, $53, $A7, $A4, $2C, $8C, $C6, $A4, $41, $C5, $48, $94, $B2, $4A,
    $D3, $4A, $94, $63, $36, $74, $36, $74, $16, $6C, $16, $6C, $F6, $73, $16, $74,
    $4E, $8C, $4C, $8C, $E5, $AC, $41, $C5, $AB, $73, $91, $3A, $4D, $63, $CB, $73,
    $D3, $42, $F4, $42, $F4, $4A, $F4, $4A, $F5, $42, $15, $43, $35, $4B, $FF, $FF,
    $FF, $FF, $A5, $D9, $85, $D1, $A6, $D1, $C6, $D1, $E8, $D1, $E8, $D1, $C9, $D1,
    $A8, $D1, $E8, $C9, $E8, $D1, $87, $C9, $25, $C9, $E4, $C8, $E5, $D0, $07, $D1,
    $C7, $D1, $25, $CB, $C6, $CA, $A2, $C4, $A2, $C4, $8B, $C0, $CF, $B0, $D2, $99,
    $54, $82, $54, $52, $F2, $31, $AB, $73, $EB, $7B, $12, $5B, $28, $94, $02, $BD,
    $CB, $41, $4C, $29, $6C, $39, $CA, $72, $AF, $49, $8F, $49, $8F, $49, $6E, $49,
    $4E, $41, $4F, $49, $90, $49, $31, $5A, $B3, $6A, $AF, $8B, $E5, $B4, $41, $C5,
    $0E, $73, $52, $5A, $B3, $62, $F4, $6A, $34, $73, $34, $73, $35, $73, $56, $7B,
    $55, $73, $55, $73, $76, $73, $96, $7B, $A9, $A4, $C7, $AC, $76, $7B, $D6, $83,
    $C9, $AC, $D1, $83, $34, $73, $55, $73, $96, $7B, $B5, $83, $6A, $9C, $72, $7B,
    $4A, $9C, $87, $A4, $22, $BD, $2D, $73, $71, $5A, $92, $5A, $B3, $62, $F4, $62,
    $15, $6B, $35, $6B, $36, $73, $57, $6B, $77, $73, $57, $73, $16, $73, $36, $73,
    $77, $7B, $B7, $7B, $97, $7B, $77, $73, $57, $73, $77, $73, $D7, $7B, $18, $84,
    $38, $8C, $F8, $83, $C8, $AC, $33, $63, $8F, $73, $89, $9C, $F0, $83, $C6, $AC,
    $41, $C5, $09, $8C, $B2, $4A, $B3, $52, $D3, $52, $34, $63, $96, $6B, $96, $6B,
    $76, $6B, $55, $6B, $F0, $83, $6C, $94, $B3, $6B, $4B, $8C, $41, $C5, $CA, $83,
    $92, $42, $92, $4A, $11, $5B, $31, $5B, $D5, $4A, $D4, $4A, $F5, $4A, $F5, $4A,
    $F5, $4A, $F5, $4A, $F5, $4A, $FF, $FF, $FF, $FF, $C6, $D9, $C5, $D9, $E7, $D9,
    $08, $DA, $29, $DA, $4A, $E2, $4B, $E2, $2A, $E2, $29, $E2, $29, $DA, $07, $DA,
    $86, $D9, $E4, $D8, $E3, $D0, $C3, $CA, $A4, $CA, $47, $D1, $63, $C4, $43, $C4,
    $6B, $D8, $2C, $C8, $8E, $B0, $B3, $A1, $96, $8A, $F2, $72, $27, $94, $70, $32,
    $53, $2A, $E9, $83, $22, $BD, $2C, $52, $4D, $29, $4D, $29, $AE, $39, $4E, $41,
    $4E, $41, $2E, $41, $0E, $39, $EE, $38, $EE, $38, $2F, $41, $8F, $49, $F1, $59,
    $CA, $8B, $EB, $93, $41, $C5, $2C, $7B, $F1, $51, $12, $52, $72, $5A, $D3, $6A,
    $F4, $6A, $F5, $6A, $F5, $6A, $15, $6B, $15, $73, $15, $73, $75, $7B, $96, $7B,
    $4C, $9C, $72, $7B, $14, $73, $55, $73, $75, $7B, $34, $73, $34, $73, $76, $7B,
    $B6, $83, $E7, $B4, $2C, $94, $2A, $9C, $EB, $93, $22, $BD, $4D, $73, $92, $5A,
    $92, $5A, $B3, $5A, $B4, $5A, $D4, $62, $D5, $62, $F5, $62, $F5, $62, $16, $6B,
    $F5, $6A, $F5, $62, $D5, $62, $D5, $62, $D5, $62, $F5, $62, $F5, $62, $F5, $62,
    $F5, $62, $15, $63, $56, $6B, $B7, $7B, $F8, $83, $18, $84, $AC, $A4, $0F, $8C,
    $D2, $7B, $D2, $7B, $24, $B5, $43, $BD, $CD, $7B, $B3, $52, $B3, $52, $D4, $52,
    $F4, $52, $15, $63, $35, $63, $35, $63, $33, $63, $2A, $8C, $91, $6B, $34, $5B,
    $EE, $83, $41, $C5, $CA, $83, $92, $4A, $B3, $4A, $D3, $4A, $F4, $4A, $F4, $4A,
    $D5, $4A, $F5, $4A, $D5, $4A, $D5, $4A, $D5, $4A, $D5, $4A, $D5, $4A, $FF, $FF,
    $FF, $FF, $44, $DA, $24, $DA, $64, $DA, $84, $DA, $A7, $E2, $C9, $E2, $CA, $EA,
    $CB, $E2, $AC, $E2, $EC, $E2, $EB, $E2, $8A, $DA, $C5, $D2, $63, $CB, $64, $D1,
    $66, $D1, $23, $C4, $C3, $C3, $85, $D0, $66, $D8, $27, $E8, $6B, $E8, $EF, $E8,
    $4F, $DA, $28, $BC, $F6, $89, $94, $49, $CA, $83, $A5, $A4, $11, $3A, $92, $21,
    $72, $29, $31, $39, $71, $41, $6E, $41, $2E, $39, $2F, $39, $2F, $39, $2F, $39,
    $0F, $39, $50, $49, $F2, $59, $0D, $7B, $EA, $93, $67, $A4, $8E, $6A, $71, $49,
    $B2, $49, $D2, $51, $F3, $51, $53, $5A, $73, $5A, $73, $62, $94, $62, $B4, $62,
    $B4, $62, $D5, $6A, $36, $73, $55, $73, $36, $7B, $15, $73, $14, $6B, $14, $73,
    $34, $73, $F4, $72, $35, $73, $96, $83, $D7, $83, $6D, $9C, $4B, $9C, $AE, $8B,
    $22, $BD, $4E, $7B, $93, $62, $93, $5A, $93, $5A, $B4, $5A, $B4, $62, $D5, $62,
    $D5, $62, $D5, $62, $D5, $62, $D4, $62, $D4, $62, $D4, $62, $D4, $62, $B3, $62,
    $B3, $62, $D4, $62, $D4, $62, $D4, $62, $D4, $62, $D4, $62, $D4, $62, $D4, $62,
    $76, $7B, $F6, $83, $8E, $9C, $8D, $9C, $C8, $AC, $05, $B5, $4C, $94, $54, $6B,
    $D4, $62, $B4, $52, $B4, $5A, $B4, $62, $B5, $5A, $15, $63, $36, $6B, $34, $6B,
    $49, $9C, $F3, $62, $D5, $5A, $2B, $8C, $22, $BD, $AC, $7B, $72, $4A, $73, $4A,
    $94, $4A, $94, $52, $B5, $4A, $B5, $4A, $B5, $4A, $B5, $4A, $B5, $4A, $B4, $4A,
    $B4, $4A, $B4, $4A, $B5, $4A, $FF, $FF, $FF, $FF, $A5, $E2, $85, $E2, $A5, $E2,
    $C5, $E2, $C8, $EA, $E9, $EA, $0B, $F3, $0D, $F3, $0D, $F3, $6E, $F3, $8E, $F3,
    $08, $DC, $E6, $DB, $28, $EA, $67, $E2, $82, $CC, $A4, $DA, $65, $D8, $46, $D8,
    $27, $E0, $28, $F0, $ED, $F0, $71, $F1, $A5, $CC, $34, $BA, $D7, $A2, $87, $AC,
    $09, $8C, $33, $32, $B4, $21, $D4, $31, $B2, $39, $72, $41, $91, $49, $6F, $41,
    $6F, $41, $70, $41, $70, $41, $50, $41, $4F, $41, $71, $49, $D2, $51, $52, $62,
    $73, $62, $32, $5A, $91, $49, $50, $41, $71, $41, $92, $49, $D2, $51, $F2, $51,
    $32, $52, $53, $5A, $53, $5A, $73, $5A, $94, $62, $B4, $62, $D4, $6A, $F5, $6A,
    $F5, $6A, $F4, $6A, $D4, $62, $D4, $62, $D4, $62, $D4, $62, $35, $73, $B7, $83,
    $51, $94, $C8, $AC, $0E, $8C, $04, $B5, $10, $73, $93, $5A, $93, $5A, $93, $5A,
    $93, $62, $B3, $62, $B4, $62, $B4, $62, $B4, $62, $B4, $62, $B4, $62, $D4, $62,
    $B3, $62, $B3, $62, $B3, $5A, $B3, $5A, $B3, $5A, $B3, $5A, $B3, $5A, $B3, $5A,
    $B3, $5A, $B3, $5A, $B3, $5A, $B3, $5A, $14, $63, $95, $73, $B5, $7B, $B6, $7B,
    $96, $73, $76, $73, $35, $6B, $F5, $62, $B5, $5A, $B5, $5A, $B5, $5A, $D5, $5A,
    $B5, $5A, $36, $6B, $76, $73, $A8, $A4, $71, $73, $D5, $62, $69, $9C, $E5, $AC,
    $70, $6B, $93, $4A, $93, $4A, $93, $4A, $73, $4A, $94, $4A, $94, $4A, $B5, $4A,
    $B5, $4A, $95, $4A, $95, $4A, $94, $4A, $94, $4A, $94, $4A, $94, $4A, $FF, $FF,
    $FF, $FF, $85, $E3, $65, $DB, $86, $DB, $86, $DB, $87, $E3, $A8, $E3, $A8, $EB,
    $A9, $EB, $AA, $EB, $0D, $F4, $6F, $F4, $05, $D5, $ED, $F3, $47, $DC, $65, $D4,
    $08, $E3, $06, $D2, $65, $D9, $84, $F0, $43, $E8, $44, $E8, $4A, $E9, $AC, $F9,
    $45, $D4, $49, $E3, $AA, $DB, $33, $C3, $F6, $71, $76, $39, $96, $31, $96, $31,
    $D7, $39, $F6, $39, $D4, $39, $F3, $41, $B2, $41, $71, $49, $51, $51, $51, $51,
    $51, $51, $71, $49, $B1, $51, $F1, $51, $F2, $51, $B1, $59, $71, $51, $30, $49,
    $51, $49, $52, $49, $72, $49, $B2, $49, $D2, $51, $F3, $51, $13, $5A, $33, $5A,
    $54, $62, $74, $62, $74, $62, $74, $62, $74, $62, $94, $6A, $94, $6A, $94, $6A,
    $94, $6A, $94, $6A, $35, $7B, $B6, $83, $E8, $AC, $8B, $A4, $4C, $9C, $13, $6B,
    $B3, $62, $B3, $62, $B3, $62, $B4, $62, $B4, $62, $B4, $62, $B4, $62, $B4, $62,
    $B4, $62, $B4, $62, $B4, $5A, $94, $62, $94, $62, $94, $62, $94, $62, $94, $5A,
    $93, $5A, $93, $5A, $93, $5A, $94, $5A, $93, $5A, $93, $5A, $93, $5A, $93, $5A,
    $B4, $62, $F5, $62, $35, $6B, $14, $6B, $14, $6B, $F4, $6A, $D5, $62, $B4, $5A,
    $94, $5A, $94, $5A, $94, $5A, $94, $5A, $B4, $5A, $55, $6B, $96, $73, $C8, $AC,
    $4C, $94, $69, $9C, $AE, $83, $F4, $62, $D4, $5A, $B3, $5A, $93, $52, $94, $52,
    $94, $52, $74, $52, $74, $52, $94, $52, $74, $52, $74, $52, $74, $4A, $74, $4A,
    $53, $4A, $53, $4A, $74, $4A, $FF, $FF, $FF, $FF, $E7, $EB, $E6, $EB, $E7, $E3,
    $E8, $EB, $E8, $EB, $E9, $EB, $09, $F4, $0B, $F4, $EB, $F3, $4E, $F4, $90, $FC,
    $AD, $F4, $AA, $EC, $2D, $F4, $8D, $FB, $2C, $FB, $A9, $F2, $28, $F2, $26, $F9,
    $A5, $F8, $65, $E8, $08, $E9, $4C, $F9, $6E, $F9, $4F, $F9, $73, $E9, $97, $CA,
    $D9, $8A, $19, $4A, $56, $29, $76, $29, $B7, $31, $D5, $39, $14, $42, $F4, $41,
    $D3, $49, $92, $51, $71, $51, $71, $59, $71, $59, $71, $51, $71, $49, $71, $49,
    $71, $49, $51, $49, $51, $49, $51, $49, $51, $49, $72, $49, $72, $49, $72, $49,
    $92, $49, $B2, $49, $D2, $51, $F2, $51, $13, $52, $33, $5A, $54, $5A, $53, $62,
    $54, $62, $74, $62, $74, $62, $94, $62, $94, $62, $94, $62, $F5, $72, $76, $7B,
    $96, $83, $76, $7B, $15, $73, $B4, $6A, $94, $62, $B4, $62, $B4, $62, $B4, $62,
    $94, $62, $94, $62, $94, $62, $B4, $62, $B4, $62, $B4, $5A, $93, $5A, $94, $62,
    $94, $62, $94, $62, $93, $5A, $93, $5A, $93, $5A, $93, $5A, $93, $5A, $93, $5A,
    $93, $5A, $73, $5A, $73, $5A, $93, $5A, $93, $5A, $93, $5A, $93, $5A, $73, $5A,
    $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $93, $5A, $93, $5A, $93, $52,
    $93, $5A, $14, $6B, $75, $73, $75, $6B, $54, $6B, $14, $63, $F4, $5A, $B4, $5A,
    $94, $52, $74, $52, $74, $52, $74, $52, $73, $52, $74, $52, $74, $52, $73, $4A,
    $73, $4A, $53, $4A, $53, $4A, $53, $4A, $53, $4A, $53, $4A, $53, $4A, $FF, $FF,
    $FF, $FF, $87, $F4, $86, $F4, $86, $EC, $A6, $EC, $A6, $F4, $C7, $F4, $C7, $F4,
    $C8, $F4, $C9, $F4, $EB, $F4, $ED, $F4, $EE, $F4, $CF, $F4, $8F, $FC, $4E, $FC,
    $EE, $FB, $AD, $FB, $4C, $FB, $CA, $F2, $08, $F2, $46, $E9, $26, $E9, $07, $F1,
    $28, $F1, $0A, $F9, $ED, $F8, $51, $F9, $16, $DA, $18, $9A, $96, $51, $96, $29,
    $B6, $29, $B5, $39, $F5, $41, $15, $42, $14, $42, $F4, $51, $B3, $59, $B2, $59,
    $B2, $59, $91, $51, $91, $51, $91, $51, $91, $51, $91, $51, $71, $51, $71, $51,
    $71, $51, $91, $49, $91, $49, $71, $49, $71, $49, $92, $49, $92, $49, $B2, $49,
    $B2, $51, $D2, $51, $F3, $51, $13, $5A, $13, $5A, $33, $5A, $54, $62, $54, $62,
    $54, $62, $74, $62, $B5, $6A, $F5, $72, $F5, $72, $F5, $72, $B5, $6A, $94, $62,
    $74, $62, $94, $62, $94, $62, $74, $62, $74, $62, $74, $5A, $94, $5A, $94, $5A,
    $94, $5A, $74, $5A, $74, $5A, $74, $62, $74, $62, $94, $5A, $74, $5A, $74, $5A,
    $74, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A,
    $73, $5A, $73, $5A, $73, $5A, $74, $5A, $74, $5A, $74, $5A, $74, $5A, $74, $5A,
    $74, $5A, $74, $5A, $73, $5A, $73, $5A, $73, $5A, $B4, $5A, $F4, $62, $F4, $62,
    $F4, $62, $D4, $5A, $B3, $5A, $94, $52, $53, $52, $53, $52, $53, $52, $53, $52,
    $53, $52, $73, $52, $73, $52, $53, $4A, $53, $4A, $53, $4A, $53, $4A, $53, $4A,
    $33, $4A, $33, $4A, $33, $4A, $FF, $FF, $FF, $FF, $C8, $FC, $A7, $F4, $C7, $F4,
    $E7, $F4, $E8, $FC, $08, $FD, $09, $FD, $09, $FD, $2A, $FD, $0B, $FD, $0D, $FD,
    $0E, $FD, $CE, $FC, $AE, $FC, $6F, $FC, $4F, $FC, $0F, $FC, $CE, $FB, $6C, $FB,
    $CB, $FA, $29, $FA, $67, $F9, $A6, $F8, $46, $F0, $47, $F0, $6C, $F8, $B0, $E8,
    $B5, $C9, $7A, $AA, $7A, $6A, $D6, $31, $95, $29, $B5, $39, $B5, $39, $F5, $41,
    $14, $42, $F4, $51, $F4, $59, $D3, $61, $D2, $59, $B2, $59, $D2, $51, $B2, $51,
    $B2, $51, $B2, $59, $91, $59, $91, $59, $91, $51, $B1, $51, $B1, $49, $92, $49,
    $92, $49, $92, $49, $92, $49, $92, $49, $B2, $49, $B2, $49, $D2, $51, $D2, $51,
    $F2, $51, $13, $5A, $13, $5A, $33, $5A, $33, $5A, $54, $62, $54, $62, $53, $62,
    $53, $62, $73, $62, $73, $62, $74, $62, $74, $62, $73, $5A, $73, $5A, $73, $5A,
    $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $74, $62,
    $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A,
    $73, $5A, $53, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A,
    $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A, $73, $5A,
    $73, $5A, $73, $52, $73, $52, $73, $52, $53, $52, $53, $52, $53, $52, $74, $52,
    $53, $52, $53, $52, $53, $4A, $53, $4A, $53, $4A, $53, $4A, $53, $4A, $53, $4A,
    $33, $4A, $53, $4A, $53, $4A, $33, $4A, $33, $4A, $33, $4A, $33, $4A, $FF, $FF,
    $FF, $FF, $25, $F5, $24, $F5, $45, $F5, $45, $F5, $64, $F5, $85, $F5, $85, $FD,
    $A5, $FD, $C6, $FD, $C7, $FD, $C8, $F5, $A9, $F5, $6A, $F5, $4B, $F5, $2B, $F5,
    $0C, $F5, $CC, $F4, $CC, $F4, $8C, $EC, $4C, $EC, $8B, $FB, $A9, $FA, $E6, $F1,
    $25, $E9, $A4, $F0, $65, $F0, $89, $F8, $6D, $F8, $93, $E9, $37, $C2, $D6, $71,
    $35, $41, $57, $31, $98, $31, $D6, $39, $15, $3A, $16, $4A, $15, $52, $14, $5A,
    $13, $5A, $F2, $59, $F2, $59, $D2, $59, $D2, $59, $B2, $59, $B2, $59, $B2, $59,
    $B2, $59, $D1, $51, $D1, $51, $B2, $51, $B2, $51, $B2, $51, $B2, $51, $B2, $49,
    $B2, $49, $B2, $49, $B2, $51, $B2, $49, $B2, $51, $D3, $51, $D3, $51, $F3, $51,
    $13, $5A, $14, $5A, $34, $5A, $33, $5A, $33, $5A, $34, $62, $54, $62, $54, $62,
    $54, $62, $54, $62, $54, $62, $54, $62, $54, $62, $54, $5A, $54, $5A, $54, $5A,
    $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A,
    $54, $5A, $54, $5A, $54, $5A, $54, $5A, $53, $5A, $53, $5A, $54, $5A, $54, $5A,
    $54, $5A, $53, $5A, $53, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A,
    $54, $5A, $54, $5A, $54, $5A, $74, $5A, $54, $5A, $54, $5A, $53, $52, $53, $52,
    $53, $52, $33, $52, $33, $52, $53, $52, $53, $52, $53, $52, $53, $52, $33, $52,
    $33, $52, $33, $4A, $33, $4A, $33, $4A, $33, $4A, $33, $4A, $33, $4A, $33, $4A,
    $12, $4A, $12, $4A, $33, $4A, $FF, $FF, $FF, $FF, $45, $FD, $45, $FD, $65, $F5,
    $65, $F5, $85, $FD, $A5, $FD, $A5, $FD, $C6, $FD, $E7, $FD, $E8, $FD, $E9, $FD,
    $CA, $FD, $AB, $FD, $8C, $FD, $4C, $FD, $4D, $FD, $0D, $FD, $ED, $FC, $CD, $F4,
    $AD, $F4, $0C, $FC, $6C, $FB, $AA, $FA, $E8, $F9, $06, $F9, $65, $F0, $48, $F8,
    $4C, $F8, $31, $D9, $36, $C2, $B9, $8A, $D7, $51, $16, $31, $77, $31, $B5, $31,
    $F4, $39, $F5, $49, $15, $52, $14, $5A, $14, $5A, $33, $62, $33, $62, $13, $5A,
    $F3, $61, $D3, $61, $D3, $61, $D3, $61, $D2, $59, $F2, $51, $F2, $51, $D3, $51,
    $D3, $51, $D3, $51, $D2, $51, $D2, $51, $B2, $51, $B2, $51, $B2, $51, $B2, $49,
    $B2, $49, $B2, $51, $B2, $51, $D3, $51, $D3, $51, $F3, $59, $13, $5A, $13, $5A,
    $13, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A,
    $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A,
    $54, $5A, $54, $5A, $54, $5A, $53, $5A, $53, $5A, $53, $5A, $33, $5A, $53, $5A,
    $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $53, $5A, $33, $52, $54, $5A,
    $54, $5A, $33, $5A, $33, $5A, $53, $5A, $53, $5A, $53, $5A, $33, $52, $53, $52,
    $53, $52, $53, $52, $53, $52, $33, $52, $33, $52, $33, $52, $33, $52, $33, $4A,
    $33, $4A, $33, $52, $33, $52, $33, $52, $33, $4A, $33, $4A, $33, $4A, $33, $4A,
    $33, $4A, $33, $4A, $33, $4A, $12, $4A, $12, $4A, $12, $4A, $12, $4A, $FF, $FF,
    $FF, $FF, $44, $FD, $24, $F5, $44, $F5, $64, $F5, $84, $FD, $C5, $FD, $E4, $FD,
    $04, $FE, $25, $FE, $25, $FE, $25, $F6, $26, $FE, $27, $FE, $07, $F6, $07, $F6,
    $E7, $F5, $C7, $F5, $A7, $F5, $89, $ED, $4B, $ED, $EB, $F4, $8C, $FC, $0C, $FC,
    $6A, $FB, $88, $F2, $A5, $E9, $E4, $F0, $C5, $F0, $A8, $F0, $0F, $F9, $F5, $D9,
    $B7, $A9, $38, $59, $17, $39, $76, $31, $96, $39, $B7, $41, $F7, $49, $16, $52,
    $35, $52, $34, $5A, $53, $62, $33, $62, $13, $62, $F4, $69, $F4, $61, $F4, $61,
    $F4, $61, $F3, $59, $F3, $59, $F3, $59, $F2, $59, $F2, $59, $D2, $59, $D2, $59,
    $D2, $59, $D3, $59, $D2, $51, $D3, $51, $D3, $51, $D3, $51, $D3, $51, $D3, $51,
    $D3, $51, $D3, $51, $F3, $51, $F3, $59, $F3, $59, $13, $5A, $13, $5A, $14, $5A,
    $14, $5A, $14, $5A, $13, $5A, $14, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A,
    $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A,
    $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $33, $5A, $13, $5A, $33, $5A,
    $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A,
    $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $52,
    $33, $52, $13, $52, $13, $52, $13, $52, $13, $52, $13, $52, $13, $52, $13, $52,
    $13, $52, $13, $52, $13, $52, $33, $52, $13, $4A, $12, $4A, $12, $4A, $12, $4A,
    $F2, $49, $12, $4A, $12, $4A, $FF, $FF, $FF, $FF, $03, $F5, $03, $F5, $23, $F5,
    $44, $F5, $84, $FD, $C5, $FD, $E4, $FD, $04, $FE, $25, $FE, $25, $FE, $46, $FE,
    $46, $FE, $47, $FE, $27, $FE, $28, $FE, $28, $FE, $08, $FE, $E8, $FD, $AA, $F5,
    $8B, $F5, $2C, $FD, $CD, $FC, $6D, $FC, $EC, $FB, $2A, $FB, $89, $FA, $A7, $F9,
    $05, $F9, $A8, $F0, $CE, $F0, $B4, $D1, $3A, $BA, $FC, $71, $37, $39, $56, $31,
    $75, $31, $96, $39, $D6, $41, $16, $4A, $35, $52, $33, $5A, $33, $5A, $33, $6A,
    $33, $6A, $14, $6A, $F4, $69, $F4, $61, $F4, $61, $14, $62, $13, $62, $13, $62,
    $13, $62, $13, $5A, $F3, $59, $F3, $59, $F3, $59, $F3, $59, $F3, $59, $F3, $59,
    $F3, $59, $F3, $59, $F3, $59, $F3, $51, $D3, $51, $D3, $51, $D3, $51, $D3, $59,
    $F3, $59, $F3, $59, $13, $5A, $13, $5A, $13, $5A, $13, $5A, $13, $5A, $13, $5A,
    $14, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A,
    $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A,
    $33, $5A, $13, $52, $13, $52, $13, $52, $13, $5A, $13, $5A, $13, $5A, $13, $52,
    $13, $52, $13, $52, $13, $52, $13, $5A, $13, $5A, $33, $5A, $33, $5A, $33, $52,
    $33, $52, $33, $5A, $34, $5A, $34, $52, $33, $52, $33, $52, $13, $52, $13, $52,
    $13, $52, $13, $52, $13, $52, $13, $4A, $13, $4A, $13, $52, $13, $52, $33, $52,
    $33, $52, $33, $52, $12, $4A, $12, $4A, $12, $4A, $12, $4A, $12, $4A, $FF, $FF,
    $FF, $FF, $C4, $F4, $A4, $F4, $E3, $F4, $03, $F5, $44, $F5, $64, $FD, $A5, $FD,
    $C5, $FD, $E5, $FD, $05, $FE, $06, $FE, $46, $FE, $66, $FE, $67, $FE, $66, $FE,
    $46, $FE, $65, $FE, $65, $FE, $27, $FE, $09, $FE, $E9, $F5, $AA, $ED, $4B, $F5,
    $0B, $F5, $AA, $F4, $29, $F4, $A6, $EB, $05, $F3, $C4, $F1, $05, $E1, $4B, $E9,
    $F2, $F1, $15, $C2, $55, $89, $17, $49, $17, $39, $17, $39, $78, $41, $D8, $49,
    $F7, $49, $16, $52, $55, $5A, $33, $62, $33, $6A, $34, $6A, $34, $6A, $14, $6A,
    $14, $62, $13, $62, $13, $62, $13, $62, $33, $62, $13, $62, $13, $62, $13, $62,
    $13, $62, $13, $5A, $13, $5A, $13, $5A, $13, $5A, $F3, $59, $F3, $59, $13, $5A,
    $13, $5A, $13, $5A, $13, $5A, $F3, $59, $13, $5A, $13, $5A, $13, $5A, $13, $5A,
    $13, $5A, $13, $5A, $13, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $62, $34, $62,
    $34, $62, $34, $62, $34, $62, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A,
    $34, $5A, $34, $5A, $34, $5A, $34, $5A, $13, $5A, $13, $5A, $13, $5A, $13, $5A,
    $13, $5A, $34, $5A, $34, $5A, $13, $5A, $13, $52, $13, $52, $13, $52, $13, $52,
    $13, $5A, $13, $5A, $13, $5A, $13, $5A, $13, $5A, $33, $5A, $33, $5A, $34, $5A,
    $33, $5A, $33, $5A, $33, $52, $33, $52, $13, $52, $13, $52, $13, $52, $13, $52,
    $13, $52, $13, $52, $13, $52, $13, $52, $12, $4A, $12, $4A, $12, $4A, $12, $4A,
    $12, $4A, $12, $4A, $12, $4A, $FF, $FF, $FF, $FF, $E5, $F4, $C4, $F4, $C3, $F4,
    $03, $F5, $24, $F5, $44, $F5, $84, $FD, $C4, $FD, $C5, $FD, $E5, $FD, $E5, $FD,
    $26, $FE, $46, $FE, $46, $FE, $66, $FE, $66, $FE, $66, $FE, $86, $FE, $48, $FE,
    $49, $FE, $2A, $FE, $EB, $F5, $AD, $FD, $6C, $FD, $0B, $FD, $8A, $FC, $29, $FC,
    $A8, $FB, $A8, $FA, $C8, $F9, $4B, $E9, $91, $E9, $35, $CA, $58, $A2, $37, $49,
    $37, $41, $17, $39, $37, $39, $77, $39, $F7, $49, $15, $52, $14, $52, $33, $62,
    $33, $6A, $34, $6A, $55, $6A, $35, $6A, $35, $6A, $34, $6A, $53, $6A, $33, $6A,
    $33, $6A, $33, $6A, $33, $6A, $33, $62, $33, $62, $13, $62, $13, $62, $33, $62,
    $13, $62, $13, $5A, $13, $5A, $34, $5A, $34, $62, $34, $5A, $34, $5A, $13, $5A,
    $14, $62, $14, $62, $14, $62, $14, $62, $14, $62, $14, $62, $14, $62, $34, $62,
    $34, $62, $34, $62, $34, $62, $34, $62, $34, $62, $34, $62, $34, $62, $34, $62,
    $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A, $34, $5A,
    $34, $5A, $34, $5A, $13, $5A, $13, $5A, $13, $5A, $13, $5A, $34, $5A, $13, $5A,
    $13, $5A, $13, $52, $13, $52, $13, $5A, $33, $5A, $33, $5A, $13, $5A, $33, $5A,
    $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $52,
    $33, $52, $13, $52, $13, $52, $13, $52, $13, $52, $13, $52, $13, $52, $13, $52,
    $13, $52, $12, $4A, $12, $4A, $12, $4A, $12, $4A, $12, $4A, $12, $4A, $FF, $FF,
    $FF, $FF, $44, $F5, $44, $F5, $43, $F5, $43, $F5, $63, $F5, $84, $F5, $A4, $F5,
    $C4, $F5, $C5, $F5, $E5, $F5, $E6, $F5, $E6, $F5, $07, $FE, $28, $FE, $48, $FE,
    $68, $FE, $88, $FE, $A8, $FE, $A8, $FE, $A8, $FE, $A8, $FE, $A8, $FE, $89, $FE,
    $69, $F6, $09, $EE, $A8, $ED, $68, $ED, $28, $ED, $A7, $F4, $E7, $EB, $C7, $E2,
    $47, $DA, $49, $E2, $4E, $EA, $16, $92, $77, $61, $D6, $48, $F7, $40, $58, $39,
    $79, $41, $B7, $49, $16, $52, $35, $62, $54, $62, $54, $6A, $74, $6A, $74, $6A,
    $74, $6A, $73, $6A, $73, $6A, $53, $6A, $53, $6A, $53, $6A, $33, $6A, $53, $6A,
    $33, $6A, $33, $62, $33, $62, $33, $62, $33, $62, $13, $62, $33, $62, $33, $62,
    $33, $62, $34, $62, $33, $62, $34, $62, $34, $62, $34, $62, $54, $62, $54, $62,
    $54, $62, $54, $62, $54, $62, $54, $62, $54, $62, $54, $62, $54, $62, $54, $62,
    $54, $62, $54, $62, $54, $62, $54, $62, $54, $62, $54, $62, $54, $62, $54, $62,
    $34, $62, $54, $62, $54, $62, $54, $5A, $54, $5A, $34, $5A, $34, $5A, $33, $5A,
    $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A,
    $54, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A, $33, $5A,
    $33, $5A, $33, $5A, $33, $5A, $53, $52, $33, $52, $33, $52, $13, $52, $13, $52,
    $33, $52, $33, $52, $33, $52, $13, $52, $13, $52, $13, $52, $13, $4A, $13, $4A,
    $13, $4A, $13, $4A, $13, $4A, $FF, $FF, $FF, $FF, $A6, $FD, $85, $FD, $A5, $FD,
    $A5, $FD, $C5, $FD, $E5, $FD, $E5, $FD, $E5, $FD, $05, $FE, $06, $F6, $E6, $F5,
    $07, $FE, $07, $FE, $27, $FE, $47, $FE, $68, $FE, $88, $FE, $88, $FE, $A8, $FE,
    $C8, $FE, $E9, $FE, $E9, $FE, $CA, $FE, $AA, $FE, $4A, $FE, $0A, $F6, $E9, $F5,
    $69, $FD, $09, $FD, $AA, $FC, $CB, $FB, $0A, $FB, $8A, $F2, $2E, $EA, $FA, $AA,
    $19, $72, $17, $51, $F7, $40, $38, $39, $38, $39, $76, $41, $D6, $49, $14, $5A,
    $33, $62, $34, $6A, $54, $6A, $74, $6A, $74, $6A, $93, $72, $93, $72, $54, $6A,
    $54, $6A, $53, $6A, $53, $6A, $53, $6A, $53, $6A, $54, $6A, $54, $6A, $54, $62,
    $33, $62, $33, $62, $33, $62, $53, $62, $54, $62, $54, $62, $54, $62, $54, $6A,
    $54, $6A, $54, $62, $74, $62, $74, $62, $74, $62, $75, $6A, $75, $6A, $75, $6A,
    $75, $6A, $75, $6A, $74, $62, $74, $62, $74, $62, $74, $62, $54, $62, $74, $62,
    $74, $62, $74, $62, $54, $62, $54, $62, $54, $62, $54, $62, $54, $62, $74, $62,
    $74, $62, $74, $62, $54, $62, $54, $62, $54, $62, $54, $62, $54, $62, $74, $5A,
    $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A,
    $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A, $54, $5A,
    $54, $5A, $53, $52, $33, $52, $33, $52, $33, $52, $33, $52, $33, $52, $13, $52,
    $13, $52, $13, $4A, $13, $4A, $12, $4A, $12, $4A, $12, $4A, $12, $4A, $FF, $FF,
    $FF, $FF, $83, $F6, $63, $F6, $64, $FE, $64, $FE, $63, $F6, $84, $F6, $A4, $F6,
    $A4, $F6, $A4, $F6, $C5, $F6, $85, $F6, $86, $F6, $67, $F6, $68, $F6, $88, $F6,
    $89, $F6, $89, $F6, $AA, $EE, $C9, $F6, $E9, $F6, $E9, $FE, $09, $FF, $09, $FF,
    $0A, $FF, $EB, $FE, $CB, $FE, $AB, $FE, $49, $F6, $09, $EE, $C8, $F5, $68, $F5,
    $E8, $F4, $27, $FC, $A7, $EB, $4E, $D3, $F3, $B2, $33, $82, $53, $59, $16, $39,
    $37, $39, $78, $41, $97, $41, $D6, $51, $F5, $59, $15, $5A, $35, $62, $55, $6A,
    $75, $6A, $73, $72, $74, $72, $54, $72, $54, $72, $54, $72, $54, $72, $54, $72,
    $54, $6A, $54, $6A, $54, $6A, $54, $6A, $74, $6A, $74, $6A, $74, $62, $74, $62,
    $74, $62, $74, $6A, $74, $6A, $74, $62, $74, $62, $74, $62, $94, $6A, $74, $6A,
    $94, $6A, $94, $6A, $94, $6A, $95, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A,
    $74, $6A, $74, $6A, $74, $6A, $94, $6A, $94, $6A, $94, $6A, $74, $62, $74, $62,
    $74, $62, $74, $62, $74, $62, $74, $62, $74, $62, $74, $62, $74, $62, $74, $62,
    $74, $62, $74, $62, $74, $62, $94, $62, $94, $62, $94, $62, $94, $5A, $94, $5A,
    $74, $5A, $74, $5A, $74, $5A, $74, $5A, $74, $5A, $73, $5A, $73, $5A, $53, $5A,
    $73, $5A, $73, $5A, $73, $5A, $74, $5A, $74, $5A, $54, $5A, $54, $52, $54, $52,
    $53, $52, $33, $52, $33, $52, $33, $52, $33, $52, $33, $4A, $33, $4A, $33, $4A,
    $33, $4A, $33, $4A, $33, $4A, $FF, $FF, $FF, $FF, $E4, $FE, $C4, $FE, $C5, $FE,
    $C5, $FE, $C5, $FE, $E5, $FE, $05, $FF, $05, $FF, $06, $FF, $06, $FF, $E7, $FE,
    $C8, $FE, $C8, $FE, $C9, $FE, $C9, $FE, $CA, $FE, $CA, $F6, $CA, $F6, $C9, $F6,
    $C8, $F6, $C8, $FE, $E9, $FE, $09, $FF, $2A, $FF, $0B, $FF, $0C, $FF, $EC, $FE,
    $CB, $FE, $8B, $FE, $4A, $FE, $CA, $FD, $6A, $FD, $EA, $FC, $8B, $FC, $F1, $E3,
    $B6, $CB, $37, $A3, $17, $72, $58, $41, $16, $31, $57, $39, $97, $41, $B6, $49,
    $D5, $51, $F5, $59, $35, $62, $55, $6A, $54, $6A, $73, $72, $74, $7A, $95, $7A,
    $75, $72, $75, $72, $75, $72, $74, $72, $74, $72, $74, $72, $74, $6A, $74, $72,
    $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A,
    $94, $6A, $94, $6A, $94, $6A, $94, $6A, $95, $6A, $95, $6A, $95, $6A, $95, $6A,
    $95, $6A, $95, $6A, $95, $6A, $95, $6A, $95, $6A, $95, $6A, $95, $6A, $95, $6A,
    $95, $6A, $95, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $62,
    $94, $62, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $B4, $62,
    $94, $62, $94, $62, $94, $62, $94, $62, $94, $62, $94, $5A, $74, $5A, $74, $5A,
    $74, $5A, $74, $5A, $74, $5A, $74, $5A, $74, $5A, $74, $5A, $74, $5A, $74, $5A,
    $74, $5A, $74, $5A, $74, $5A, $74, $5A, $74, $5A, $54, $5A, $53, $52, $53, $52,
    $53, $52, $53, $52, $53, $52, $53, $52, $53, $52, $53, $52, $53, $52, $FF, $FF,
    $FF, $FF, $A4, $F7, $84, $F7, $65, $FF, $65, $FF, $84, $FF, $A4, $FF, $A3, $F7,
    $A3, $F7, $A3, $F7, $A3, $F7, $85, $FF, $86, $FF, $67, $FF, $68, $FF, $69, $FF,
    $6A, $FF, $6B, $F7, $4B, $F7, $0B, $EF, $0B, $EF, $EA, $F6, $CA, $FE, $CB, $FE,
    $CB, $FE, $EC, $FE, $ED, $FE, $CC, $FE, $EB, $FE, $EA, $FE, $CA, $FE, $89, $FE,
    $69, $F6, $4A, $EE, $0A, $E6, $2B, $FD, $8C, $FC, $32, $CC, $75, $9B, $58, $62,
    $76, $41, $37, $31, $78, $39, $97, $49, $B7, $49, $D7, $51, $F7, $59, $17, $62,
    $36, $6A, $36, $72, $55, $72, $76, $7A, $75, $7A, $95, $7A, $95, $7A, $95, $7A,
    $95, $72, $75, $72, $95, $72, $95, $72, $95, $72, $95, $72, $95, $72, $95, $6A,
    $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A, $94, $6A,
    $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A,
    $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A,
    $B5, $6A, $B5, $6A, $B5, $6A, $B4, $6A, $B4, $6A, $B5, $6A, $B5, $6A, $B5, $6A,
    $B4, $6A, $B4, $6A, $94, $6A, $B4, $62, $B4, $62, $B4, $62, $B4, $62, $B4, $62,
    $B4, $62, $B4, $62, $94, $62, $94, $62, $94, $62, $94, $62, $94, $62, $94, $62,
    $94, $62, $94, $62, $94, $62, $94, $5A, $94, $5A, $94, $5A, $94, $5A, $94, $5A,
    $94, $5A, $74, $5A, $74, $5A, $74, $5A, $74, $5A, $74, $52, $74, $52, $74, $52,
    $54, $52, $54, $52, $54, $52, $FF, $FF, $FF, $FF, $C4, $FF, $A4, $FF, $85, $FF,
    $85, $FF, $A4, $FF, $C4, $FF, $E4, $FF, $E4, $FF, $E4, $FF, $E4, $FF, $C5, $FF,
    $A7, $FF, $A8, $FF, $A9, $FF, $AB, $FF, $AB, $FF, $AC, $FF, $AC, $FF, $8D, $FF,
    $6D, $FF, $0B, $FF, $EB, $FE, $CB, $FE, $AB, $FE, $CC, $F6, $CC, $F6, $CC, $FE,
    $AA, $FE, $A9, $FE, $CA, $FE, $CA, $FE, $CB, $FE, $CC, $FE, $6C, $F6, $8C, $FD,
    $4F, $FD, $36, $ED, $99, $C4, $9D, $8B, $9B, $62, $BA, $49, $58, $39, $77, $41,
    $96, $49, $B6, $51, $D6, $59, $F6, $61, $16, $6A, $36, $72, $35, $72, $75, $7A,
    $75, $7A, $95, $7A, $95, $7A, $96, $7A, $96, $7A, $96, $7A, $B6, $72, $B5, $72,
    $B5, $72, $B6, $72, $B5, $72, $B5, $72, $B5, $72, $B5, $6A, $B5, $6A, $B5, $6A,
    $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $D5, $72, $B5, $6A,
    $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $D5, $72, $D5, $72, $D5, $72, $D5, $72,
    $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A,
    $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $62,
    $B5, $62, $D5, $62, $D5, $62, $D5, $62, $D5, $62, $B5, $62, $B4, $62, $B4, $62,
    $B4, $62, $B5, $62, $B5, $62, $B4, $62, $B4, $62, $B4, $62, $B4, $62, $B5, $62,
    $B5, $62, $94, $5A, $94, $5A, $94, $5A, $94, $5A, $94, $5A, $94, $5A, $94, $5A,
    $74, $5A, $74, $5A, $74, $5A, $74, $52, $74, $52, $74, $52, $74, $52, $FF, $FF,
    $FF, $FF, $46, $FE, $46, $FE, $46, $FE, $46, $FE, $26, $FE, $26, $FE, $26, $FE,
    $66, $FE, $A6, $FE, $E6, $FE, $06, $FF, $47, $FF, $67, $FF, $88, $FF, $89, $FF,
    $A9, $FF, $CA, $FF, $AC, $FF, $8D, $FF, $8D, $FF, $AC, $FF, $6B, $F7, $2B, $F7,
    $AC, $FE, $2D, $FE, $8E, $FD, $4E, $FD, $6F, $FD, $AE, $FD, $0D, $FE, $8C, $FE,
    $EB, $FE, $0B, $FF, $29, $F7, $28, $F7, $07, $EF, $4B, $F6, $D1, $ED, $15, $D5,
    $D7, $9B, $F9, $62, $59, $3A, $F9, $29, $F9, $29, $D8, $39, $D7, $49, $B6, $61,
    $D7, $61, $18, $6A, $18, $6A, $56, $6A, $76, $6A, $96, $72, $96, $7A, $96, $7A,
    $B6, $7A, $B6, $7A, $B6, $7A, $D6, $72, $D6, $72, $D6, $72, $D6, $72, $B6, $72,
    $B6, $6A, $B6, $72, $B6, $72, $B5, $6A, $B5, $6A, $B5, $6A, $B5, $6A, $D5, $6A,
    $D5, $6A, $D5, $6A, $D5, $6A, $D5, $6A, $D5, $6A, $D5, $6A, $D5, $6A, $D5, $6A,
    $D5, $6A, $F5, $6A, $F5, $72, $D5, $6A, $D5, $6A, $D5, $6A, $D5, $6A, $D5, $6A,
    $D5, $6A, $D5, $6A, $D5, $6A, $D5, $6A, $D5, $6A, $D5, $6A, $F5, $6A, $F5, $6A,
    $D5, $6A, $D4, $6A, $D5, $6A, $D5, $62, $D5, $62, $D5, $6A, $D5, $6A, $D5, $6A,
    $D5, $6A, $D5, $6A, $D5, $6A, $D4, $6A, $D4, $6A, $D4, $6A, $D4, $6A, $D4, $6A,
    $D4, $62, $B4, $62, $B4, $62, $D4, $62, $D4, $62, $D4, $62, $B4, $5A, $B5, $5A,
    $B4, $5A, $B4, $5A, $B4, $5A, $B4, $5A, $B4, $5A, $94, $52, $94, $52, $94, $52,
    $94, $52, $94, $52, $94, $52, $FF, $FF, $FF, $FF, $C0, $D4, $C0, $D4, $C0, $DC,
    $C0, $DC, $C0, $DC, $C0, $DC, $C0, $DC, $E0, $DC, $00, $DD, $40, $DD, $C1, $E5,
    $02, $E6, $63, $EE, $C5, $EE, $07, $F7, $48, $F7, $89, $FF, $8B, $FF, $4C, $FF,
    $4C, $FF, $6B, $F7, $4A, $F7, $CA, $EE, $4A, $EE, $8B, $ED, $EC, $EC, $6B, $E4,
    $AC, $F4, $EB, $F4, $6A, $ED, $2B, $F6, $AA, $F6, $0B, $FF, $6A, $FF, $89, $FF,
    $89, $FF, $CD, $FE, $33, $FE, $B8, $ED, $FB, $BC, $1D, $8C, $5C, $5B, $9B, $3A,
    $3A, $32, $D8, $41, $B7, $49, $96, $59, $B6, $61, $F7, $69, $F7, $69, $55, $6A,
    $76, $6A, $76, $72, $76, $72, $76, $72, $95, $7A, $96, $7A, $B6, $72, $D6, $72,
    $D6, $72, $D6, $72, $D6, $72, $B6, $72, $B6, $72, $B6, $72, $B6, $72, $B5, $6A,
    $D5, $72, $D5, $72, $D5, $72, $D5, $72, $D5, $72, $D5, $72, $D5, $72, $F5, $72,
    $F5, $72, $F5, $72, $F5, $72, $F5, $72, $F5, $72, $F5, $72, $F5, $72, $F6, $72,
    $F6, $72, $F6, $72, $F6, $6A, $F5, $6A, $F5, $6A, $F5, $6A, $D5, $6A, $F5, $6A,
    $F5, $6A, $F5, $6A, $F5, $6A, $F5, $6A, $F5, $6A, $F5, $6A, $F5, $6A, $15, $6B,
    $15, $6B, $F5, $6A, $F5, $6A, $F5, $6A, $F5, $6A, $F5, $6A, $F5, $6A, $F5, $6A,
    $F5, $6A, $F5, $6A, $F5, $6A, $F5, $6A, $F5, $6A, $D4, $6A, $D4, $6A, $F5, $62,
    $F5, $62, $F5, $62, $D5, $62, $D5, $62, $D5, $62, $D5, $5A, $D5, $5A, $B5, $5A,
    $B5, $5A, $B5, $5A, $B4, $5A, $B5, $5A, $B5, $5A, $B5, $5A, $B5, $5A, $FF, $FF,
    $FF, $FF, $43, $9A, $23, $9A, $43, $9A, $63, $9A, $83, $A2, $83, $AA, $83, $B2,
    $83, $B2, $63, $BA, $63, $BA, $84, $C2, $A4, $CA, $C5, $DA, $26, $EB, $67, $F3,
    $87, $FB, $C7, $FB, $E8, $FB, $EA, $FB, $CA, $FB, $8A, $FB, $6A, $F3, $6A, $F3,
    $49, $EB, $29, $EB, $29, $EB, $0A, $EB, $2A, $EB, $4B, $EB, $AD, $EB, $8D, $FC,
    $4C, $FD, $0C, $FE, $CD, $FE, $8D, $FF, $AE, $FF, $4D, $F7, $0D, $F7, $EE, $F6,
    $51, $DE, $73, $B5, $74, $94, $95, $6B, $F8, $52, $58, $4A, $38, $42, $F8, $49,
    $F7, $49, $F7, $59, $17, $5A, $37, $62, $37, $6A, $58, $6A, $57, $72, $57, $72,
    $76, $72, $96, $7A, $B5, $7A, $D5, $72, $D5, $72, $F5, $6A, $F5, $6A, $D5, $72,
    $D5, $72, $D5, $72, $D5, $72, $D5, $72, $D5, $72, $D5, $72, $D6, $72, $F5, $72,
    $F5, $72, $F6, $72, $F6, $72, $F6, $72, $F6, $72, $F5, $72, $F5, $72, $F5, $72,
    $F5, $72, $15, $73, $15, $73, $36, $73, $36, $73, $16, $73, $16, $73, $16, $73,
    $16, $73, $16, $73, $16, $73, $16, $73, $16, $73, $16, $73, $36, $73, $36, $73,
    $16, $73, $16, $73, $36, $73, $36, $73, $36, $73, $36, $73, $35, $73, $16, $6B,
    $15, $6B, $15, $6B, $15, $6B, $F5, $6A, $F5, $6A, $F5, $6A, $15, $6B, $15, $6B,
    $F5, $6A, $15, $6B, $F5, $6A, $F5, $6A, $F5, $6A, $F5, $62, $F5, $62, $F5, $62,
    $D5, $62, $D5, $62, $D5, $62, $D5, $62, $D5, $5A, $D5, $5A, $D4, $5A, $D5, $5A,
    $D5, $5A, $D5, $5A, $D5, $5A, $FF, $FF, $FF, $FF, $60, $60, $60, $60, $80, $60,
    $A0, $60, $C0, $68, $E0, $70, $E0, $78, $C0, $80, $C0, $88, $C0, $88, $C0, $90,
    $E0, $98, $00, $A1, $20, $A9, $40, $B1, $60, $B9, $80, $C1, $A0, $C9, $C2, $C9,
    $A1, $C1, $62, $C1, $83, $C9, $E4, $C9, $25, $D2, $66, $D2, $87, $D2, $C9, $DA,
    $CA, $DA, $E9, $DA, $29, $DB, $A9, $DB, $69, $EC, $29, $FD, $EA, $FD, $4C, $F7,
    $8E, $F7, $4D, $F7, $0D, $EF, $CF, $E6, $52, $DE, $F5, $C5, $57, $AD, $99, $8C,
    $DB, $73, $1B, $5B, $BA, $4A, $58, $52, $18, $52, $18, $5A, $17, $5A, $F7, $59,
    $16, $62, $17, $62, $36, $6A, $36, $6A, $55, $72, $75, $72, $95, $72, $B5, $72,
    $D5, $72, $F5, $6A, $F5, $72, $F6, $72, $F6, $72, $F6, $72, $F6, $72, $F6, $72,
    $F6, $72, $F6, $72, $F6, $72, $F6, $72, $16, $7B, $16, $73, $16, $73, $16, $73,
    $16, $73, $16, $73, $16, $73, $16, $73, $16, $73, $16, $73, $36, $73, $36, $7B,
    $36, $7B, $36, $7B, $36, $7B, $36, $7B, $36, $7B, $36, $73, $36, $73, $36, $73,
    $36, $73, $36, $73, $56, $73, $56, $73, $36, $73, $36, $73, $56, $73, $56, $73,
    $56, $73, $56, $73, $56, $73, $36, $73, $36, $73, $36, $73, $36, $73, $16, $73,
    $16, $73, $16, $6B, $16, $73, $16, $73, $16, $6B, $16, $6B, $16, $6B, $16, $6B,
    $15, $6B, $15, $6B, $15, $6B, $F5, $62, $F5, $62, $F5, $62, $D5, $62, $F5, $62,
    $F5, $62, $D5, $62, $D5, $62, $D5, $5A, $F5, $62, $F5, $62, $F5, $62, $FF, $FF,
    $FF, $FF, $00, $08, $00, $08, $20, $08, $20, $08, $41, $10, $21, $18, $21, $20,
    $21, $28, $22, $38, $01, $40, $02, $48, $01, $58, $21, $68, $01, $78, $21, $88,
    $21, $98, $61, $A0, $61, $B0, $40, $C0, $20, $C0, $42, $C8, $83, $D0, $45, $D1,
    $A6, $D1, $26, $CA, $66, $C2, $C7, $CA, $E8, $D2, $C9, $DA, $C8, $DA, $E9, $E2,
    $09, $DB, $AA, $EB, $8B, $F4, $8D, $F5, $6E, $EE, $EC, $E6, $EB, $DE, $A9, $CE,
    $89, $CE, $2C, $CE, $CF, $CD, $31, $B5, $D3, $94, $B5, $6C, $37, $5C, $78, $4B,
    $18, $4B, $59, $6A, $39, $62, $37, $5A, $57, $5A, $57, $62, $56, $62, $56, $6A,
    $56, $6A, $76, $72, $75, $72, $B6, $72, $B5, $72, $D6, $72, $D6, $7A, $F6, $7A,
    $F6, $7A, $F7, $7A, $F7, $7A, $16, $7B, $16, $7B, $16, $7B, $16, $7B, $16, $7B,
    $16, $7B, $16, $7B, $16, $7B, $36, $7B, $36, $7B, $36, $7B, $36, $7B, $36, $7B,
    $36, $7B, $56, $7B, $56, $7B, $56, $7B, $56, $7B, $56, $7B, $56, $7B, $56, $7B,
    $56, $7B, $56, $7B, $56, $7B, $56, $7B, $56, $73, $56, $73, $56, $7B, $56, $7B,
    $56, $7B, $56, $73, $76, $7B, $56, $73, $56, $73, $56, $73, $56, $73, $56, $73,
    $56, $73, $36, $73, $36, $73, $56, $73, $56, $73, $36, $73, $56, $73, $56, $73,
    $56, $73, $56, $6B, $56, $6B, $36, $6B, $36, $6B, $36, $6B, $36, $6B, $15, $6B,
    $15, $6B, $15, $63, $15, $63, $15, $63, $F5, $62, $F5, $62, $F5, $62, $F5, $62,
    $F5, $62, $15, $63, $15, $63, $FF, $FF, $FF, $FF, $00, $08, $00, $08, $00, $08,
    $00, $08, $00, $08, $00, $10, $00, $18, $00, $20, $00, $28, $00, $38, $00, $40,
    $00, $48, $00, $58, $00, $68, $00, $78, $00, $88, $00, $90, $00, $A0, $00, $B8,
    $00, $B8, $21, $C0, $63, $B8, $04, $C1, $85, $B9, $E5, $B9, $26, $B2, $67, $B2,
    $A8, $C2, $C9, $CA, $C9, $D2, $C8, $DA, $E8, $DA, $08, $D3, $88, $D3, $68, $D4,
    $2A, $D5, $09, $D6, $6A, $CE, $29, $C6, $E9, $BD, $AC, $B5, $4E, $B5, $52, $B5,
    $54, $A5, $57, $85, $FA, $7C, $7B, $6C, $FB, $63, $FC, $7A, $9A, $72, $99, $6A,
    $77, $62, $57, $62, $57, $62, $56, $6A, $56, $6A, $76, $72, $96, $72, $96, $72,
    $B5, $72, $B6, $72, $D6, $72, $F6, $7A, $F6, $7A, $F7, $7A, $F7, $7A, $16, $7B,
    $16, $7B, $17, $7B, $17, $7B, $36, $83, $36, $83, $36, $7B, $37, $7B, $57, $83,
    $57, $83, $56, $7B, $56, $7B, $56, $7B, $56, $7B, $56, $7B, $56, $7B, $56, $7B,
    $56, $7B, $56, $7B, $56, $7B, $56, $7B, $56, $7B, $77, $7B, $77, $7B, $77, $7B,
    $76, $7B, $76, $7B, $77, $7B, $77, $7B, $76, $7B, $76, $7B, $77, $7B, $77, $7B,
    $77, $7B, $76, $7B, $76, $7B, $76, $7B, $76, $7B, $57, $7B, $57, $7B, $57, $7B,
    $57, $7B, $56, $73, $76, $73, $56, $73, $56, $73, $56, $73, $56, $73, $56, $73,
    $56, $73, $56, $6B, $36, $6B, $36, $6B, $36, $6B, $35, $6B, $15, $6B, $15, $63,
    $15, $63, $15, $63, $15, $63, $15, $63, $15, $63, $15, $63, $15, $63, $FF, $FF,
    $FF, $FF, $01, $08, $01, $08, $00, $00, $00, $00, $00, $00, $00, $00, $00, $08,
    $00, $08, $01, $10, $01, $18, $02, $20, $03, $28, $03, $38, $02, $40, $02, $50,
    $02, $58, $22, $60, $02, $70, $03, $90, $03, $A0, $21, $A8, $41, $A8, $C1, $A8,
    $42, $B1, $A3, $A9, $E4, $A1, $25, $AA, $86, $B2, $C6, $BA, $E7, $C2, $E8, $DA,
    $C8, $E2, $89, $E2, $68, $DA, $88, $DA, $08, $D3, $E9, $CB, $CA, $C4, $4A, $BD,
    $8B, $B5, $6B, $AD, $6C, $A5, $6D, $AD, $8F, $AD, $B1, $A5, $D4, $AD, $96, $A5,
    $39, $95, $DB, $7C, $5A, $6C, $79, $6B, $18, $6B, $D7, $62, $B7, $5A, $97, $62,
    $97, $62, $77, $6A, $77, $6A, $97, $6A, $96, $72, $96, $72, $B6, $7A, $B6, $7A,
    $B6, $82, $D6, $82, $D6, $82, $F6, $82, $F6, $82, $16, $83, $17, $83, $16, $83,
    $37, $83, $37, $83, $37, $83, $56, $83, $56, $83, $56, $83, $56, $83, $56, $83,
    $56, $83, $76, $83, $76, $83, $76, $83, $96, $7B, $96, $7B, $96, $7B, $96, $7B,
    $97, $7B, $97, $7B, $97, $7B, $97, $83, $97, $7B, $97, $7B, $97, $7B, $97, $7B,
    $97, $7B, $97, $7B, $97, $7B, $97, $7B, $97, $7B, $97, $7B, $97, $7B, $97, $7B,
    $97, $7B, $97, $7B, $97, $7B, $77, $73, $77, $73, $77, $73, $77, $73, $77, $73,
    $77, $73, $77, $73, $77, $73, $76, $6B, $76, $6B, $76, $6B, $56, $6B, $56, $6B,
    $56, $6B, $56, $6B, $56, $6B, $56, $63, $56, $63, $56, $63, $35, $63, $35, $63,
    $35, $63, $35, $63, $35, $63, $FF, $FF, $FF, $FF, $01, $08, $00, $08, $00, $00,
    $00, $00, $00, $00, $00, $08, $00, $08, $00, $08, $01, $10, $01, $18, $02, $20,
    $03, $28, $03, $38, $03, $48, $02, $50, $02, $60, $22, $60, $02, $70, $02, $88,
    $02, $A0, $01, $98, $20, $98, $80, $A0, $22, $A9, $83, $A1, $A3, $A1, $04, $A2,
    $65, $AA, $86, $B2, $A6, $BA, $C8, $CA, $C8, $D2, $88, $D2, $68, $CA, $27, $C2,
    $25, $BA, $A4, $A2, $A6, $AB, $88, $B4, $29, $A5, $4A, $AD, $4B, $A5, $4C, $A5,
    $6E, $A5, $B2, $AD, $16, $BE, $5A, $BE, $5D, $B6, $DE, $A5, $5F, $8D, $9E, $8C,
    $1C, $84, $9A, $7B, $39, $73, $F8, $6A, $B8, $6A, $B7, $6A, $97, $6A, $97, $6A,
    $76, $72, $96, $72, $96, $7A, $96, $7A, $B6, $7A, $B5, $82, $B5, $82, $F6, $7A,
    $F6, $7A, $F6, $82, $16, $83, $16, $83, $37, $83, $37, $83, $37, $83, $36, $83,
    $56, $83, $56, $83, $77, $83, $77, $83, $77, $83, $97, $8B, $B7, $83, $B7, $83,
    $B7, $83, $B7, $83, $B7, $83, $B7, $83, $B7, $83, $B7, $83, $B7, $83, $B7, $83,
    $B7, $83, $B7, $83, $B7, $83, $B7, $83, $97, $7B, $97, $7B, $B7, $83, $B7, $83,
    $B7, $83, $B7, $83, $B7, $83, $B7, $83, $97, $7B, $97, $7B, $97, $7B, $97, $7B,
    $97, $7B, $97, $7B, $97, $73, $97, $73, $97, $73, $97, $73, $97, $73, $97, $73,
    $97, $73, $97, $73, $77, $73, $76, $6B, $76, $6B, $76, $6B, $76, $6B, $76, $6B,
    $56, $6B, $56, $6B, $56, $63, $56, $63, $56, $63, $56, $63, $56, $63, $FF, $FF,
    $FF, $FF, $00, $00, $00, $00, $00, $08, $00, $08, $01, $08, $02, $08, $04, $00,
    $06, $00, $09, $00, $0B, $00, $0D, $00, $30, $08, $52, $10, $72, $18, $73, $20,
    $72, $28, $72, $28, $71, $30, $13, $11, $DB, $01, $FD, $01, $76, $09, $67, $58,
    $21, $90, $81, $98, $E2, $98, $84, $99, $C5, $99, $45, $A2, $45, $AA, $66, $B2,
    $87, $BA, $46, $BA, $E6, $A1, $71, $29, $B8, $09, $FD, $01, $DB, $01, $91, $29,
    $68, $B3, $2B, $AC, $AC, $AC, $ED, $A4, $4D, $AD, $8F, $B5, $51, $C6, $F4, $CE,
    $57, $CF, $79, $CF, $1B, $B7, $1E, $A6, $7C, $8D, $FA, $84, $9A, $74, $19, $6C,
    $DA, $6B, $9A, $6B, $18, $63, $18, $6B, $D8, $6A, $B7, $6A, $D6, $72, $B6, $72,
    $D5, $72, $D5, $7A, $F5, $7A, $F6, $7A, $16, $7B, $17, $83, $17, $83, $37, $83,
    $37, $83, $57, $83, $57, $83, $57, $83, $77, $8B, $77, $8B, $77, $8B, $97, $8B,
    $77, $83, $97, $8B, $97, $83, $B7, $83, $B7, $83, $D7, $83, $D7, $83, $D7, $83,
    $B7, $83, $B7, $83, $B7, $83, $B7, $83, $B7, $83, $B7, $83, $B7, $83, $B7, $83,
    $B7, $83, $B7, $83, $B7, $83, $B7, $83, $B7, $7B, $B7, $7B, $B7, $83, $B7, $83,
    $B7, $83, $B7, $83, $B7, $7B, $B7, $7B, $B7, $7B, $97, $7B, $B7, $73, $B7, $73,
    $B7, $73, $B7, $73, $B7, $73, $B8, $73, $B7, $73, $B7, $73, $97, $73, $97, $6B,
    $97, $6B, $97, $6B, $97, $6B, $77, $6B, $97, $6B, $97, $6B, $77, $63, $76, $63,
    $76, $63, $76, $63, $76, $63, $FF, $FF, $FF, $FF, $00, $00, $00, $00, $00, $08,
    $00, $08, $01, $08, $02, $08, $04, $08, $27, $08, $49, $08, $4C, $08, $8F, $10,
    $71, $10, $72, $18, $93, $20, $93, $28, $B3, $30, $B3, $38, $35, $32, $1D, $02,
    $FA, $09, $D9, $32, $9D, $1A, $DB, $01, $86, $58, $20, $90, $20, $88, $A1, $88,
    $43, $91, $E4, $89, $05, $92, $05, $9A, $04, $9A, $6F, $31, $FD, $01, $1D, $02,
    $7A, $22, $B7, $3A, $1C, $33, $FD, $01, $90, $21, $07, $9B, $E9, $A3, $AC, $A4,
    $0D, $AD, $AF, $B5, $71, $C6, $14, $D7, $78, $D7, $DB, $D7, $DE, $CF, $3F, $C7,
    $BF, $B6, $3F, $AE, $9E, $9D, $FC, $8C, $7C, $84, $3C, $84, $FB, $7B, $9A, $7B,
    $5A, $7B, $38, $7B, $17, $7B, $17, $83, $16, $7B, $15, $83, $16, $83, $16, $7B,
    $37, $83, $37, $83, $37, $83, $37, $83, $57, $83, $57, $83, $57, $83, $77, $8B,
    $77, $8B, $97, $8B, $97, $8B, $97, $8B, $97, $8B, $B7, $8B, $B7, $8B, $D7, $83,
    $D7, $83, $D7, $83, $D7, $8B, $D8, $83, $D8, $83, $D8, $83, $D8, $83, $D8, $83,
    $D8, $83, $D7, $83, $D7, $83, $D7, $83, $D7, $83, $D7, $83, $D7, $83, $D7, $83,
    $D7, $83, $D7, $83, $D7, $83, $D8, $83, $D8, $83, $D7, $83, $B7, $83, $B8, $83,
    $B7, $7B, $B8, $7B, $B8, $7B, $B8, $7B, $B8, $7B, $B7, $73, $B7, $73, $B7, $73,
    $B7, $73, $97, $6B, $96, $6B, $96, $73, $96, $73, $97, $6B, $97, $6B, $97, $6B,
    $97, $6B, $97, $6B, $97, $6B, $97, $6B, $77, $63, $97, $63, $97, $63, $FF, $FF,
    $FF, $FF, $00, $00, $00, $00, $00, $00, $01, $00, $04, $08, $08, $08, $0C, $08,
    $30, $08, $72, $10, $94, $10, $D6, $10, $D6, $08, $D6, $08, $D6, $08, $F7, $10,
    $18, $19, $3A, $19, $7B, $43, $DB, $01, $34, $49, $13, $49, $12, $52, $BE, $1A,
    $98, $01, $05, $78, $02, $80, $01, $88, $61, $88, $E2, $88, $22, $89, $83, $89,
    $D2, $21, $1D, $02, $B7, $09, $8B, $51, $44, $89, $23, $91, $A6, $99, $5E, $3B,
    $DB, $01, $66, $A9, $C7, $A1, $AA, $A2, $AB, $AB, $2E, $BD, $71, $CE, $14, $E7,
    $95, $EF, $D7, $FF, $D9, $F7, $FC, $DF, $DD, $D7, $BC, $CF, $3C, $BF, $9B, $A6,
    $FB, $95, $7B, $8D, $1B, $85, $BB, $7C, $7B, $7C, $1A, $7C, $DA, $73, $B9, $73,
    $B9, $73, $98, $73, $98, $73, $57, $7B, $77, $7B, $57, $7B, $57, $7B, $57, $83,
    $77, $83, $77, $83, $77, $83, $78, $8B, $98, $8B, $98, $8B, $98, $8B, $98, $8B,
    $B8, $8B, $B8, $8B, $B8, $8B, $D8, $83, $D8, $8B, $F8, $8B, $F8, $8B, $F8, $8B,
    $F8, $8B, $F8, $8B, $F8, $8B, $18, $8C, $F8, $8B, $F8, $8B, $F7, $83, $F7, $83,
    $F7, $83, $F8, $8B, $F8, $8B, $F8, $83, $F8, $83, $F7, $83, $F7, $83, $F8, $83,
    $D8, $83, $D7, $83, $D7, $83, $D8, $83, $D8, $83, $D7, $7B, $D7, $7B, $D7, $7B,
    $D7, $7B, $D8, $7B, $B7, $7B, $D7, $73, $96, $73, $96, $6B, $96, $6B, $97, $6B,
    $B7, $6B, $96, $73, $B7, $6B, $B7, $6B, $B7, $6B, $B7, $6B, $97, $6B, $97, $63,
    $77, $63, $76, $63, $76, $63, $FF, $FF, $FF, $FF, $20, $00, $20, $00, $00, $08,
    $21, $08, $25, $08, $29, $10, $4D, $10, $71, $10, $B3, $18, $D5, $18, $D6, $10,
    $F6, $10, $17, $11, $37, $11, $38, $19, $39, $19, $5A, $21, $BE, $4B, $DA, $01,
    $75, $49, $54, $51, $10, $61, $39, $4B, $FD, $01, $8A, $48, $23, $88, $01, $88,
    $00, $80, $40, $78, $A0, $70, $F1, $31, $1D, $02, $72, $11, $42, $79, $43, $81,
    $23, $89, $44, $91, $44, $A1, $3C, $3B, $DB, $01, $46, $A1, $46, $99, $C6, $91,
    $C7, $92, $2A, $AC, $AE, $BD, $F2, $D6, $95, $EF, $D7, $FF, $D8, $F7, $FC, $DF,
    $FE, $D7, $FE, $D7, $FF, $CF, $9F, $C7, $3F, $BF, $9F, $AE, $FF, $A5, $9E, $9D,
    $3E, $95, $9C, $94, $5B, $8C, $1A, $7C, $FA, $7B, $B9, $73, $98, $73, $97, $7B,
    $77, $83, $77, $83, $78, $83, $77, $83, $98, $83, $98, $8B, $98, $8B, $98, $8B,
    $98, $8B, $98, $8B, $B8, $8B, $B8, $8B, $B8, $8B, $B8, $8B, $B8, $8B, $F8, $8B,
    $F8, $8B, $F8, $8B, $F8, $8B, $F8, $8B, $F8, $8B, $18, $8C, $18, $8C, $18, $8C,
    $18, $8C, $18, $8C, $F8, $8B, $F8, $8B, $F8, $8B, $18, $8C, $18, $8C, $18, $8C,
    $F8, $8B, $F8, $8B, $F8, $8B, $F8, $8B, $F8, $8B, $F8, $83, $F8, $83, $F8, $83,
    $F8, $83, $F8, $83, $F8, $7B, $F8, $7B, $F8, $7B, $D7, $7B, $B7, $73, $96, $73,
    $95, $6B, $75, $6B, $75, $6B, $76, $6B, $97, $6B, $B7, $6B, $D8, $73, $D8, $73,
    $D8, $73, $96, $6B, $96, $6B, $76, $63, $56, $5B, $56, $63, $76, $63, $FF, $FF,
    $FF, $FF, $01, $00, $01, $00, $26, $00, $0A, $00, $2B, $08, $4E, $08, $71, $10,
    $D2, $18, $F4, $20, $14, $21, $74, $21, $B3, $21, $F4, $29, $15, $2A, $15, $2A,
    $F6, $29, $D7, $29, $7A, $4B, $FD, $01, $95, $31, $97, $39, $96, $49, $95, $52,
    $5D, $12, $32, $19, $28, $68, $D6, $19, $32, $11, $03, $78, $2A, $51, $3D, $0A,
    $52, $11, $C3, $78, $E4, $78, $03, $79, $24, $89, $45, $91, $AA, $71, $7D, $12,
    $96, $09, $48, $99, $48, $99, $68, $99, $88, $A9, $09, $BA, $0B, $CB, $90, $DC,
    $15, $EE, $18, $F7, $9A, $FF, $D8, $FF, $F8, $FF, $F9, $FF, $FA, $EF, $FB, $EF,
    $FC, $DF, $9C, $CF, $3C, $C7, $9C, $B6, $3C, $AE, $9B, $9D, $1A, $95, $DA, $84,
    $79, $7C, $59, $74, $18, $6C, $F8, $7B, $D7, $7B, $F8, $73, $D9, $7B, $D8, $7B,
    $D8, $83, $D8, $83, $D8, $83, $B8, $83, $D8, $83, $D8, $8B, $D9, $8B, $D9, $8B,
    $D9, $8B, $D8, $8B, $B8, $8B, $B7, $8B, $D8, $8B, $F8, $8B, $F8, $8B, $F8, $8B,
    $F8, $8B, $18, $8C, $19, $8C, $18, $8C, $18, $8C, $18, $8C, $18, $8C, $18, $8C,
    $18, $8C, $38, $8C, $38, $8C, $F7, $8B, $F7, $8B, $F7, $8B, $F7, $8B, $F7, $8B,
    $F7, $8B, $F7, $8B, $D8, $8B, $F8, $83, $F8, $83, $F8, $83, $F8, $83, $F8, $83,
    $F7, $83, $F7, $7B, $B6, $7B, $95, $73, $54, $6B, $34, $63, $54, $6B, $75, $6B,
    $75, $73, $B7, $73, $B6, $73, $D8, $73, $B7, $73, $B7, $6B, $76, $6B, $55, $63,
    $54, $63, $35, $5B, $35, $5B, $FF, $FF, $FF, $FF, $01, $08, $22, $08, $06, $00,
    $4A, $00, $8D, $10, $F0, $20, $54, $31, $D5, $39, $17, $42, $38, $4A, $97, $42,
    $B6, $42, $B6, $42, $D7, $4A, $97, $42, $36, $32, $F8, $29, $17, $4B, $1D, $02,
    $75, $09, $B7, $39, $76, $41, $B4, $51, $3E, $3B, $96, $09, $28, $70, $FE, $2A,
    $DB, $01, $25, $68, $3A, $1A, $B9, $01, $82, $78, $C3, $78, $03, $79, $04, $81,
    $24, $89, $29, $59, $3B, $12, $FD, $01, $4B, $61, $48, $99, $48, $99, $68, $99,
    $88, $A9, $C8, $B1, $49, $BA, $2B, $C3, $8F, $D4, $D4, $E5, $D6, $EE, $77, $FF,
    $F8, $FF, $F9, $FF, $FB, $F7, $FC, $EF, $FD, $E7, $FE, $DF, $BF, $D7, $5E, $C7,
    $FD, $C6, $5C, $AE, $9B, $9D, $1B, $95, $BA, $84, $79, $7C, $38, $74, $18, $7C,
    $18, $7C, $18, $84, $19, $84, $F9, $83, $F9, $83, $F9, $83, $F9, $83, $D9, $8B,
    $B9, $8B, $B8, $8B, $B8, $83, $B7, $83, $B7, $83, $97, $83, $B7, $83, $B6, $83,
    $B7, $83, $D8, $83, $D9, $8B, $F9, $8B, $19, $8C, $19, $8C, $19, $8C, $18, $8C,
    $18, $8C, $38, $8C, $38, $94, $17, $94, $17, $8C, $17, $84, $F6, $83, $D6, $83,
    $B6, $83, $B6, $83, $B6, $83, $B6, $83, $D6, $83, $D6, $83, $D7, $83, $F7, $83,
    $F7, $8B, $18, $84, $18, $84, $18, $84, $F7, $83, $D6, $7B, $95, $73, $54, $6B,
    $33, $6B, $33, $63, $33, $6B, $54, $6B, $96, $6B, $B7, $73, $D7, $7B, $D7, $73,
    $97, $6B, $76, $6B, $55, $63, $34, $5B, $14, $5B, $13, $53, $13, $5B, $FF, $FF,
    $FF, $FF, $A6, $18, $C6, $20, $4B, $29, $CD, $39, $6D, $52, $EE, $6A, $8E, $73,
    $D0, $83, $D1, $8B, $B2, $83, $74, $7B, $35, $73, $F7, $6A, $B7, $62, $57, $52,
    $D6, $49, $95, $41, $B4, $41, $5B, $43, $FD, $01, $74, $11, $73, $41, $51, $49,
    $BE, $22, $DA, $01, $11, $21, $7D, $12, $FD, $01, $DB, $01, $FD, $01, $CD, $38,
    $86, $80, $A6, $80, $A6, $88, $EA, $58, $53, $19, $FD, $01, $FD, $01, $6D, $41,
    $87, $99, $88, $91, $89, $99, $4A, $99, $6B, $A1, $AC, $B1, $CC, $B9, $0C, $C2,
    $6E, $D2, $51, $EB, $53, $F4, $95, $F5, $77, $FE, $F9, $FE, $5A, $FF, $BB, $FF,
    $DB, $FF, $FB, $F7, $BB, $E7, $9A, $DF, $3A, $C7, $B9, $BE, $18, $AE, $97, $9D,
    $16, $8D, $D5, $84, $95, $74, $78, $7C, $79, $84, $9A, $84, $9A, $8C, $9A, $8C,
    $9B, $8C, $5A, $8C, $5A, $8C, $19, $8C, $D8, $83, $D7, $83, $B7, $7B, $96, $7B,
    $96, $7B, $96, $7B, $96, $7B, $96, $7B, $B6, $7B, $D7, $8B, $F8, $8B, $F8, $8B,
    $19, $8C, $39, $94, $39, $94, $39, $94, $39, $94, $39, $94, $18, $8C, $17, $8C,
    $16, $8C, $F7, $83, $D6, $83, $B6, $7B, $96, $7B, $95, $7B, $95, $7B, $95, $7B,
    $96, $7B, $B5, $7B, $B5, $7B, $D6, $7B, $F6, $83, $F7, $83, $F7, $8B, $17, $8C,
    $F7, $83, $D6, $73, $94, $6B, $33, $6B, $12, $6B, $12, $63, $33, $6B, $74, $73,
    $B6, $7B, $B7, $7B, $D7, $73, $B7, $73, $96, $73, $55, $6B, $34, $63, $F3, $5A,
    $D2, $5A, $D2, $52, $D2, $52, $FF, $FF, $FF, $FF, $CE, $62, $0F, $6B, $93, $73,
    $16, $84, $D6, $9C, $36, $A5, $56, $B5, $35, $AD, $D4, $A4, $54, $94, $94, $7B,
    $34, $73, $B5, $62, $55, $5A, $15, $4A, $B4, $41, $73, $39, $54, $39, $F6, $31,
    $3A, $43, $1D, $02, $DB, $01, $97, $09, $3D, $0A, $FD, $01, $FD, $01, $3A, $12,
    $55, $3A, $FE, $2A, $FD, $01, $98, $09, $76, $09, $96, $09, $DB, $01, $FD, $01,
    $5D, $12, $D8, $11, $4B, $51, $A8, $99, $C8, $99, $CA, $A1, $CB, $A9, $AC, $A9,
    $8C, $A9, $6B, $B1, $8C, $B1, $EB, $B9, $2C, $CA, $8E, $D2, $4F, $D3, $70, $DC,
    $53, $E5, $16, $F6, $97, $F6, $59, $FF, $BA, $F7, $BB, $EF, $9B, $E7, $39, $D7,
    $DA, $C6, $78, $BE, $F8, $AD, $96, $A5, $56, $95, $16, $8D, $D6, $84, $97, $84,
    $B8, $84, $DA, $8C, $FB, $94, $FC, $94, $DB, $9C, $BB, $9C, $9A, $94, $59, $8C,
    $18, $84, $D7, $83, $96, $7B, $75, $7B, $55, $73, $55, $73, $55, $6B, $74, $7B,
    $95, $7B, $B6, $83, $D7, $8B, $F8, $8B, $18, $94, $39, $94, $59, $94, $59, $94,
    $39, $94, $38, $8C, $17, $8C, $F7, $83, $D6, $83, $B5, $7B, $95, $7B, $74, $7B,
    $74, $73, $74, $73, $54, $73, $54, $73, $54, $73, $73, $73, $74, $73, $95, $7B,
    $B5, $7B, $D6, $83, $F7, $83, $17, $84, $74, $3A, $B6, $11, $13, $5B, $32, $6B,
    $11, $63, $12, $6B, $33, $6B, $74, $73, $B6, $7B, $D7, $7B, $D7, $7B, $B6, $7B,
    $75, $6B, $34, $63, $12, $63, $F2, $5A, $D1, $5A, $B1, $52, $B1, $52, $FF, $FF,
    $FF, $FF, $88, $C5, $88, $C5, $2A, $DE, $4B, $EE, $4C, $F6, $2D, $F6, $EE, $ED,
    $6E, $DD, $AE, $C4, $0E, $AC, $6D, $93, $EE, $7A, $8F, $6A, $50, $5A, $52, $52,
    $32, $4A, $D2, $39, $92, $31, $72, $31, $52, $31, $94, $3A, $D9, $32, $5E, $3B,
    $FE, $2A, $DB, $01, $52, $19, $2F, $51, $2E, $59, $BE, $22, $BA, $01, $5A, $1A,
    $FE, $2A, $FE, $2A, $99, $32, $54, $3A, $CE, $59, $50, $29, $4F, $39, $6A, $79,
    $C9, $A1, $09, $A2, $29, $AA, $2B, $AA, $2B, $AA, $EC, $A9, $CC, $B1, $CC, $B9,
    $ED, $C1, $2E, $D2, $6F, $E2, $B1, $EA, $14, $F3, $F5, $FB, $D6, $FC, $97, $FD,
    $38, $FE, $B7, $F6, $F7, $E6, $D6, $DE, $75, $C6, $14, $BE, $D4, $AD, $94, $A5,
    $74, $A5, $53, $9D, $34, $9D, $34, $95, $76, $8D, $B7, $95, $D9, $9D, $FA, $9D,
    $DB, $95, $7B, $8D, $1A, $8D, $BA, $84, $59, $7C, $F6, $73, $B6, $73, $96, $6B,
    $55, $6B, $34, $63, $34, $63, $53, $6B, $74, $6B, $95, $73, $D6, $7B, $F7, $8B,
    $38, $8C, $3A, $94, $5A, $94, $3A, $94, $38, $8C, $17, $8C, $D6, $83, $D5, $7B,
    $95, $7B, $73, $73, $53, $6B, $53, $6B, $52, $6B, $52, $6B, $52, $6B, $52, $6B,
    $52, $6B, $53, $6B, $53, $6B, $74, $6B, $B4, $73, $D5, $7B, $17, $7C, $D5, $42,
    $1D, $02, $DB, $01, $D3, $52, $32, $63, $12, $63, $33, $6B, $73, $6B, $B5, $73,
    $D6, $7B, $F7, $7B, $F6, $7B, $95, $6B, $54, $63, $32, $63, $12, $5B, $F1, $5A,
    $F1, $5A, $D1, $52, $D0, $52, $FF, $FF, $FF, $FF, $AC, $E6, $AC, $E6, $8C, $EE,
    $8C, $F6, $6D, $EE, $2D, $F6, $CE, $E5, $4E, $DD, $8E, $C4, $0E, $AC, $6E, $93,
    $EE, $7A, $6E, $62, $4F, $5A, $51, $52, $32, $4A, $F2, $41, $D2, $39, $71, $31,
    $50, $29, $4F, $29, $2E, $29, $2E, $31, $7E, $3B, $DA, $01, $2F, $51, $2F, $59,
    $54, $4A, $FD, $01, $0E, $39, $AC, $68, $8A, $70, $6A, $78, $8A, $80, $E8, $88,
    $10, $5A, $1E, $2B, $1D, $02, $FD, $01, $73, $19, $0A, $92, $6A, $B2, $8C, $BA,
    $6D, $BA, $2D, $BA, $ED, $B1, $CC, $B1, $CD, $B9, $ED, $C1, $2E, $D2, $70, $E2,
    $B1, $EA, $52, $F3, $13, $F4, $B3, $EC, $53, $E5, $B4, $DD, $53, $B5, $F3, $4A,
    $34, $1A, $54, $2A, $92, $84, $94, $AD, $74, $A5, $74, $A5, $55, $A5, $75, $95,
    $B6, $9D, $19, $9E, $5B, $AE, $7C, $AE, $5D, $AE, $DC, $9D, $5A, $95, $DA, $8C,
    $57, $84, $F6, $73, $B6, $73, $96, $73, $75, $6B, $74, $6B, $54, $6B, $53, $6B,
    $73, $6B, $74, $73, $D6, $7B, $F7, $8B, $38, $8C, $59, $94, $7A, $94, $39, $8C,
    $18, $8C, $D6, $83, $D5, $7B, $95, $73, $74, $6B, $53, $6B, $53, $6B, $52, $6B,
    $52, $6B, $52, $6B, $32, $6B, $32, $6B, $32, $6B, $52, $6B, $32, $63, $52, $63,
    $53, $6B, $B4, $6B, $75, $63, $9D, $1A, $DB, $01, $D4, $4A, $94, $6B, $32, $63,
    $32, $63, $33, $6B, $74, $73, $D5, $73, $F6, $7B, $F6, $7B, $75, $6B, $F3, $21,
    $B6, $09, $B7, $09, $B3, $11, $D1, $52, $F2, $5A, $F1, $5A, $F1, $5A, $FF, $FF,
    $FF, $FF, $CB, $FD, $CB, $FD, $EB, $F5, $EC, $F5, $CC, $ED, $AC, $F5, $6D, $E5,
    $ED, $D4, $4D, $BC, $CD, $A3, $4D, $93, $CD, $7A, $6D, $6A, $2E, $5A, $2F, $52,
    $51, $52, $51, $4A, $31, $42, $D1, $39, $90, $31, $6F, $29, $4E, $29, $8F, $29,
    $5E, $3B, $96, $01, $6F, $39, $4F, $49, $18, $43, $FD, $01, $EE, $50, $ED, $68,
    $CC, $68, $CB, $68, $EB, $70, $2B, $81, $2A, $89, $AD, $79, $71, $62, $19, $3B,
    $3D, $0A, $DA, $01, $4C, $92, $AB, $CA, $CC, $CA, $AC, $BA, $6D, $B2, $2D, $AA,
    $0D, $B2, $ED, $B9, $0F, $CA, $50, $DA, $91, $EA, $B2, $F2, $13, $FB, $34, $FB,
    $B4, $F3, $33, $52, $DB, $01, $FD, $01, $9D, $1A, $7D, $12, $DB, $01, $B2, $73,
    $53, $B5, $53, $B5, $72, $AD, $73, $AD, $B4, $B5, $36, $C6, $B9, $C6, $FA, $C6,
    $DA, $C6, $5A, $B6, $D8, $A5, $36, $8D, $D5, $84, $74, $7C, $54, $74, $35, $74,
    $34, $74, $14, $6C, $F3, $6B, $94, $6B, $94, $6B, $B4, $6B, $D6, $73, $18, $7C,
    $78, $84, $9A, $8C, $9A, $94, $9A, $8C, $39, $8C, $F7, $83, $B5, $7B, $94, $73,
    $53, $6B, $53, $6B, $52, $6B, $74, $6B, $94, $73, $94, $73, $94, $73, $94, $73,
    $74, $73, $73, $6B, $52, $6B, $52, $6B, $52, $6B, $73, $6B, $17, $4B, $FD, $01,
    $33, $2A, $D4, $73, $93, $6B, $52, $63, $32, $63, $53, $6B, $94, $73, $F6, $73,
    $F7, $7B, $74, $3A, $DB, $01, $FD, $01, $9D, $1A, $FE, $2A, $1D, $02, $DB, $01,
    $B2, $4A, $32, $5B, $11, $5B, $FF, $FF, $FF, $FF, $8A, $F5, $6A, $F5, $8A, $ED,
    $EC, $CC, $52, $32, $DA, $01, $FD, $01, $DA, $01, $11, $32, $AC, $A3, $0D, $8B,
    $CD, $7A, $6D, $6A, $4E, $62, $4E, $52, $30, $4A, $94, $11, $DB, $01, $FD, $01,
    $97, $01, $90, $29, $90, $31, $D0, $31, $FE, $2A, $96, $01, $2F, $39, $2F, $49,
    $5E, $3B, $B8, $01, $EE, $68, $0E, $51, $75, $09, $FD, $01, $DA, $01, $2E, $49,
    $6B, $91, $AB, $A1, $AB, $A9, $EA, $A9, $F3, $6A, $9D, $1A, $DA, $01, $CD, $B2,
    $2D, $D3, $0E, $CB, $CE, $C2, $6E, $B2, $2D, $B2, $0E, $B2, $0F, $C2, $2F, $DA,
    $71, $E2, $91, $EA, $D2, $F2, $F2, $EA, $73, $62, $1D, $02, $DA, $01, $91, $6A,
    $8F, $AB, $92, $83, $BE, $1A, $D7, $09, $12, $B5, $32, $AD, $52, $AD, $52, $AD,
    $B4, $B5, $36, $C6, $B9, $CE, $FA, $C6, $FA, $BE, $37, $8D, $75, $22, $D8, $09,
    $FD, $01, $FD, $01, $D8, $09, $D4, $42, $F7, $8C, $B7, $84, $76, $7C, $F6, $7B,
    $D5, $73, $D5, $6B, $F6, $73, $38, $84, $79, $8C, $BA, $94, $DB, $94, $BB, $94,
    $F8, $7B, $54, $32, $B6, $11, $DA, $01, $FD, $01, $FD, $01, $DB, $01, $D8, $09,
    $D5, $19, $74, $3A, $F6, $83, $F6, $83, $D5, $83, $B5, $73, $94, $73, $73, $6B,
    $52, $6B, $53, $6B, $7B, $4B, $FD, $01, $B5, $73, $B4, $6B, $93, $6B, $53, $63,
    $32, $63, $52, $6B, $74, $6B, $B5, $73, $F4, $4A, $3D, $0A, $DA, $01, $93, $3A,
    $12, $5B, $32, $5B, $56, $53, $5D, $12, $B6, $09, $52, $63, $32, $5B, $FF, $FF,
    $FF, $FF, $29, $FD, $09, $FD, $8B, $DC, $9A, $22, $FD, $01, $5A, $1A, $D7, $3A,
    $FC, $32, $FD, $01, $B6, $09, $EB, $8A, $CC, $7A, $8C, $72, $6D, $6A, $4E, $52,
    $1A, $12, $FD, $01, $3A, $12, $F9, $32, $5D, $12, $DB, $01, $F1, $39, $12, $32,
    $9D, $1A, $74, $09, $6F, $21, $F0, $39, $DE, $22, $54, $09, $0E, $41, $1C, $0A,
    $1D, $02, $79, $22, $9D, $1A, $FD, $01, $8F, $69, $F0, $99, $2F, $A2, $0E, $A2,
    $0C, $AA, $14, $6B, $3D, $0A, $B5, $19, $8E, $DB, $AF, $DB, $8E, $CB, $2D, $B3,
    $CD, $AA, $8D, $AA, $8E, $BA, $70, $D2, $91, $DA, $92, $EA, $B4, $EA, $73, $AA,
    $5D, $12, $DA, $01, $51, $AA, $71, $B2, $90, $AA, $F1, $AA, $7B, $4B, $FD, $01,
    $12, $B4, $52, $B4, $92, $B4, $D3, $B4, $54, $BD, $D6, $CD, $77, $D6, $D6, $BD,
    $55, $22, $FD, $01, $1D, $02, $9C, $22, $F8, $32, $18, $3B, $DE, $22, $FD, $01,
    $F5, $42, $7A, $A5, $18, $95, $B7, $84, $55, $7C, $14, $74, $15, $74, $77, $7C,
    $B8, $8C, $FA, $94, $99, $84, $35, $22, $FD, $01, $FD, $01, $7D, $12, $DC, $2A,
    $D8, $32, $D8, $32, $D9, $32, $FC, $2A, $BE, $22, $FD, $01, $DA, $01, $94, $42,
    $57, $8C, $36, $7C, $D5, $7B, $B4, $73, $93, $6B, $72, $6B, $BE, $4B, $DA, $01,
    $93, $73, $93, $73, $93, $73, $73, $63, $52, $63, $73, $63, $73, $6B, $73, $63,
    $7C, $1A, $B8, $01, $33, $5B, $52, $63, $32, $5B, $32, $63, $53, $5B, $5C, $43,
    $DB, $01, $73, $5B, $52, $5B, $FF, $FF, $FF, $FF, $09, $FD, $E8, $F4, $EE, $9B,
    $5C, $3B, $D0, $5A, $89, $CC, $29, $C4, $C9, $AB, $57, $53, $FD, $01, $D1, $21,
    $AC, $7A, $8D, $72, $8E, $6A, $B6, $32, $FD, $01, $B3, $11, $B0, $52, $71, $52,
    $16, $4B, $FD, $01, $D3, $21, $B5, $42, $1D, $0A, $93, $11, $B0, $29, $32, $3A,
    $5D, $12, $31, $11, $BA, $01, $FD, $01, $0E, $31, $0D, $59, $93, $52, $1D, $02,
    $73, $21, $F1, $A1, $70, $B2, $4F, $B2, $4D, $B2, $4C, $B2, $7A, $4B, $FD, $01,
    $6F, $7A, $CF, $DB, $AF, $D3, $6F, $C3, $0D, $B3, $AD, $B2, $AE, $BA, $B1, $CA,
    $D2, $DA, $D3, $EA, $D3, $F2, $99, $2A, $FD, $01, $D1, $81, $30, $B2, $2F, $AA,
    $2F, $A2, $8F, $A2, $5C, $3B, $DB, $01, $90, $A3, $D0, $AB, $31, $AC, $92, $B4,
    $34, $BD, $B6, $D5, $75, $B5, $1A, $12, $FD, $01, $17, $12, $F2, $6B, $B3, $AD,
    $15, $AE, $78, $BE, $F9, $AD, $1C, $33, $FB, $01, $BB, $AD, $FB, $B5, $79, $9D,
    $D7, $8C, $76, $84, $76, $7C, $98, $8C, $F9, $8C, $38, $74, $FA, $09, $FD, $01,
    $1A, $0A, $F6, $42, $37, $7C, $78, $84, $98, $8C, $99, $8C, $99, $8C, $B9, $9C,
    $18, $7C, $58, $4B, $FE, $2A, $FD, $01, $15, $22, $79, $94, $57, $8C, $15, $84,
    $B4, $7B, $93, $73, $9C, $4B, $DB, $01, $93, $6B, $B4, $73, $B4, $73, $93, $6B,
    $73, $6B, $52, $63, $73, $63, $F6, $3A, $FD, $01, $D2, $4A, $52, $5B, $12, $5B,
    $11, $5B, $31, $5B, $32, $63, $7B, $43, $FD, $01, $52, $5B, $52, $5B, $FF, $FF,
    $FF, $FF, $C9, $EC, $A8, $EC, $6A, $EC, $6A, $EC, $4A, $D4, $29, $C4, $09, $B4,
    $A9, $9B, $4C, $83, $1E, $33, $B6, $09, $8B, $72, $8C, $72, $B0, $5A, $BE, $22,
    $B8, $01, $AF, $62, $D0, $5A, $AF, $52, $D1, $5A, $93, $42, $13, $63, $16, $4B,
    $FD, $01, $D2, $21, $31, $3A, $B4, $42, $3D, $0A, $B8, $01, $FD, $01, $30, $19,
    $0C, $49, $2D, $51, $CF, $59, $3E, $3B, $97, $09, $B2, $91, $33, $A2, $73, $AA,
    $51, $AA, $71, $B2, $14, $8B, $BE, $22, $B7, $11, $B0, $E3, $D0, $DB, $CF, $CB,
    $AE, $B3, $6D, $AB, $8E, $AB, $51, $CB, $92, $D3, $72, $E3, $F5, $72, $3D, $0A,
    $B4, $21, $71, $B2, $2F, $A2, $0E, $9A, $0E, $92, $70, $7A, $9D, $1A, $B6, $09,
    $EF, $B2, $30, $B3, $70, $BB, $F2, $C3, $54, $CC, $75, $BC, $3A, $1A, $FD, $01,
    $73, $3A, $13, $B5, $33, $B5, $74, $BD, $F6, $CD, $97, $DE, $1A, $E7, $58, $74,
    $FD, $01, $76, $53, $DA, $CE, $19, $B6, $77, $A5, $F5, $94, $F5, $8C, $37, $95,
    $F7, $8C, $DB, $2A, $FD, $01, $56, $22, $9C, $9D, $3B, $9D, $3B, $95, $1A, $8D,
    $FA, $94, $FA, $94, $FB, $94, $1B, $9D, $3C, $9D, $1C, $9D, $99, $84, $5B, $43,
    $FD, $01, $35, $22, $D9, $8C, $78, $84, $16, $7C, $B4, $6B, $79, $4B, $FD, $01,
    $F2, $52, $D4, $73, $D4, $7B, $D5, $73, $93, $6B, $73, $6B, $52, $63, $BE, $22,
    $D3, $19, $32, $5B, $11, $5B, $F0, $5A, $D0, $5A, $10, $53, $11, $53, $DE, $22,
    $B8, $01, $32, $5B, $32, $5B, $FF, $FF, $FF, $FF, $A9, $EC, $88, $E4, $49, $E4,
    $29, $DC, $E9, $CB, $E8, $B3, $C8, $A3, $68, $93, $08, $83, $9E, $43, $DA, $01,
    $8B, $72, $8C, $72, $F4, $4A, $FD, $01, $D1, $29, $F0, $6A, $11, $63, $F0, $5A,
    $12, $63, $13, $6B, $14, $6B, $3A, $43, $FD, $01, $72, $3A, $71, $3A, $16, $43,
    $5D, $12, $FD, $01, $B8, $01, $0D, $41, $EC, $48, $2D, $51, $2E, $61, $9E, $43,
    $DA, $01, $72, $91, $B1, $91, $12, $9A, $51, $AA, $71, $B2, $91, $C2, $7B, $4B,
    $FD, $01, $70, $C3, $D0, $D3, $CF, $C3, $AE, $B3, $8E, $AB, $AE, $B3, $91, $C3,
    $B3, $D3, $D3, $DB, $F9, $3A, $FD, $01, $71, $92, $70, $AA, $2E, $9A, $ED, $91,
    $ED, $91, $77, $2A, $FD, $01, $D0, $49, $EF, $AA, $10, $BB, $71, $C3, $D2, $CB,
    $33, $CC, $98, $2A, $FD, $01, $33, $3A, $71, $B4, $91, $AC, $F2, $B4, $74, $BD,
    $F6, $CD, $B8, $DE, $3A, $E7, $F9, $B5, $FE, $2A, $37, $1A, $FB, $D6, $7A, $BE,
    $D8, $AD, $56, $9D, $36, $9D, $98, $A5, $D7, $84, $7E, $43, $D6, $3A, $1E, $AE,
    $FD, $AD, $BD, $A5, $9D, $9D, $7C, $9D, $5C, $9D, $5C, $A5, $5D, $A5, $5C, $9D,
    $3C, $9D, $3C, $9D, $1C, $9D, $FB, $94, $5B, $43, $FD, $01, $36, $53, $BA, $8C,
    $57, $84, $F5, $7B, $96, $5B, $3D, $0A, $F3, $21, $D4, $73, $F4, $7B, $F6, $73,
    $D5, $73, $B4, $6B, $15, $4B, $FD, $01, $B1, $4A, $F0, $5A, $CF, $52, $AF, $52,
    $AF, $52, $F0, $52, $95, $32, $FD, $01, $D3, $19, $32, $5B, $52, $63, $FF, $FF,
    $FF, $FF, $69, $E4, $49, $E4, $29, $DC, $29, $D4, $8D, $52, $B6, $09, $DB, $01,
    $B4, $11, $08, $73, $5E, $3B, $B8, $01, $AA, $72, $CC, $7A, $58, $4B, $FD, $01,
    $70, $4A, $30, $73, $30, $73, $31, $6B, $11, $63, $32, $63, $33, $5B, $FE, $2A,
    $DA, $01, $F3, $52, $B2, $4A, $17, $4B, $3D, $0A, $FD, $01, $71, $19, $AE, $39,
    $6D, $41, $6E, $49, $70, $59, $BE, $4B, $DA, $01, $73, $79, $72, $89, $73, $89,
    $D3, $91, $34, $A2, $95, $BA, $58, $63, $FD, $01, $13, $6A, $54, $E3, $32, $CB,
    $51, $BB, $50, $B3, $90, $AB, $EF, $BB, $11, $C4, $B2, $93, $BE, $1A, $B6, $19,
    $50, $AB, $CF, $9A, $6E, $8A, $4D, $8A, $F3, $29, $1D, $0A, $B7, $09, $B2, $A2,
    $13, $B3, $55, $BB, $76, $CB, $B6, $DB, $F6, $62, $1D, $0A, $B6, $19, $93, $C3,
    $92, $B3, $B2, $B3, $33, $BC, $B4, $CC, $56, $DD, $F8, $ED, $98, $F6, $D9, $F6,
    $9E, $43, $F8, $09, $96, $DE, $16, $CE, $B5, $B5, $53, $AD, $54, $AD, $B6, $B5,
    $38, $BE, $D9, $B5, $BC, $CE, $BD, $C6, $5D, $BE, $3C, $B6, $FC, $B5, $DC, $AD,
    $BC, $A5, $9C, $AD, $9C, $AD, $9D, $A5, $9D, $9D, $7C, $9D, $7C, $9D, $5C, $95,
    $BA, $7C, $DE, $22, $D8, $09, $FA, $94, $98, $8C, $37, $7C, $D5, $6B, $5C, $3B,
    $DB, $01, $34, $5B, $16, $7C, $16, $84, $36, $84, $16, $7C, $39, $4B, $B8, $01,
    $11, $63, $F0, $5A, $AE, $52, $AE, $52, $AE, $52, $51, $3A, $5D, $12, $DB, $01,
    $F1, $52, $73, $63, $94, $6B, $FF, $FF, $FF, $FF, $69, $E4, $49, $E4, $49, $DC,
    $52, $3A, $FD, $01, $1D, $02, $38, $1A, $EF, $31, $CC, $5A, $BE, $22, $95, $11,
    $CA, $7A, $EC, $7A, $7A, $4B, $FD, $01, $71, $8B, $92, $83, $92, $7B, $72, $73,
    $52, $6B, $52, $6B, $14, $4B, $3D, $0A, $B5, $11, $13, $53, $F2, $52, $59, $4B,
    $1D, $0A, $DB, $01, $51, $42, $F0, $49, $CF, $49, $AF, $51, $B0, $61, $7E, $43,
    $B8, $09, $93, $81, $52, $81, $51, $81, $71, $89, $F3, $99, $75, $B2, $16, $8B,
    $5D, $12, $B4, $31, $13, $DB, $11, $CB, $10, $B3, $0F, $A3, $4E, $A3, $CF, $AB,
    $11, $B4, $36, $5B, $FD, $01, $52, $52, $70, $A3, $EF, $92, $4F, $6A, $B7, $11,
    $FD, $01, $B7, $09, $B2, $92, $34, $BB, $76, $C3, $B7, $D3, $F8, $DB, $D7, $D3,
    $BC, $22, $DB, $01, $53, $AB, $52, $BB, $51, $B3, $92, $B3, $F2, $BB, $73, $CC,
    $F5, $DC, $96, $ED, $F6, $ED, $36, $EE, $9C, $4B, $DA, $01, $D4, $C5, $94, $B5,
    $33, $A5, $F2, $A4, $13, $A5, $B6, $B5, $38, $C6, $9B, $CE, $1E, $D7, $1E, $DF,
    $FE, $D6, $DE, $C6, $7E, $BE, $1D, $B6, $DC, $AD, $9C, $AD, $7B, $A5, $9D, $9D,
    $9C, $9D, $7D, $9D, $9D, $9D, $9D, $9D, $7C, $9D, $9A, $53, $FD, $01, $36, $53,
    $B9, $8C, $57, $84, $F5, $73, $95, $63, $BE, $1A, $DA, $01, $35, $5B, $77, $84,
    $78, $8C, $77, $8C, $FE, $2A, $13, $22, $52, $6B, $11, $5B, $AF, $52, $AF, $52,
    $D2, $19, $1D, $02, $FD, $01, $72, $3A, $B4, $6B, $D5, $73, $16, $7C, $FF, $FF,
    $FF, $FF, $69, $DC, $69, $DC, $31, $6B, $3D, $0A, $DA, $01, $0C, $73, $C9, $9B,
    $69, $8B, $F2, $52, $FD, $01, $D0, $21, $0A, $83, $2C, $8B, $9B, $4B, $FD, $01,
    $D2, $9B, $F2, $A3, $F3, $93, $B3, $8B, $72, $7B, $72, $73, $F9, $32, $FD, $01,
    $92, $3A, $33, $53, $53, $5B, $59, $4B, $FD, $01, $B5, $09, $D3, $4A, $B3, $42,
    $72, $3A, $73, $42, $94, $4A, $1E, $33, $B7, $09, $15, $7A, $B3, $79, $52, $81,
    $52, $81, $94, $99, $16, $B2, $D7, $9A, $3E, $33, $B7, $11, $B6, $D2, $94, $C2,
    $72, $B2, $71, $A2, $B1, $9A, $4F, $9B, $D0, $A3, $5B, $43, $FD, $01, $AF, $93,
    $8D, $83, $F1, $29, $FD, $01, $1D, $02, $B5, $11, $B0, $93, $52, $B4, $75, $BC,
    $97, $C4, $B9, $CC, $DA, $D4, $57, $63, $FD, $01, $54, $4A, $17, $BC, $B4, $B3,
    $73, $AB, $93, $B3, $B4, $C3, $16, $DC, $76, $EC, $B7, $F4, $F7, $EC, $F6, $EC,
    $9B, $4B, $FD, $01, $94, $BC, $91, $B4, $50, $A4, $4F, $9C, $70, $A4, $13, $B5,
    $95, $C5, $58, $DE, $DA, $EE, $1C, $EF, $FC, $E6, $DC, $DE, $9B, $D6, $3B, $C6,
    $FA, $BD, $BA, $B5, $9A, $AD, $99, $AD, $BA, $AD, $BB, $A5, $BB, $AD, $DC, $AD,
    $BC, $A5, $59, $74, $5D, $12, $35, $22, $D9, $94, $77, $8C, $15, $7C, $D4, $73,
    $75, $5B, $DE, $22, $FD, $01, $D7, $09, $B5, $42, $D5, $4A, $FD, $01, $B3, $42,
    $33, $63, $51, $3A, $D2, $19, $DA, $01, $FD, $01, $DB, $01, $32, $32, $B4, $73,
    $F5, $7B, $16, $7C, $57, $84, $FF, $FF, $FF, $FF, $8A, $E4, $89, $E4, $59, $4B,
    $FD, $01, $2C, $83, $4A, $B4, $E9, $A3, $A9, $93, $D9, $32, $FD, $01, $AB, $62,
    $4B, $93, $8D, $93, $7A, $4B, $FD, $01, $F3, $9B, $74, $B4, $55, $AC, $15, $9C,
    $D4, $8B, $33, $5B, $7D, $12, $B8, $01, $73, $63, $74, $5B, $75, $63, $7B, $4B,
    $FD, $01, $54, $2A, $76, $5B, $35, $53, $D4, $4A, $D4, $4A, $D5, $52, $9D, $1A,
    $B5, $11, $77, $82, $36, $92, $F5, $91, $B4, $91, $D5, $A1, $16, $B2, $98, $CA,
    $9E, $43, $B8, $09, $B5, $D2, $73, $BA, $51, $AA, $50, $9A, $8F, $92, $2E, $93,
    $8F, $8B, $DE, $22, $DA, $01, $F4, $19, $DB, $01, $1D, $02, $1A, $12, $D1, $52,
    $B1, $B4, $14, $C5, $36, $D5, $59, $DD, $5A, $E5, $5B, $E5, $5D, $ED, $1C, $33,
    $DB, $01, $9A, $DC, $37, $CC, $F5, $BB, $B4, $B3, $D4, $BB, $15, $CC, $36, $DC,
    $56, $EC, $77, $EC, $75, $E4, $54, $D4, $9B, $4B, $FD, $01, $D0, $AB, $EE, $9B,
    $CD, $93, $AD, $93, $EF, $93, $91, $AC, $33, $BD, $D6, $CD, $59, $DE, $9A, $DE,
    $BA, $D6, $7B, $D6, $5B, $CE, $1A, $BE, $D9, $B5, $B9, $B5, $B9, $AD, $DA, $AD,
    $DB, $AD, $DB, $AD, $DC, $AD, $DC, $B5, $DD, $AD, $3A, $95, $5E, $3B, $D7, $09,
    $FA, $94, $98, $84, $36, $7C, $D5, $7B, $D5, $73, $D5, $6B, $39, $43, $DE, $22,
    $3D, $0A, $3D, $0A, $FD, $01, $FD, $01, $FD, $01, $FD, $01, $1D, $02, $7D, $12,
    $36, $22, $B1, $4A, $93, $6B, $D4, $73, $16, $7C, $57, $84, $99, $8C, $FF, $FF,
    $FF, $FF, $CA, $E4, $AA, $E4, $BE, $4B, $DA, $01, $89, $D4, $6A, $CC, $29, $BC,
    $D0, $52, $3D, $0A, $B5, $11, $89, $9B, $AB, $A3, $0C, $B4, $98, $5B, $FD, $01,
    $B2, $5A, $B3, $CC, $93, $C4, $74, $BC, $F3, $93, $7A, $1A, $FD, $01, $92, $4A,
    $D4, $7B, $D4, $7B, $F6, $73, $9B, $4B, $FD, $01, $D7, $63, $39, $6C, $D8, $5B,
    $96, $53, $B7, $4B, $56, $4B, $1D, $0A, $15, $22, $79, $73, $38, $8B, $17, $93,
    $B6, $A2, $76, $AA, $B6, $BA, $D7, $C2, $BE, $4B, $DA, $01, $14, $B3, $F0, $A2,
    $CE, $92, $AE, $8A, $CD, $82, $EE, $6A, $35, $22, $3D, $0A, $FD, $01, $FD, $01,
    $58, $1A, $D0, $42, $CA, $9C, $4B, $AD, $CC, $BD, $2E, $CE, $6F, $DE, $B0, $E6,
    $B1, $E6, $B2, $EE, $D4, $9C, $9D, $1A, $74, $32, $73, $BD, $D3, $B4, $72, $A4,
    $53, $A4, $75, $B4, $B7, $C4, $98, $D4, $B9, $E4, $99, $E4, $56, $DC, $F4, $D3,
    $9B, $4B, $FD, $01, $0E, $A3, $0D, $93, $ED, $8A, $0D, $8B, $4D, $8B, $CF, $9B,
    $71, $B4, $13, $C5, $B6, $D5, $D6, $DD, $16, $D6, $D6, $CD, $B5, $C5, $75, $BD,
    $54, $B5, $34, $B5, $55, $B5, $76, $B5, $B8, $BD, $D8, $BD, $FA, $C5, $FB, $C5,
    $1B, $BE, $FC, $BD, $9E, $43, $DA, $01, $F8, $9C, $97, $8C, $35, $84, $14, $7C,
    $14, $7C, $76, $8C, $B8, $94, $57, $84, $B7, $63, $1B, $33, $FD, $01, $DA, $01,
    $58, $22, $96, $32, $72, $3A, $D0, $5A, $11, $63, $51, $6B, $93, $6B, $D4, $7B,
    $16, $84, $77, $8C, $98, $8C, $FF, $FF, $FF, $FF, $EA, $EC, $CA, $E4, $9C, $4B,
    $DB, $01, $CB, $DC, $AA, $D4, $AF, $62, $3D, $0A, $DB, $01, $6C, $8B, $2B, $B4,
    $4C, $BC, $6E, $CC, $13, $8C, $DE, $22, $DA, $01, $94, $BC, $F5, $D4, $55, $AC,
    $37, $1A, $FD, $01, $F5, $19, $76, $94, $76, $94, $78, $8C, $99, $8C, $9C, $4B,
    $DB, $01, $BB, $84, $9B, $7C, $7B, $74, $5A, $6C, $3A, $64, $58, $4B, $FD, $01,
    $76, $32, $1B, $84, $DB, $9B, $9A, $AB, $59, $BB, $18, $C3, $38, $CB, $17, $CB,
    $9E, $43, $DA, $01, $33, $B3, $11, $9B, $AF, $7A, $F1, $31, $B6, $09, $FD, $01,
    $3D, $0A, $FD, $01, $D7, $11, $70, $63, $2D, $AD, $EB, $A4, $0B, $A5, $8B, $B5,
    $0C, $C6, $4E, $CE, $6F, $DE, $70, $DE, $71, $DE, $92, $DE, $D6, $63, $FD, $01,
    $D4, $73, $D5, $CD, $55, $C5, $D4, $B4, $B4, $B4, $B6, $BC, $F8, $D4, $FA, $DC,
    $1A, $E5, $D9, $E4, $56, $DC, $F4, $CB, $DE, $22, $DA, $01, $EE, $9A, $ED, $8A,
    $CC, $82, $CC, $82, $0D, $8B, $6E, $93, $EF, $A3, $71, $B4, $F2, $C4, $54, $CD,
    $54, $C5, $54, $BD, $33, $B5, $13, $AD, $F3, $A4, $D3, $A4, $14, $AD, $35, $AD,
    $77, $B5, $B8, $BD, $1A, $C6, $7C, $CE, $9D, $CE, $7D, $CE, $9E, $43, $DA, $01,
    $39, $A5, $B7, $8C, $34, $84, $F4, $7B, $35, $7C, $76, $8C, $D8, $94, $F9, $9C,
    $3A, $A5, $79, $4B, $FD, $01, $D3, $4A, $F4, $7B, $72, $6B, $10, $63, $10, $63,
    $31, $63, $52, $6B, $93, $6B, $D4, $73, $15, $7C, $36, $84, $97, $94, $FF, $FF,
    $FF, $FF, $0A, $F5, $EA, $F4, $D6, $6B, $1D, $02, $DA, $09, $D8, $09, $FD, $01,
    $DB, $01, $EE, $72, $8B, $D4, $AB, $D4, $AC, $DC, $ED, $DC, $2F, $E5, $B9, $5B,
    $1D, $0A, $DB, $01, $D7, $11, $DB, $01, $1D, $02, $D6, $19, $B5, $D4, $B7, $CC,
    $B8, $C4, $D8, $BC, $1A, $AD, $BE, $4B, $DA, $01, $3B, $8D, $1C, $8D, $1C, $85,
    $FC, $7C, $FC, $6C, $7A, $4B, $FD, $01, $98, $43, $FD, $74, $DB, $8C, $9B, $9C,
    $59, $B4, $39, $CC, $D8, $D3, $76, $B3, $5E, $3B, $B8, $09, $B0, $6A, $D4, $19,
    $DB, $01, $FD, $01, $7D, $12, $18, $3B, $FB, $32, $FD, $01, $0F, $7C, $6E, $BD,
    $2D, $B5, $AC, $AC, $8C, $AC, $8C, $B4, $CC, $C4, $0D, $CD, $4C, $CD, $6C, $CD,
    $8C, $CD, $AC, $CD, $98, $53, $FD, $01, $6E, $B5, $0E, $CE, $CE, $BD, $6F, $B5,
    $50, $B5, $91, $BD, $D3, $C5, $F4, $D5, $F7, $D5, $34, $63, $15, $22, $D7, $11,
    $3D, $0A, $D8, $09, $50, $9B, $EF, $9A, $CE, $92, $AD, $8A, $CD, $8A, $0E, $9B,
    $6E, $A3, $AF, $AB, $0F, $B4, $70, $BC, $90, $B4, $8F, $B4, $70, $AC, $90, $AC,
    $B0, $AC, $B1, $AC, $D1, $AC, $D2, $AC, $13, $B5, $55, $BD, $D7, $CD, $5A, $DE,
    $BB, $DE, $1B, $CE, $5E, $3B, $D8, $09, $78, $AD, $D6, $94, $54, $84, $34, $84,
    $75, $84, $B6, $94, $F7, $94, $19, $9D, $19, $9D, $7A, $4B, $FD, $01, $54, $5B,
    $B3, $6B, $51, $63, $0F, $5B, $0F, $5B, $30, $63, $51, $6B, $92, $6B, $B3, $6B,
    $D3, $73, $F5, $7B, $36, $84, $FF, $FF, $FF, $FF, $2B, $F5, $0A, $F5, $CC, $DC,
    $76, $63, $FC, $32, $DC, $2A, $76, $32, $ED, $B3, $EC, $EC, $EC, $E4, $ED, $E4,
    $2D, $E5, $4E, $ED, $71, $ED, $32, $E5, $96, $6B, $FB, $32, $FE, $2A, $B9, $2A,
    $14, $5B, $56, $E5, $37, $E5, $39, $E5, $3A, $DD, $5A, $D5, $7C, $BD, $BA, $53,
    $16, $1A, $7D, $A5, $7D, $9D, $7E, $95, $5E, $8D, $5E, $85, $B9, $53, $D9, $09,
    $3E, $7D, $3E, $85, $3D, $95, $FC, $AC, $DB, $C4, $7A, $CC, $D7, $CB, $15, $8B,
    $9D, $1A, $FD, $01, $FD, $01, $5D, $12, $99, $22, $B3, $3A, $CF, $94, $AE, $B5,
    $78, $4B, $FD, $01, $4F, $B5, $6E, $C5, $CC, $BC, $0A, $A4, $A9, $9B, $A9, $A3,
    $E9, $AB, $09, $B4, $29, $B4, $69, $B4, $69, $AC, $A9, $AC, $9B, $4B, $DA, $01,
    $4B, $BD, $4C, $B5, $4D, $B5, $2D, $AD, $4F, $AD, $91, $BD, $14, $CE, $F4, $73,
    $FB, $01, $FD, $01, $5D, $12, $DE, $22, $5D, $12, $FD, $01, $B7, $09, $51, $5A,
    $10, $9B, $EE, $92, $EE, $92, $0D, $93, $4E, $9B, $2E, $8B, $12, $32, $B6, $09,
    $D6, $09, $12, $32, $CF, $93, $70, $AC, $B0, $AC, $B0, $AC, $D1, $AC, $D3, $AC,
    $D3, $B4, $13, $B5, $76, $BD, $19, $D6, $7A, $DE, $59, $A5, $DE, $22, $F7, $19,
    $99, $B5, $F7, $9C, $95, $94, $95, $94, $D7, $94, $F7, $9C, $18, $9D, $F9, $94,
    $F8, $94, $9C, $4B, $FD, $01, $72, $63, $51, $6B, $30, $63, $0F, $63, $10, $63,
    $51, $63, $72, $6B, $92, $6B, $93, $73, $B3, $6B, $D3, $73, $F4, $7B, $FF, $FF,
    $FF, $FF, $69, $F5, $49, $F5, $2A, $FD, $2A, $FD, $2B, $FD, $4B, $FD, $4C, $FD,
    $4C, $FD, $2C, $F5, $2D, $ED, $4D, $ED, $6E, $ED, $6F, $FD, $90, $F5, $92, $FD,
    $B3, $FD, $B4, $FD, $D4, $FD, $D4, $FD, $D4, $F5, $D5, $ED, $D6, $ED, $B6, $ED,
    $B6, $ED, $B8, $ED, $D9, $ED, $BA, $ED, $BB, $E5, $9C, $DD, $9D, $D5, $9D, $CD,
    $7D, $C5, $5D, $C5, $5D, $BD, $7F, $B5, $5E, $AD, $5D, $A5, $7B, $AD, $5B, $B5,
    $38, $C5, $36, $B4, $34, $3A, $1C, $0A, $1D, $02, $DB, $01, $12, $22, $CC, $6B,
    $8B, $94, $0C, $A5, $6D, $B5, $D0, $CD, $9B, $4B, $FD, $01, $0D, $DD, $2C, $D4,
    $C9, $C3, $28, $B3, $07, $AB, $07, $A3, $26, $A3, $46, $A3, $66, $AB, $66, $AB,
    $66, $AB, $86, $AB, $BE, $4B, $DA, $01, $87, $BC, $A8, $BC, $A8, $BC, $88, $B4,
    $C9, $B4, $0A, $B5, $F0, $7B, $5D, $12, $FD, $01, $D4, $3A, $32, $A5, $34, $74,
    $3D, $0A, $14, $22, $34, $22, $FD, $01, $12, $32, $6E, $9B, $4E, $9B, $2E, $9B,
    $EE, $92, $18, $1A, $FD, $01, $3D, $0A, $DE, $22, $FD, $01, $DB, $01, $B0, $62,
    $30, $B4, $50, $B4, $90, $B4, $90, $B4, $90, $B4, $B1, $B4, $13, $BD, $95, $CD,
    $17, $DE, $36, $7C, $1D, $02, $55, $32, $35, $BD, $F4, $B4, $B3, $A4, $B5, $AC,
    $F6, $B4, $F7, $B4, $F7, $B4, $D8, $AC, $97, $9C, $3E, $33, $FD, $01, $71, $73,
    $30, $6B, $0F, $63, $2F, $63, $51, $6B, $B2, $6B, $D3, $7B, $F4, $7B, $F4, $7B,
    $D3, $73, $D3, $73, $14, $7C, $FF, $FF, $FF, $FF, $89, $FD, $69, $F5, $2A, $FD,
    $2A, $FD, $2A, $FD, $4B, $FD, $4C, $FD, $4C, $FD, $6D, $FD, $6D, $FD, $6E, $FD,
    $8F, $FD, $8F, $FD, $B0, $FD, $B2, $FD, $B3, $FD, $B4, $FD, $D4, $FD, $D4, $FD,
    $F5, $FD, $F5, $FD, $F6, $F5, $F7, $F5, $F8, $F5, $F9, $F5, $FA, $F5, $1C, $F6,
    $3D, $F6, $1E, $EE, $1F, $E6, $1F, $E6, $1F, $DE, $1F, $D6, $1F, $CE, $1F, $C6,
    $1F, $C6, $3F, $C6, $3F, $C6, $DC, $CD, $15, $5B, $DA, $01, $3D, $0A, $5D, $12,
    $FD, $01, $32, $2A, $6C, $94, $AB, $94, $EC, $94, $2C, $AD, $8D, $BD, $AE, $CD,
    $9C, $4B, $DA, $01, $AC, $DC, $0A, $D4, $89, $C3, $08, $AB, $C6, $A2, $E6, $A2,
    $E6, $92, $E5, $92, $05, $9B, $05, $9B, $04, $9B, $05, $A3, $BE, $4B, $DB, $01,
    $04, $B4, $26, $B4, $47, $AC, $47, $AC, $48, $AC, $88, $AC, $58, $4B, $FD, $01,
    $AF, $6B, $50, $DE, $B1, $DE, $D6, $63, $FD, $01, $12, $4B, $B2, $CD, $B5, $6B,
    $FD, $01, $B0, $5A, $AF, $A3, $6F, $A3, $F4, $5A, $3D, $0A, $B5, $11, $F0, $92,
    $10, $93, $55, $5B, $BE, $22, $FD, $01, $10, $73, $50, $B4, $50, $B4, $6F, $B4,
    $4F, $AC, $50, $AC, $B1, $B4, $33, $C5, $95, $D5, $58, $53, $FD, $01, $73, $6B,
    $14, $B5, $D4, $AC, $D5, $AC, $F6, $B4, $57, $B5, $38, $BD, $18, $B5, $D7, $A4,
    $F4, $4A, $7D, $1A, $FD, $01, $DB, $01, $FD, $01, $FD, $01, $DA, $01, $D4, $11,
    $F2, $52, $35, $84, $55, $8C, $35, $84, $14, $7C, $F4, $7B, $14, $7C, $FF, $FF,
    $FF, $FF, $89, $FD, $69, $FD, $2A, $FD, $2A, $FD, $2A, $FD, $4B, $FD, $6C, $FD,
    $6D, $FD, $8D, $FD, $8D, $F5, $8D, $FD, $AE, $FD, $AF, $FD, $D0, $F5, $D1, $FD,
    $D2, $FD, $D2, $FD, $B3, $FD, $D4, $FD, $D5, $FD, $F5, $FD, $F6, $FD, $16, $FE,
    $37, $FE, $37, $FE, $58, $FE, $58, $FE, $59, $F6, $79, $F6, $7A, $F6, $9A, $EE,
    $9A, $EE, $BA, $EE, $BA, $EE, $9A, $F6, $9A, $F6, $B9, $F6, $B7, $EE, $55, $2A,
    $FD, $01, $1D, $02, $34, $4B, $F6, $3A, $FD, $01, $0D, $53, $89, $94, $A9, $9C,
    $C9, $AC, $CA, $BC, $E9, $CC, $CA, $E4, $BE, $4B, $DA, $09, $47, $E4, $E6, $DB,
    $85, $C3, $C5, $92, $B0, $21, $DB, $01, $FD, $01, $94, $11, $84, $82, $C2, $9A,
    $C2, $9A, $E3, $9A, $9B, $4B, $FD, $01, $45, $9B, $A4, $C3, $C4, $BB, $A4, $BB,
    $A5, $B3, $A5, $AB, $9B, $4B, $DA, $01, $C9, $CC, $0A, $DD, $4C, $E5, $77, $5B,
    $FD, $01, $10, $8C, $CF, $CD, $4F, $B5, $FE, $2A, $D6, $09, $4E, $9C, $EF, $9B,
    $59, $4B, $FD, $01, $EF, $72, $8E, $A3, $6D, $AB, $4D, $AB, $75, $63, $7D, $1A,
    $D8, $09, $D1, $B3, $F1, $B3, $F0, $B3, $CF, $AB, $AF, $AB, $F0, $AB, $51, $BC,
    $72, $B4, $FE, $2A, $DB, $01, $F3, $BC, $D2, $B4, $D2, $B4, $14, $BD, $35, $BD,
    $56, $C5, $56, $C5, $74, $32, $DA, $01, $1D, $02, $FD, $01, $DB, $01, $98, $2A,
    $D8, $32, $D9, $32, $FC, $32, $7D, $1A, $FD, $01, $74, $3A, $B8, $94, $77, $94,
    $56, $8C, $55, $8C, $56, $84, $FF, $FF, $FF, $FF, $69, $FD, $49, $F5, $0A, $FD,
    $0A, $FD, $2A, $FD, $4B, $FD, $6C, $FD, $8D, $FD, $8D, $FD, $8D, $FD, $8E, $FD,
    $AE, $FD, $CF, $FD, $D0, $FD, $D1, $FD, $D2, $FD, $D2, $FD, $D3, $FD, $D4, $FD,
    $D5, $FD, $F5, $FD, $16, $FE, $16, $FE, $37, $FE, $58, $FE, $78, $FE, $79, $FE,
    $79, $FE, $9A, $FE, $BA, $FE, $BB, $F6, $DB, $F6, $DB, $EE, $FB, $F6, $DB, $FE,
    $DB, $FE, $FA, $FE, $B7, $32, $1D, $02, $D8, $09, $F0, $9C, $6D, $B5, $FC, $32,
    $DB, $01, $89, $94, $88, $8C, $69, $9C, $88, $AC, $88, $B4, $87, $C4, $47, $E4,
    $BE, $4B, $DA, $09, $E6, $DB, $A4, $D3, $06, $AB, $FA, $09, $1D, $02, $5A, $1A,
    $1B, $3B, $FD, $01, $92, $19, $A2, $92, $C2, $9A, $E3, $9A, $78, $53, $FD, $01,
    $89, $62, $A3, $CB, $C4, $CB, $A4, $C3, $84, $B3, $64, $AB, $2C, $73, $C9, $6A,
    $06, $B4, $47, $C4, $68, $CC, $7A, $4B, $FD, $01, $8D, $B4, $0D, $C5, $4D, $BD,
    $7B, $4B, $DB, $01, $6E, $9C, $30, $9C, $7B, $4B, $FD, $01, $10, $B4, $F0, $B3,
    $CF, $B3, $8F, $B3, $6E, $AB, $7B, $4B, $FD, $01, $B0, $72, $B1, $B3, $AF, $AB,
    $8E, $A3, $6D, $9B, $6E, $9B, $CF, $A3, $14, $53, $1D, $02, $13, $2A, $71, $B4,
    $91, $AC, $D2, $B4, $14, $BD, $36, $C5, $D4, $7B, $DA, $01, $FD, $01, $9A, $22,
    $DC, $2A, $FD, $01, $31, $63, $B1, $83, $D2, $7B, $D2, $7B, $14, $84, $B6, $6B,
    $FC, $32, $FD, $01, $56, $5B, $F9, $9C, $D9, $9C, $B8, $94, $B7, $94, $FF, $FF,
    $FF, $FF, $48, $FD, $28, $F5, $08, $F5, $29, $F5, $4A, $F5, $4B, $F5, $6C, $FD,
    $8C, $FD, $AD, $FD, $CE, $FD, $CE, $FD, $EE, $FD, $0F, $FE, $10, $FE, $10, $FE,
    $11, $FE, $31, $FE, $11, $FE, $F3, $FD, $13, $FE, $13, $FE, $33, $FE, $54, $FE,
    $74, $FE, $94, $FE, $B4, $FE, $B4, $FE, $D4, $FE, $D4, $FE, $F4, $FE, $F4, $FE,
    $F4, $FE, $14, $FF, $14, $FF, $33, $FF, $52, $FF, $54, $7C, $3D, $0A, $F6, $11,
    $6D, $C5, $8B, $D5, $EE, $83, $5D, $12, $F3, $19, $E8, $A3, $A8, $AB, $A7, $B3,
    $67, $C3, $47, $D3, $06, $E3, $C8, $EA, $9C, $4B, $DA, $09, $27, $E3, $66, $DB,
    $B7, $32, $FD, $01, $AD, $31, $62, $82, $42, $82, $5C, $3B, $DB, $01, $81, $92,
    $A1, $9A, $C1, $9A, $51, $6B, $5D, $12, $D2, $21, $C3, $D3, $03, $D4, $03, $CC,
    $C3, $C3, $A3, $B3, $83, $B3, $63, $B3, $A4, $B3, $E4, $BB, $06, $C4, $5E, $3B,
    $DA, $01, $E8, $CB, $C9, $C3, $ED, $BB, $3C, $3B, $FD, $01, $4C, $A4, $8C, $A4,
    $9A, $53, $FD, $01, $70, $9C, $F1, $BC, $D2, $B4, $50, $B4, $F0, $AB, $95, $6B,
    $3D, $0A, $D3, $29, $2E, $A3, $2E, $A3, $0E, $9B, $ED, $92, $0D, $93, $EF, $82,
    $9D, $1A, $FD, $01, $2F, $83, $10, $B4, $50, $B4, $B2, $C4, $13, $CD, $D3, $52,
    $1D, $02, $DB, $01, $73, $3A, $51, $AC, $1C, $33, $FD, $01, $F0, $8B, $F1, $93,
    $12, $94, $33, $94, $96, $A4, $D7, $AC, $57, $8C, $BE, $22, $F7, $11, $3B, $B5,
    $1A, $AD, $F9, $A4, $F9, $A4, $FF, $FF, $FF, $FF, $27, $F5, $07, $F5, $09, $F5,
    $49, $F5, $4A, $FD, $6B, $FD, $8C, $FD, $8D, $FD, $AD, $FD, $CE, $FD, $EE, $FD,
    $0F, $FE, $0F, $FE, $30, $FE, $30, $FE, $31, $FE, $51, $FE, $32, $FE, $13, $FE,
    $13, $FE, $33, $FE, $53, $FE, $54, $FE, $74, $FE, $94, $FE, $94, $FE, $B4, $FE,
    $B4, $FE, $B4, $FE, $D4, $FE, $D3, $FE, $D3, $FE, $D3, $FE, $D3, $F6, $F2, $F6,
    $F1, $F6, $7B, $4B, $FD, $01, $AD, $B4, $8A, $E5, $49, $CD, $99, $2A, $FD, $01,
    $8A, $83, $08, $B4, $C7, $B3, $66, $C3, $E5, $CA, $A4, $D2, $84, $DA, $45, $E2,
    $7B, $4B, $FD, $01, $67, $EB, $0D, $8B, $7D, $12, $B4, $11, $04, $9B, $A3, $8A,
    $83, $82, $5B, $43, $FD, $01, $A2, $92, $E2, $9A, $02, $AB, $47, $9B, $5E, $3B,
    $FD, $01, $25, $AB, $02, $DC, $03, $D4, $E2, $CB, $C3, $C3, $83, $B3, $84, $B3,
    $A4, $B3, $A4, $AB, $6B, $8B, $3E, $33, $B4, $11, $87, $BB, $67, $B3, $0F, $73,
    $9D, $1A, $D8, $09, $EA, $A3, $2B, $A4, $B6, $63, $FD, $01, $12, $5B, $93, $D5,
    $54, $CD, $D3, $C4, $51, $BC, $B1, $93, $3E, $33, $B6, $09, $CD, $92, $CD, $92,
    $CD, $92, $AC, $8A, $CC, $8A, $57, $22, $FD, $01, $F2, $31, $AE, $AB, $EF, $B3,
    $50, $BC, $D2, $CC, $73, $73, $3D, $0A, $DB, $01, $92, $7B, $72, $AC, $92, $7B,
    $BE, $22, $B7, $09, $11, $94, $32, $9C, $74, $9C, $B5, $A4, $18, $B5, $5A, $BD,
    $9C, $C5, $9E, $43, $DA, $01, $9C, $BD, $7B, $B5, $5B, $AD, $5A, $AD, $FF, $FF,
    $FF, $FF, $47, $F5, $27, $F5, $48, $F5, $69, $F5, $8A, $FD, $AB, $FD, $CC, $FD,
    $CC, $FD, $ED, $FD, $0E, $FE, $0E, $FE, $2E, $FE, $2E, $FE, $4E, $F6, $4F, $F6,
    $4F, $FE, $70, $FE, $70, $FE, $70, $FE, $70, $FE, $90, $FE, $90, $F6, $B0, $F6,
    $B1, $F6, $B1, $FE, $B1, $FE, $D1, $FE, $B1, $FE, $91, $FE, $90, $FE, $70, $FE,
    $70, $FE, $4F, $FE, $4F, $FE, $0C, $FE, $EB, $FD, $BE, $4B, $DB, $01, $6B, $E5,
    $6B, $DD, $74, $32, $FD, $01, $12, $32, $2D, $CC, $8C, $CB, $CB, $D2, $2A, $DA,
    $A9, $E1, $29, $E9, $2A, $F1, $86, $F9, $57, $63, $FD, $01, $6D, $9A, $56, $32,
    $FD, $01, $2E, $7B, $0C, $A4, $AA, $8B, $2C, $73, $BE, $22, $B8, $09, $A9, $93,
    $E9, $A3, $09, $B4, $49, $C4, $B6, $6B, $3D, $0A, $D8, $09, $66, $E4, $25, $E4,
    $03, $D4, $E3, $CB, $A1, $BB, $61, $B3, $61, $B3, $82, $B3, $87, $9B, $3C, $3B,
    $4C, $52, $A4, $AB, $84, $AB, $78, $22, $FD, $01, $D0, $31, $4A, $B3, $8C, $B3,
    $D2, $93, $FE, $2A, $D8, $09, $D0, $DD, $D0, $DD, $91, $D5, $10, $C5, $2F, $AC,
    $9E, $43, $DA, $01, $0C, $83, $AC, $8A, $AC, $8A, $AC, $8A, $16, $22, $1D, $02,
    $B8, $09, $6F, $AB, $B0, $B3, $F1, $C3, $51, $D4, $13, $B4, $9C, $22, $DB, $01,
    $F2, $A3, $B2, $CC, $51, $B4, $15, $53, $FD, $01, $12, $32, $10, $A4, $52, $AC,
    $B3, $B4, $15, $BD, $77, $CD, $B9, $D5, $DA, $DD, $F8, $73, $F6, $52, $FC, $D5,
    $BB, $CD, $BB, $CD, $BB, $C5, $FF, $FF, $FF, $FF, $68, $FD, $68, $FD, $69, $FD,
    $89, $F5, $8A, $FD, $CB, $FD, $CC, $FD, $ED, $FD, $EE, $FD, $0E, $FE, $2E, $FE,
    $4E, $FE, $4E, $FE, $4E, $FE, $4F, $FE, $6F, $FE, $70, $FE, $70, $FE, $70, $FE,
    $90, $FE, $90, $FE, $B0, $FE, $B1, $FE, $B1, $FE, $B1, $FE, $B1, $FE, $91, $FE,
    $70, $FE, $50, $FE, $2F, $FE, $0F, $FE, $EE, $F5, $CD, $F5, $AD, $ED, $8A, $F5,
    $69, $F5, $D9, $63, $FD, $01, $D8, $09, $DA, $09, $1D, $02, $F6, $11, $ED, $DC,
    $4C, $DC, $4B, $D3, $8A, $CA, $E8, $D9, $69, $E1, $2A, $F1, $2A, $F9, $C7, $F9,
    $D1, $92, $5D, $12, $D2, $31, $1C, $0A, $DA, $09, $F0, $CC, $6D, $B4, $2C, $9C,
    $76, $2A, $FD, $01, $11, $2A, $2B, $9C, $8B, $AC, $EC, $BC, $4C, $D5, $4D, $CD,
    $9A, $53, $FD, $01, $D6, $11, $0A, $B4, $A5, $EC, $64, $DC, $22, $D4, $E2, $CB,
    $A1, $C3, $81, $BB, $81, $BB, $83, $BB, $A4, $BB, $66, $9B, $15, $22, $1D, $02,
    $B8, $09, $8A, $BB, $AB, $C3, $CD, $CB, $2D, $D4, $B9, $5B, $FD, $01, $F5, $19,
    $F0, $E5, $B1, $D5, $31, $CD, $90, $B4, $9B, $4B, $FD, $01, $2C, $8B, $CD, $8A,
    $8D, $7A, $F7, $11, $1D, $02, $DA, $01, $0F, $9B, $B0, $BB, $11, $CC, $52, $D4,
    $93, $DC, $56, $63, $FD, $01, $73, $42, $D3, $DC, $92, $D4, $11, $A4, $BC, $22,
    $FD, $01, $B0, $93, $30, $AC, $92, $B4, $F4, $C4, $56, $CD, $B8, $DD, $1A, $E6,
    $1B, $E6, $3C, $E6, $3C, $E6, $3D, $DE, $3D, $DE, $FD, $D5, $FD, $D5, $FF, $FF,
    $FF, $FF, $67, $FD, $67, $FD, $88, $FD, $A9, $FD, $CA, $FD, $EB, $FD, $0C, $FE,
    $0C, $FE, $0D, $FE, $2D, $FE, $2D, $FE, $4D, $FE, $4E, $FE, $4E, $FE, $6E, $FE,
    $6E, $FE, $4F, $FE, $4E, $FE, $6E, $FE, $8E, $FE, $8F, $FE, $6F, $FE, $6F, $FE,
    $6F, $FE, $4F, $FE, $0F, $FE, $EE, $FD, $CE, $FD, $8E, $FD, $4C, $FD, $2C, $FD,
    $2B, $FD, $0B, $FD, $EA, $F4, $C9, $FC, $09, $FD, $49, $DD, $78, $4B, $1E, $2B,
    $BA, $2A, $13, $53, $B0, $ED, $F0, $EC, $11, $EC, $F3, $E2, $72, $EA, $12, $F2,
    $D2, $F1, $CB, $F9, $C9, $F9, $87, $D1, $EB, $D2, $5C, $43, $3C, $12, $FD, $01,
    $D5, $19, $AF, $DC, $EE, $AB, $14, $2A, $1D, $02, $D8, $09, $D0, $83, $12, $8C,
    $96, $9C, $F9, $AC, $3B, $B5, $1B, $CD, $DA, $C4, $9A, $53, $5D, $12, $DB, $01,
    $55, $32, $D2, $8B, $51, $DD, $CD, $D4, $49, $C4, $E7, $C3, $C5, $C3, $65, $B3,
    $0F, $3A, $DB, $01, $1D, $02, $D8, $09, $A7, $B3, $45, $CC, $66, $D4, $A7, $DC,
    $E8, $E4, $CC, $D4, $9B, $4B, $FD, $01, $D8, $09, $11, $63, $2F, $CD, $CD, $BC,
    $BA, $2A, $FD, $01, $0D, $6B, $D2, $21, $DB, $01, $FD, $01, $D8, $09, $70, $9B,
    $F2, $BB, $34, $CC, $55, $D4, $55, $DC, $95, $EC, $7A, $4B, $FD, $01, $54, $D4,
    $B4, $E4, $93, $DC, $95, $3A, $FD, $01, $F3, $29, $11, $B4, $51, $BC, $B2, $C4,
    $33, $D5, $94, $DD, $D5, $ED, $37, $F6, $58, $FE, $79, $FE, $5A, $F6, $5A, $EE,
    $5B, $EE, $5B, $EE, $5B, $E6, $FF, $FF, $FF, $FF, $67, $FD, $67, $FD, $A8, $FD,
    $A9, $FD, $CA, $FD, $EB, $FD, $EC, $FD, $0C, $FE, $0D, $FE, $2D, $FE, $2D, $FE,
    $4D, $F6, $4E, $FE, $4E, $FE, $4E, $FE, $4E, $FE, $4E, $FE, $4E, $FE, $4E, $FE,
    $6E, $F6, $4E, $F6, $4E, $F6, $2E, $F6, $2E, $F6, $EE, $F5, $CE, $F5, $8D, $F5,
    $6D, $F5, $4C, $F5, $0B, $F5, $EB, $F4, $EA, $F4, $EA, $F4, $EA, $F4, $EA, $FC,
    $6A, $FD, $09, $FE, $8B, $FE, $EC, $FE, $EE, $FE, $D1, $FE, $32, $FE, $11, $F5,
    $32, $F4, $14, $EB, $93, $FA, $F2, $F1, $50, $F1, $08, $F1, $07, $E9, $4A, $EA,
    $4C, $F3, $B3, $93, $5E, $3B, $5D, $12, $DB, $01, $D8, $09, $FD, $01, $1D, $02,
    $DA, $01, $8F, $83, $11, $8C, $53, $94, $96, $9C, $B8, $A4, $B9, $A4, $78, $B4,
    $59, $B4, $78, $C4, $77, $63, $FC, $32, $3D, $0A, $FD, $01, $FB, $01, $D8, $09,
    $D6, $11, $D6, $11, $DA, $01, $FD, $01, $1D, $02, $5D, $12, $51, $3A, $86, $BB,
    $25, $DC, $65, $DC, $C6, $E4, $E7, $EC, $29, $ED, $4C, $F5, $4F, $E5, $79, $53,
    $BE, $22, $FD, $01, $DB, $01, $D8, $09, $3D, $0A, $FD, $01, $FD, $01, $1D, $02,
    $5D, $12, $54, $32, $52, $C4, $53, $CC, $75, $D4, $95, $DC, $96, $EC, $B7, $EC,
    $D6, $F4, $BB, $53, $FD, $01, $55, $D4, $D5, $EC, $54, $3A, $1D, $02, $D8, $09,
    $72, $CC, $72, $CC, $B2, $CC, $F3, $D4, $74, $E5, $B5, $ED, $F6, $F5, $16, $F6,
    $38, $FE, $59, $F6, $5A, $F6, $7B, $F6, $7B, $EE, $7C, $EE, $7C, $EE, $FF, $FF,
    $FF, $FF, $87, $FD, $87, $FD, $87, $FD, $A8, $FD, $A9, $FD, $C9, $FD, $EA, $FD,
    $EB, $FD, $0B, $FE, $0C, $FE, $0C, $FE, $0C, $FE, $0D, $FE, $0D, $FE, $0D, $FE,
    $ED, $FD, $ED, $FD, $EE, $FD, $CE, $FD, $CE, $FD, $AE, $FD, $8E, $FD, $6E, $FD,
    $4D, $FD, $2D, $FD, $0C, $FD, $CC, $FC, $CB, $FC, $AA, $FC, $A9, $FC, $A8, $F4,
    $C8, $F4, $E8, $FC, $28, $FD, $06, $EE, $E8, $F6, $0C, $F7, $2E, $F7, $50, $FF,
    $55, $FF, $79, $FE, $FA, $FC, $3C, $FB, $5A, $FA, $76, $F9, $2F, $F9, $E8, $F8,
    $64, $E8, $43, $E8, $64, $E8, $67, $F9, $2A, $FA, $0C, $FB, $72, $93, $3E, $33,
    $FD, $01, $1D, $0A, $B9, $2A, $B5, $42, $76, $A4, $76, $8C, $77, $7C, $B9, $7C,
    $DB, $7C, $FC, $7C, $FE, $74, $BF, $6C, $9F, $6C, $7F, $64, $7F, $64, $1D, $64,
    $79, $5B, $18, $43, $FA, $32, $DC, $2A, $FE, $2A, $FE, $2A, $FB, $32, $D8, $32,
    $71, $63, $CB, $BC, $C6, $D4, $65, $DC, $65, $DC, $86, $DC, $A6, $EC, $07, $ED,
    $47, $ED, $A7, $F5, $E7, $F5, $E8, $F5, $2D, $8C, $55, $2A, $FA, $09, $FD, $01,
    $FD, $01, $1B, $0A, $97, $2A, $D2, $4A, $AF, $B4, $51, $D5, $52, $DD, $54, $DD,
    $34, $E5, $36, $ED, $37, $ED, $17, $ED, $18, $F5, $D8, $7B, $3D, $0A, $DB, $01,
    $DB, $01, $1D, $02, $DA, $09, $14, $C4, $94, $DC, $93, $DC, $B3, $DC, $F3, $E4,
    $54, $ED, $94, $F5, $B5, $F5, $D5, $FD, $F5, $FD, $16, $FE, $37, $FE, $38, $FE,
    $59, $FE, $59, $FE, $59, $FE, $FF, $FF, $FF, $FF, $A7, $FD, $87, $FD, $87, $F5,
    $88, $F5, $A8, $FD, $C9, $FD, $CA, $FD, $CB, $F5, $EB, $FD, $EB, $F5, $EC, $F5,
    $EC, $F5, $EC, $FD, $EC, $FD, $EC, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $8E, $FD,
    $8D, $FD, $6D, $FD, $4D, $F5, $2D, $F5, $0C, $F5, $EC, $F4, $CB, $F4, $8B, $FC,
    $8A, $F4, $89, $FC, $A9, $FC, $C8, $FC, $E8, $FC, $49, $FD, $AA, $FD, $88, $FE,
    $09, $FF, $4D, $FF, $90, $FF, $D2, $FF, $34, $FF, $95, $F5, $95, $E3, $18, $DA,
    $15, $E1, $51, $E0, $2B, $E0, $04, $E0, $03, $D8, $43, $E0, $C5, $F0, $68, $F9,
    $2A, $FA, $2D, $FB, $CF, $F3, $9C, $4B, $DA, $01, $15, $D5, $16, $C5, $17, $C5,
    $18, $B5, $19, $9D, $FA, $94, $3B, $8D, $3C, $8D, $3E, $7D, $3E, $7D, $BF, $6C,
    $7F, $64, $5F, $64, $3E, $5C, $1D, $64, $FC, $73, $1C, $8C, $5A, $A4, $1A, $C5,
    $99, $DD, $38, $EE, $B5, $F6, $F2, $F6, $31, $F7, $AE, $F6, $2C, $F6, $88, $F5,
    $27, $F5, $C6, $EC, $A5, $EC, $C6, $EC, $26, $ED, $E7, $D4, $36, $22, $F6, $11,
    $F6, $11, $F8, $09, $FB, $01, $3D, $0A, $54, $32, $CD, $C4, $4C, $DD, $8F, $D5,
    $B1, $E5, $D2, $E5, $F4, $ED, $D6, $F5, $D6, $F5, $98, $FD, $79, $FD, $39, $FD,
    $39, $FD, $D7, $E4, $78, $5B, $1E, $33, $BB, $2A, $95, $4A, $34, $D4, $D5, $EC,
    $D5, $E4, $D5, $E4, $F4, $E4, $14, $ED, $53, $ED, $74, $FD, $B4, $FD, $B4, $FD,
    $D4, $FD, $D5, $FD, $F6, $FD, $17, $FE, $18, $F6, $39, $F6, $39, $F6, $FF, $FF,
    $FF, $FF, $86, $FD, $86, $FD, $67, $FD, $67, $FD, $88, $FD, $A8, $FD, $A9, $FD,
    $AA, $FD, $AA, $FD, $AA, $FD, $AA, $FD, $AB, $FD, $AB, $FD, $8C, $FD, $8C, $FD,
    $6C, $FD, $4D, $FD, $4D, $FD, $2D, $FD, $0D, $FD, $ED, $FC, $CC, $FC, $AC, $FC,
    $8B, $FC, $6B, $FC, $6A, $FC, $69, $FC, $88, $FC, $C7, $FC, $07, $F5, $47, $F5,
    $A7, $F5, $28, $FE, $A9, $FE, $2B, $F7, $4D, $F7, $71, $FF, $78, $FF, $9F, $FE,
    $9F, $F4, $BF, $DA, $7C, $D1, $B5, $D8, $2F, $E0, $08, $E8, $06, $E8, $06, $E0,
    $27, $E0, $C9, $E8, $AC, $E9, $B3, $D2, $B5, $BB, $36, $C4, $B6, $B4, $D8, $63,
    $FD, $01, $95, $3A, $DB, $BD, $DB, $C5, $DC, $B5, $DC, $A5, $BC, $95, $BD, $95,
    $BE, $8D, $5D, $95, $3E, $8D, $FF, $84, $9F, $74, $1F, $74, $FF, $73, $DF, $6B,
    $DF, $73, $3F, $74, $7F, $7C, $FF, $8C, $5F, $A5, $DF, $C5, $1E, $DE, $5C, $E6,
    $9B, $EE, $FC, $F6, $3A, $F7, $B7, $FE, $33, $F6, $70, $ED, $CD, $EC, $4B, $FC,
    $4A, $FC, $69, $FC, $98, $5B, $FE, $2A, $FE, $2A, $D9, $32, $F2, $4A, $EB, $B4,
    $EA, $ED, $CC, $ED, $CC, $ED, $CC, $ED, $ED, $F5, $0E, $F6, $31, $F6, $33, $FE,
    $34, $FE, $36, $FE, $17, $FE, $B7, $F5, $97, $FD, $77, $F5, $57, $F5, $37, $F5,
    $18, $F5, $18, $F5, $18, $F5, $D6, $F4, $D6, $F4, $D6, $EC, $F6, $F4, $16, $F5,
    $36, $FD, $35, $FD, $55, $FD, $55, $FD, $55, $FD, $75, $FD, $95, $FD, $B5, $FD,
    $D6, $FD, $F6, $FD, $16, $FE, $FF, $FF, $FF, $FF, $86, $FD, $66, $F5, $67, $FD,
    $67, $FD, $88, $FD, $88, $FD, $89, $FD, $89, $FD, $89, $FD, $8A, $FD, $8A, $F5,
    $6A, $F5, $6B, $FD, $6B, $FD, $4B, $FD, $4C, $FD, $2C, $FD, $0C, $FD, $EC, $FC,
    $CC, $FC, $AB, $F4, $8B, $F4, $6B, $F4, $4A, $FC, $4A, $FC, $49, $FC, $49, $FC,
    $88, $FC, $E8, $FC, $48, $FD, $A8, $FD, $08, $FE, $89, $FE, $EA, $FE, $8C, $FF,
    $F0, $FF, $B2, $FF, $95, $FE, $D8, $DC, $DA, $BA, $9B, $B1, $DA, $B8, $33, $C8,
    $0E, $D8, $08, $E8, $28, $F0, $68, $F0, $A9, $F0, $4B, $F9, $0E, $FA, $F4, $DA,
    $D5, $C3, $36, $C4, $B6, $B4, $F8, $9C, $3C, $3B, $FD, $01, $9C, $B5, $5D, $CE,
    $7E, $C6, $7D, $B6, $5D, $AE, $3E, $9E, $FE, $95, $7F, $9D, $5E, $8D, $DF, $84,
    $9F, $7C, $3F, $7C, $FF, $73, $DF, $6B, $BF, $6B, $FF, $6B, $3F, $74, $9F, $84,
    $FE, $9C, $7E, $B5, $FD, $D5, $3C, $DE, $5A, $E6, $9A, $E6, $D9, $EE, $F8, $FE,
    $B5, $FE, $13, $FE, $4F, $FD, $6C, $FC, $E9, $F3, $E7, $F3, $06, $FC, $A7, $FC,
    $06, $F5, $87, $F5, $E8, $F5, $09, $EE, $0B, $EE, $0C, $EE, $0D, $EE, $ED, $ED,
    $ED, $F5, $EE, $F5, $10, $F6, $32, $FE, $34, $FE, $36, $FE, $17, $FE, $F8, $FD,
    $D8, $FD, $B8, $FD, $78, $FD, $58, $FD, $38, $FD, $38, $FD, $38, $FD, $F7, $FC,
    $F7, $FC, $F7, $F4, $16, $F5, $16, $F5, $15, $F5, $15, $F5, $35, $F5, $35, $FD,
    $54, $FD, $54, $FD, $74, $F5, $75, $F5, $B5, $F5, $D6, $FD, $F6, $FD, $FF, $FF,
    $FF, $FF, $86, $FD, $66, $FD, $66, $FD, $67, $FD, $67, $FD, $68, $FD, $68, $FD,
    $68, $FD, $48, $FD, $49, $FD, $49, $FD, $29, $FD, $09, $FD, $EA, $FC, $EB, $FC,
    $CB, $FC, $AB, $FC, $8B, $FC, $8A, $FC, $6A, $F4, $4A, $F4, $49, $F4, $29, $F4,
    $29, $F4, $49, $FC, $68, $FC, $A8, $FC, $08, $FD, $88, $FD, $E8, $F5, $68, $F6,
    $09, $EF, $89, $EF, $CA, $F7, $75, $FF, $1B, $FF, $7E, $FD, $7D, $EB, $FB, $D9,
    $19, $E1, $F5, $E0, $90, $E0, $4B, $E8, $6A, $E8, $AA, $E8, $EB, $E8, $8E, $C9,
    $51, $BA, $14, $A3, $D7, $93, $7B, $94, $FC, $8C, $3C, $8D, $9C, $95, $FC, $A5,
    $7B, $9D, $97, $5B, $7D, $D6, $9E, $DE, $BD, $DE, $BD, $DE, $7D, $D6, $FC, $D5,
    $7D, $DD, $FC, $EC, $9B, $DC, $FA, $CB, $BA, $CB, $BA, $BB, $9A, $B3, $5A, $AB,
    $5A, $A3, $7B, $A3, $BC, $AB, $1D, $B4, $5C, $B4, $BD, $BC, $3E, $CD, $9F, $DD,
    $DF, $E5, $FF, $ED, $1F, $EE, $7B, $EE, $9A, $F6, $3A, $FE, $98, $FD, $95, $FC,
    $91, $F3, $EE, $F2, $CC, $F2, $0B, $FB, $8B, $FB, $4B, $FC, $EB, $FC, $4B, $FD,
    $AA, $FD, $09, $F6, $0A, $FE, $0B, $FE, $EB, $FD, $EC, $FD, $ED, $FD, $EE, $FD,
    $10, $FE, $12, $FE, $33, $FE, $35, $FE, $16, $FE, $F6, $FD, $D7, $F5, $B8, $FD,
    $99, $FD, $79, $F5, $59, $F5, $38, $FD, $18, $FD, $17, $FD, $17, $FD, $F7, $F4,
    $F7, $F4, $F7, $FC, $F7, $FC, $F6, $FC, $16, $FD, $15, $FD, $35, $FD, $54, $FD,
    $74, $FD, $94, $FD, $B5, $FD, $FF, $FF, $FF, $FF, $66, $F5, $66, $F5, $46, $FD,
    $46, $FD, $47, $FD, $47, $FD, $68, $FD, $48, $FD, $28, $F5, $28, $F5, $28, $F5,
    $08, $F5, $C9, $F4, $A9, $F4, $AA, $F4, $8A, $FC, $6A, $F4, $4A, $F4, $69, $F4,
    $49, $F4, $09, $F4, $29, $F4, $29, $F4, $29, $FC, $69, $FC, $89, $FC, $E9, $FC,
    $49, $FD, $C9, $FD, $29, $FE, $C9, $FE, $6A, $FF, $EB, $FF, $EB, $FF, $75, $FF,
    $F7, $E5, $D7, $D3, $79, $CA, $BB, $D9, $3A, $E1, $16, $E9, $D1, $E8, $0D, $F9,
    $0D, $F9, $2C, $F9, $6C, $F1, $EF, $D9, $B2, $C2, $96, $B3, $59, $A4, $BC, $9C,
    $3D, $95, $7C, $95, $BC, $9D, $1D, $AE, $5D, $B6, $7D, $D6, $BE, $DE, $DE, $E6,
    $DE, $E6, $BE, $DE, $7E, $D6, $3E, $DE, $DD, $E5, $3D, $F5, $FD, $EC, $DD, $EC,
    $7D, $DC, $1B, $CC, $DB, $BB, $9B, $B3, $7B, $AB, $9B, $AB, $BC, $AB, $FC, $B3,
    $5C, $B4, $DD, $BC, $FD, $C4, $3D, $CD, $7D, $D5, $9E, $DD, $BE, $E5, $19, $E6,
    $39, $E6, $1A, $FE, $B9, $FD, $F6, $FC, $F2, $FB, $0E, $FB, $CB, $F2, $68, $E2,
    $A8, $EA, $68, $EB, $28, $F4, $09, $FD, $89, $FD, $E9, $F5, $E9, $F5, $0B, $FE,
    $EC, $FD, $EC, $FD, $CD, $F5, $CE, $F5, $CF, $F5, $D1, $F5, $F2, $F5, $14, $F6,
    $15, $FE, $17, $FE, $18, $FE, $F9, $FD, $D9, $FD, $9A, $FD, $59, $F5, $58, $FD,
    $38, $FD, $18, $FD, $18, $FD, $18, $FD, $F7, $F4, $F7, $FC, $17, $FD, $F6, $FC,
    $16, $FD, $15, $FD, $14, $FD, $34, $F5, $54, $F5, $73, $F5, $94, $FD, $FF, $FF,
    $FF, $FF, $26, $FD, $26, $FD, $06, $FD, $07, $FD, $07, $FD, $27, $FD, $07, $F5,
    $08, $F5, $E8, $F4, $A8, $FC, $88, $FC, $69, $FC, $29, $FC, $29, $FC, $2A, $FC,
    $0A, $FC, $EA, $FB, $EA, $F3, $C9, $FB, $C8, $FB, $E7, $F3, $27, $F4, $67, $F4,
    $A7, $F4, $E8, $F4, $48, $F5, $A7, $F5, $06, $EE, $A4, $EE, $46, $F7, $AB, $FF,
    $B2, $FF, $59, $FF, $DE, $FE, $7F, $F4, $5E, $F3, $99, $EA, $36, $EA, $D4, $F9,
    $B1, $F9, $8F, $F1, $AF, $F9, $F0, $E1, $30, $C2, $B2, $AA, $34, $9B, $D6, $93,
    $78, $8C, $FA, $8C, $3B, $8D, $7B, $9D, $7B, $A5, $BB, $B5, $DC, $BD, $1C, $CE,
    $3D, $DE, $5D, $E6, $7E, $E6, $BF, $EE, $9E, $EE, $5E, $EE, $1D, $EE, $DD, $F5,
    $9C, $F5, $7C, $F5, $5C, $FD, $1B, $FD, $DB, $FC, $9A, $F4, $19, $F4, $B7, $EB,
    $56, $E3, $57, $EB, $78, $EB, $98, $EB, $D9, $EB, $1A, $EC, $5C, $E4, $9C, $E4,
    $DD, $DC, $1E, $DD, $5F, $DD, $7F, $DD, $9F, $DD, $9D, $ED, $7B, $FD, $37, $FD,
    $B5, $FC, $B1, $FB, $CE, $EA, $AF, $FA, $6E, $F2, $2D, $EA, $4D, $F2, $4E, $FB,
    $70, $FC, $30, $FD, $8E, $FD, $CD, $FD, $EC, $FD, $EC, $FD, $EC, $FD, $CB, $FD,
    $AA, $FD, $AC, $FD, $CE, $FD, $F0, $FD, $F2, $FD, $14, $FE, $16, $FE, $16, $FE,
    $F7, $FD, $F7, $FD, $D7, $F5, $99, $FD, $79, $F5, $59, $F5, $59, $F5, $39, $F5,
    $39, $F5, $39, $F5, $19, $F5, $18, $F5, $F8, $F4, $F7, $F4, $16, $F5, $16, $FD,
    $15, $FD, $35, $FD, $35, $FD, $FF, $FF, $FF, $FF, $E5, $F4, $E5, $F4, $C5, $FC,
    $C6, $FC, $E6, $F4, $07, $F5, $07, $F5, $E7, $EC, $A7, $EC, $67, $EC, $27, $EC,
    $07, $F4, $E8, $FB, $E8, $FB, $E9, $FB, $C9, $F3, $C9, $F3, $C9, $F3, $A9, $F3,
    $C8, $FB, $08, $FC, $68, $FC, $88, $FC, $C8, $FC, $29, $FD, $69, $FD, $E8, $FD,
    $88, $FE, $26, $FF, $87, $FF, $CC, $FF, $B2, $FF, $D6, $EE, $B9, $D5, $BE, $DB,
    $FC, $EA, $99, $EA, $56, $F2, $F4, $F9, $D1, $F9, $B0, $F9, $B0, $F9, $F0, $E1,
    $71, $CA, $13, $BB, $B6, $AB, $58, $A4, $FA, $94, $5B, $95, $9C, $9D, $DD, $A5,
    $DC, $AD, $FD, $BD, $1D, $C6, $3D, $D6, $5D, $DE, $7E, $E6, $7E, $EE, $9E, $EE,
    $7E, $EE, $5E, $EE, $1D, $EE, $DD, $F5, $BD, $F5, $9C, $F5, $5C, $FD, $1B, $FD,
    $FB, $FC, $DB, $FC, $9A, $FC, $39, $FC, $D8, $F3, $B8, $F3, $B9, $F3, $B9, $F3,
    $FA, $EB, $3B, $EC, $7C, $EC, $BC, $E4, $DD, $DC, $FE, $DC, $3E, $DD, $5E, $D5,
    $7F, $D5, $7C, $ED, $5A, $F5, $17, $FD, $B5, $FC, $12, $FC, $50, $FB, $AF, $FA,
    $AF, $FA, $8F, $FA, $6E, $F2, $AC, $EA, $8C, $EB, $8E, $F4, $6E, $F5, $CD, $FD,
    $EC, $FD, $0C, $FE, $2C, $FE, $0C, $FE, $EC, $FD, $AC, $FD, $6D, $F5, $AF, $F5,
    $D2, $F5, $F4, $F5, $F5, $F5, $F6, $FD, $17, $FE, $F7, $FD, $F7, $FD, $BA, $FD,
    $BA, $FD, $9A, $FD, $79, $F5, $5A, $F5, $59, $F5, $59, $F5, $39, $F5, $38, $F5,
    $18, $F5, $F7, $F4, $16, $F5, $16, $FD, $15, $FD, $35, $FD, $35, $FD, $FF, $FF,
    $FF, $FF, $A6, $F4, $A6, $F4, $C3, $F4, $C3, $F4, $C4, $F4, $A5, $F4, $66, $F4,
    $26, $F4, $E7, $F3, $C7, $F3, $A7, $F3, $A7, $F3, $87, $F3, $87, $F3, $67, $F3,
    $88, $EB, $88, $F3, $A8, $F3, $C9, $F3, $08, $F4, $68, $F4, $E7, $F4, $26, $F5,
    $84, $F5, $E2, $FD, $43, $FE, $C5, $FE, $68, $FF, $91, $FF, $57, $FF, $DD, $FE,
    $1F, $FE, $DD, $FC, $99, $FB, $B7, $FA, $96, $FA, $75, $FA, $34, $FA, $13, $F2,
    $32, $E2, $72, $CA, $D3, $AA, $75, $9B, $16, $84, $B9, $84, $1A, $95, $3B, $9D,
    $5C, $A5, $3D, $BD, $7D, $C5, $DD, $C5, $1C, $C6, $1D, $D6, $3D, $DE, $3D, $E6,
    $5D, $EE, $7D, $F6, $7E, $F6, $7D, $F6, $5D, $EE, $5D, $F6, $3D, $F6, $1D, $F6,
    $DC, $F5, $BC, $FD, $BC, $FD, $7A, $F5, $5A, $F5, $5A, $FD, $3A, $FD, $F9, $FC,
    $B8, $F4, $77, $F4, $77, $F4, $78, $F4, $98, $F4, $B9, $EC, $DA, $EC, $FB, $E4,
    $1B, $E5, $1B, $E5, $3C, $DD, $3E, $D5, $3E, $D5, $5D, $DD, $5B, $DD, $1A, $ED,
    $D8, $F4, $16, $FC, $53, $FB, $B2, $FA, $D2, $FA, $13, $FB, $F2, $FA, $D1, $EA,
    $D0, $E2, $52, $F3, $14, $FC, $93, $F5, $F0, $F5, $2E, $F6, $4B, $F6, $6A, $FE,
    $6A, $FE, $2D, $FE, $EE, $FD, $8F, $F5, $8F, $F5, $90, $FD, $B0, $FD, $F2, $FD,
    $F3, $FD, $F6, $FD, $F6, $FD, $17, $FE, $F7, $FD, $F7, $FD, $D8, $FD, $B8, $FD,
    $98, $F5, $78, $F5, $79, $F5, $59, $F5, $38, $F5, $38, $F5, $38, $F5, $18, $F5,
    $17, $F5, $17, $FD, $37, $FD, $FF, $FF, $FF, $FF, $45, $EC, $45, $EC, $82, $EC,
    $82, $EC, $84, $EC, $84, $EC, $45, $EC, $06, $EC, $C6, $EB, $86, $EB, $66, $EB,
    $46, $EB, $46, $EB, $46, $EB, $46, $EB, $67, $EB, $88, $F3, $C9, $F3, $0A, $FC,
    $49, $FC, $A8, $FC, $07, $F5, $46, $F5, $C5, $FD, $44, $FE, $A5, $FE, $27, $FF,
    $89, $FF, $B1, $FF, $57, $FF, $7C, $FE, $5C, $F5, $3A, $F4, $99, $FB, $D7, $FA,
    $96, $FA, $34, $FA, $13, $F2, $F2, $E9, $12, $E2, $93, $D2, $34, $BB, $17, $AC,
    $B9, $9C, $3B, $95, $7C, $9D, $7D, $A5, $9D, $B5, $9E, $CD, $BE, $CD, $1E, $CE,
    $3D, $CE, $3E, $DE, $5E, $E6, $5E, $EE, $7E, $EE, $7E, $F6, $7E, $F6, $7D, $F6,
    $5D, $EE, $5E, $F6, $3D, $F6, $1D, $F6, $FD, $FD, $DD, $FD, $DC, $FD, $9B, $FD,
    $9A, $FD, $7A, $FD, $5A, $FD, $3A, $FD, $19, $FD, $D9, $FC, $D9, $FC, $F9, $FC,
    $FA, $FC, $1B, $FD, $3B, $F5, $5C, $F5, $5C, $ED, $5C, $ED, $5D, $E5, $7F, $DD,
    $3E, $D5, $3C, $D5, $3B, $DD, $1A, $ED, $D8, $FC, $16, $FC, $33, $FB, $50, $F2,
    $50, $F2, $91, $F2, $12, $FB, $73, $FB, $93, $FB, $D4, $FB, $34, $FC, $52, $ED,
    $F0, $F5, $4E, $FE, $8C, $FE, $8B, $FE, $AB, $FE, $4D, $FE, $EE, $FD, $B0, $FD,
    $8F, $F5, $6F, $F5, $8F, $F5, $B1, $F5, $D2, $FD, $D5, $FD, $F6, $FD, $F7, $FD,
    $F7, $FD, $F8, $FD, $F8, $FD, $D9, $FD, $D9, $FD, $B9, $FD, $99, $FD, $79, $FD,
    $59, $F5, $59, $F5, $58, $FD, $38, $FD, $37, $F5, $37, $FD, $37, $FD, $FF, $FF,
    $FF, $FF, $C5, $EB, $C5, $EB, $05, $F4, $05, $FC, $E6, $FB, $C6, $F3, $66, $F3,
    $26, $EB, $E6, $E2, $E6, $E2, $C5, $E2, $E5, $E2, $05, $E3, $46, $E3, $86, $EB,
    $E7, $F3, $08, $F4, $49, $FC, $68, $FC, $A6, $FC, $25, $F5, $A4, $ED, $23, $EE,
    $A4, $F6, $07, $FF, $2A, $FF, $52, $FF, $37, $FF, $1C, $FF, $9E, $FE, $9E, $FD,
    $7B, $FC, $78, $FB, $57, $FB, $B7, $FA, $56, $F2, $94, $CA, $D4, $B2, $54, $A3,
    $D5, $93, $57, $94, $98, $9C, $DA, $A4, $FA, $AC, $FB, $BC, $3B, $C5, $7B, $CD,
    $BB, $CD, $1B, $CE, $3C, $D6, $1C, $E6, $1D, $EE, $1D, $F6, $3D, $F6, $3D, $FE,
    $3D, $FE, $3D, $FE, $5D, $FE, $5D, $FE, $5D, $F6, $5D, $F6, $3C, $F6, $3C, $FE,
    $1C, $FE, $FC, $FD, $FB, $FD, $19, $F6, $19, $F6, $18, $F6, $F8, $F5, $D7, $F5,
    $D7, $F5, $B7, $F5, $B6, $F5, $D7, $FD, $B7, $FD, $B8, $FD, $D9, $FD, $DA, $FD,
    $DA, $FD, $DA, $F5, $BB, $F5, $7D, $F5, $3C, $ED, $5C, $D5, $5C, $D5, $5C, $D5,
    $5B, $DD, $99, $E4, $B6, $EB, $92, $EA, $D0, $E1, $8F, $E1, $F1, $F1, $95, $FA,
    $18, $FB, $7B, $FB, $1C, $FC, $1A, $FD, $B8, $FD, $17, $FE, $73, $FE, $B1, $F6,
    $ED, $F6, $CB, $F6, $AB, $F6, $6B, $FE, $2A, $FE, $CA, $FD, $8C, $FD, $8E, $FD,
    $90, $FD, $B2, $FD, $B3, $FD, $F3, $FD, $F4, $FD, $F5, $FD, $16, $FE, $16, $FE,
    $17, $FE, $F7, $FD, $D8, $FD, $D9, $FD, $B9, $F5, $99, $F5, $99, $F5, $79, $F5,
    $58, $F5, $58, $F5, $59, $F5, $FF, $FF, $FF, $FF, $43, $DB, $43, $DB, $83, $E3,
    $62, $E3, $03, $DB, $C3, $DA, $A3, $D2, $84, $D2, $A4, $DA, $A5, $DA, $E6, $E2,
    $06, $EB, $66, $EB, $A7, $F3, $E7, $F3, $28, $FC, $29, $FC, $49, $FC, $68, $FC,
    $C7, $FC, $66, $FD, $E6, $FD, $84, $FE, $06, $FF, $48, $FF, $6B, $FF, $92, $FF,
    $57, $FF, $FC, $FE, $3D, $EE, $3C, $F5, $5A, $FC, $57, $FB, $D5, $FA, $76, $F2,
    $35, $EA, $94, $CA, $35, $BB, $D6, $AB, $57, $9C, $B8, $9C, $FA, $A4, $3B, $AD,
    $3C, $BD, $5C, $C5, $7D, $CD, $DD, $D5, $1D, $D6, $5C, $D6, $5C, $D6, $3D, $EE,
    $3D, $F6, $3D, $F6, $3D, $FE, $3D, $FE, $3D, $FE, $3D, $FE, $3D, $FE, $3D, $FE,
    $3D, $F6, $3D, $F6, $3C, $F6, $1C, $F6, $1C, $FE, $FC, $FD, $1B, $FE, $3A, $F6,
    $39, $FE, $39, $FE, $39, $FE, $38, $FE, $18, $FE, $18, $FE, $F8, $FD, $18, $FE,
    $19, $FE, $FA, $FD, $1A, $FE, $1B, $FE, $1B, $FE, $FB, $FD, $DC, $F5, $9E, $F5,
    $7D, $F5, $9D, $DD, $7D, $DD, $5C, $D5, $3B, $D5, $BA, $EC, $38, $FC, $14, $FB,
    $31, $F2, $8F, $E9, $6F, $E1, $B2, $E1, $14, $E2, $B7, $F2, $7A, $FB, $B8, $EC,
    $77, $F5, $37, $FE, $94, $FE, $D1, $FE, $ED, $F6, $0C, $FF, $0C, $FF, $AC, $FE,
    $6B, $FE, $EB, $FD, $AC, $FD, $6D, $FD, $6F, $FD, $71, $F5, $72, $F5, $B3, $F5,
    $D3, $F5, $D4, $FD, $F5, $FD, $16, $FE, $F7, $FD, $F8, $FD, $F9, $FD, $D9, $FD,
    $B9, $FD, $B9, $FD, $B9, $FD, $99, $FD, $79, $FD, $79, $FD, $79, $FD, $FF, $FF,
    $FF, $FF, $24, $DA, $24, $DA, $04, $DA, $24, $D2, $24, $D2, $44, $D2, $85, $D2,
    $C6, $DA, $28, $E3, $69, $EB, $69, $F3, $89, $F3, $A9, $FB, $E9, $FB, $08, $FC,
    $48, $F4, $68, $FC, $A7, $F4, $25, $F5, $A4, $F5, $24, $FE, $A5, $FE, $27, $FF,
    $89, $F7, $90, $F7, $75, $F7, $1C, $FF, $DC, $FE, $3B, $FE, $59, $FD, $B6, $F4,
    $54, $EC, $B5, $DB, $15, $CB, $98, $A3, $B8, $9B, $D8, $A3, $38, $A4, $78, $AC,
    $B8, $B4, $F8, $BC, $18, $C5, $39, $CD, $79, $DD, $7A, $E5, $9A, $ED, $DA, $F5,
    $FA, $F5, $1A, $FE, $1A, $FE, $1C, $FE, $1C, $FE, $1B, $FE, $1B, $FE, $FC, $FD,
    $FB, $FD, $FC, $FD, $FC, $FD, $1C, $FE, $1C, $FE, $1C, $F6, $1B, $F6, $1B, $F6,
    $1B, $F6, $1B, $FE, $3A, $FE, $78, $F6, $98, $F6, $B8, $F6, $B8, $F6, $B7, $FE,
    $D7, $FE, $D6, $FE, $B6, $FE, $B7, $FE, $D7, $FE, $B8, $FE, $98, $FE, $79, $FE,
    $7A, $FE, $5A, $FE, $3A, $FE, $DB, $FD, $BC, $FD, $DC, $ED, $BC, $E5, $7C, $D5,
    $5B, $D5, $1B, $DD, $BA, $E4, $B6, $EB, $D4, $EA, $F2, $F1, $91, $E9, $72, $E9,
    $93, $E1, $36, $E2, $BA, $E2, $DC, $E2, $9F, $EB, $DE, $FC, $DB, $FD, $97, $FE,
    $F3, $FE, $0F, $F7, $2C, $F7, $2B, $F7, $EA, $F6, $AA, $FE, $4A, $FE, $EB, $F5,
    $8C, $F5, $6D, $FD, $4F, $FD, $70, $F5, $91, $F5, $B2, $FD, $D3, $FD, $D4, $FD,
    $F4, $FD, $F5, $FD, $F6, $FD, $F7, $FD, $F7, $FD, $D7, $F5, $D8, $F5, $D8, $FD,
    $B7, $F5, $B8, $F5, $B8, $FD, $FF, $FF, $FF, $FF, $C3, $D1, $E3, $D1, $E3, $D1,
    $44, $DA, $A6, $E2, $07, $E3, $48, $EB, $68, $EB, $69, $F3, $89, $F3, $69, $F3,
    $89, $F3, $A9, $FB, $E8, $FB, $08, $FC, $48, $F4, $89, $FC, $E8, $FC, $86, $FD,
    $06, $FE, $A5, $FE, $06, $FF, $68, $FF, $A9, $FF, $B1, $F7, $96, $FF, $FC, $FE,
    $7B, $F6, $B9, $F5, $17, $F5, $75, $EC, $D3, $DB, $74, $D3, $36, $D3, $B8, $AB,
    $19, $AC, $5A, $B4, $99, $B4, $B9, $B4, $19, $BD, $5A, $CD, $7A, $D5, $7A, $DD,
    $BA, $E5, $BB, $ED, $DA, $ED, $DA, $F5, $FA, $F5, $1A, $FE, $1A, $FE, $FB, $FD,
    $1B, $FE, $FB, $FD, $FB, $FD, $FB, $FD, $FB, $FD, $FC, $FD, $FC, $FD, $1C, $FE,
    $1C, $F6, $1C, $F6, $1B, $F6, $1B, $F6, $3B, $FE, $3B, $FE, $5A, $FE, $79, $F6,
    $B8, $FE, $D9, $FE, $D8, $FE, $D8, $FE, $F8, $FE, $18, $FF, $18, $FF, $F8, $FE,
    $18, $FF, $F9, $FE, $D9, $FE, $99, $FE, $9A, $FE, $7A, $FE, $5A, $FE, $FB, $FD,
    $DC, $FD, $DC, $F5, $FD, $ED, $BD, $DD, $BC, $DD, $5C, $DD, $DA, $E4, $38, $FC,
    $56, $FB, $54, $FA, $13, $FA, $F4, $F1, $D5, $E9, $36, $E2, $78, $DA, $DD, $E2,
    $FC, $DA, $98, $DB, $D7, $E4, $16, $FE, $13, $FF, $70, $FF, $6D, $FF, $4B, $FF,
    $2B, $FF, $EB, $FE, $AB, $FE, $2C, $FE, $CD, $FD, $6E, $FD, $6F, $FD, $50, $F5,
    $71, $F5, $91, $F5, $B2, $F5, $B3, $F5, $D4, $F5, $D5, $FD, $F6, $FD, $F7, $FD,
    $F7, $FD, $D7, $F5, $D8, $FD, $D8, $FD, $D8, $FD, $D8, $FD, $D8, $FD, $FF, $FF,
    $FF, $FF, $E6, $DA, $E6, $DA, $E8, $E2, $E8, $E2, $48, $E3, $88, $E3, $88, $E3,
    $88, $E3, $89, $EB, $89, $EB, $AB, $FB, $8A, $FB, $AA, $FB, $09, $FC, $88, $F4,
    $C6, $F4, $47, $F5, $E4, $ED, $E1, $EE, $42, $EF, $45, $F7, $6B, $FF, $91, $FF,
    $76, $FF, $3A, $FF, $F9, $FE, $79, $FE, $D7, $FD, $F5, $FC, $75, $EC, $16, $DC,
    $D6, $C3, $F7, $B3, $17, $B4, $57, $B4, $76, $BC, $B7, $C4, $D7, $CC, $F7, $D4,
    $37, $DD, $57, $E5, $77, $F5, $98, $F5, $98, $FD, $B9, $FD, $B9, $FD, $B9, $FD,
    $D9, $FD, $DA, $FD, $DA, $FD, $FA, $FD, $FA, $FD, $FA, $FD, $FA, $FD, $FB, $FD,
    $FB, $FD, $FB, $FD, $1B, $FE, $1B, $FE, $1B, $F6, $1B, $F6, $1B, $F6, $1A, $F6,
    $3A, $FE, $5A, $FE, $59, $FE, $B8, $FE, $D8, $FE, $D8, $FE, $F8, $FE, $17, $FF,
    $37, $FF, $57, $FF, $57, $FF, $37, $FF, $37, $FF, $38, $FF, $18, $FF, $F9, $FE,
    $D9, $FE, $B9, $FE, $9A, $FE, $5A, $FE, $3B, $FE, $FB, $FD, $DB, $FD, $BC, $F5,
    $7C, $F5, $3C, $ED, $1B, $E5, $BA, $EC, $19, $EC, $77, $EB, $D6, $EA, $76, $F2,
    $55, $EA, $55, $EA, $55, $EA, $78, $EA, $DB, $EA, $DD, $EA, $FD, $DA, $BD, $E3,
    $FE, $F4, $5B, $FE, $57, $FF, $50, $FF, $4E, $FF, $4D, $FF, $0C, $F7, $AC, $F6,
    $6C, $F6, $2B, $EE, $EB, $F5, $6D, $FD, $4E, $FD, $4E, $FD, $6F, $FD, $90, $FD,
    $91, $FD, $B2, $FD, $D3, $FD, $B3, $FD, $B4, $F5, $D5, $FD, $D6, $F5, $D6, $F5,
    $D7, $F5, $F7, $FD, $F7, $FD, $FF, $FF, $FF, $FF, $27, $E3, $27, $E3, $E8, $E2,
    $E8, $E2, $27, $E3, $47, $DB, $88, $E3, $88, $E3, $A9, $EB, $AA, $F3, $8A, $FB,
    $AB, $FB, $0B, $FC, $6A, $FC, $C8, $FC, $27, $FD, $A8, $FD, $66, $FE, $42, $F7,
    $A4, $FF, $C7, $FF, $CC, $FF, $B1, $FF, $76, $FF, $F9, $FE, $B8, $F6, $17, $FE,
    $55, $F5, $73, $EC, $13, $E4, $F5, $DB, $F7, $CB, $58, $BC, $79, $BC, $98, $BC,
    $B7, $C4, $F8, $CC, $18, $D5, $38, $DD, $57, $E5, $77, $ED, $98, $F5, $98, $F5,
    $98, $FD, $B8, $FD, $B9, $FD, $B9, $FD, $B9, $FD, $BA, $FD, $DA, $FD, $DA, $FD,
    $DA, $FD, $FA, $FD, $FA, $FD, $FA, $FD, $FA, $FD, $FB, $FD, $1B, $FE, $FB, $FD,
    $FB, $F5, $1B, $F6, $1B, $FE, $3A, $FE, $5A, $FE, $5A, $FE, $7A, $FE, $B8, $FE,
    $D8, $FE, $D8, $FE, $18, $FF, $17, $FF, $37, $FF, $36, $FF, $36, $FF, $36, $FF,
    $37, $FF, $17, $FF, $18, $FF, $F9, $FE, $D9, $FE, $B9, $FE, $9A, $FE, $7A, $FE,
    $3B, $FE, $1B, $FE, $FB, $FD, $BC, $FD, $9C, $F5, $5C, $F5, $3C, $ED, $FB, $F4,
    $5A, $F4, $B8, $F3, $37, $F3, $B7, $FA, $96, $F2, $76, $F2, $76, $F2, $98, $EA,
    $BA, $E2, $DD, $EA, $1D, $DB, $1B, $D3, $99, $CB, $F6, $DC, $54, $EE, $92, $FF,
    $B0, $FF, $8E, $FF, $2C, $F7, $CC, $F6, $8D, $FE, $6C, $F6, $0C, $FE, $AE, $FD,
    $6F, $FD, $6F, $FD, $6F, $FD, $70, $FD, $70, $F5, $91, $F5, $B3, $FD, $B3, $F5,
    $B4, $F5, $B5, $F5, $D5, $F5, $D6, $F5, $D7, $F5, $D7, $F5, $F7, $FD, $FF, $FF,
    $FF, $FF, $29, $EB, $09, $EB, $29, $EB, $29, $E3, $29, $E3, $69, $EB, $89, $EB,
    $A9, $EB, $CA, $F3, $CA, $F3, $EA, $F3, $2A, $FC, $8A, $FC, $08, $F5, $86, $E5,
    $45, $E6, $04, $E7, $85, $EF, $C6, $EF, $E8, $F7, $F0, $FF, $B5, $FF, $1A, $FF,
    $9A, $FE, $1A, $FE, $B9, $FD, $17, $FD, $95, $EC, $F5, $DB, $B5, $D3, $F5, $CB,
    $36, $CC, $94, $C4, $B4, $C4, $B4, $DC, $D4, $E4, $F4, $EC, $15, $F5, $36, $FD,
    $56, $FD, $56, $FD, $76, $FD, $97, $FD, $B7, $FD, $B7, $F5, $B7, $F5, $B7, $F5,
    $B8, $FD, $B8, $FD, $B8, $FD, $F9, $FD, $F9, $F5, $F9, $F5, $F9, $F5, $19, $F6,
    $19, $FE, $1A, $FE, $1A, $FE, $1A, $F6, $1A, $F6, $3A, $FE, $3A, $FE, $59, $FE,
    $79, $FE, $79, $FE, $99, $FE, $B8, $FE, $D7, $FE, $D8, $FE, $F7, $FE, $17, $FF,
    $17, $FF, $16, $FF, $16, $F7, $36, $F7, $36, $FF, $37, $FF, $38, $FF, $19, $FF,
    $F9, $F6, $F9, $F6, $DA, $F6, $7B, $FE, $5B, $FE, $3A, $FE, $1B, $F6, $FB, $F5,
    $DC, $F5, $9C, $F5, $5C, $F5, $3C, $F5, $DB, $EC, $7A, $E4, $19, $E4, $B8, $E3,
    $36, $E3, $D5, $F2, $B5, $EA, $D5, $E2, $B6, $E2, $DA, $EA, $FD, $EA, $BF, $E2,
    $9E, $DA, $1E, $DB, $DE, $E3, $5D, $FD, $7A, $FE, $76, $FF, $91, $FF, $4E, $FF,
    $2D, $F7, $EE, $EE, $AD, $E6, $0D, $FE, $CD, $FD, $AD, $F5, $8D, $F5, $8D, $F5,
    $6E, $F5, $8F, $F5, $91, $FD, $92, $FD, $B3, $FD, $B4, $FD, $B5, $F5, $B5, $FD,
    $D6, $F5, $D7, $FD, $F7, $FD, $FF, $FF, $FF, $FF, $2A, $F3, $2A, $EB, $2A, $EB,
    $4A, $EB, $6A, $EB, $AA, $F3, $EA, $F3, $EA, $F3, $EB, $F3, $0B, $FC, $2B, $FC,
    $6B, $FC, $CA, $FC, $49, $F5, $08, $F6, $E7, $FE, $A6, $FF, $E7, $F7, $E8, $F7,
    $E9, $FF, $D0, $FF, $54, $F7, $B9, $F6, $39, $F6, $98, $F5, $37, $F5, $75, $EC,
    $34, $E4, $D5, $DB, $D5, $DB, $16, $D4, $57, $CC, $B5, $CC, $D4, $CC, $F5, $E4,
    $15, $ED, $35, $F5, $56, $FD, $56, $FD, $76, $FD, $76, $FD, $97, $FD, $97, $FD,
    $B7, $FD, $B7, $FD, $B7, $FD, $B8, $FD, $B8, $FD, $B8, $FD, $B8, $FD, $F9, $FD,
    $F9, $F5, $F9, $F5, $19, $FE, $19, $FE, $19, $FE, $1A, $FE, $1A, $FE, $3A, $FE,
    $3A, $FE, $3A, $FE, $5A, $FE, $59, $FE, $79, $FE, $79, $FE, $99, $FE, $B8, $FE,
    $D7, $FE, $D8, $FE, $F7, $FE, $F7, $FE, $16, $F7, $16, $F7, $16, $F7, $16, $F7,
    $36, $F7, $37, $FF, $18, $FF, $19, $FF, $F9, $FE, $F9, $FE, $DA, $FE, $7B, $FE,
    $5B, $FE, $5B, $FE, $3B, $FE, $1C, $FE, $FC, $F5, $BC, $FD, $7D, $FD, $5D, $F5,
    $1C, $F5, $DB, $EC, $5B, $EC, $19, $F4, $98, $F3, $16, $FB, $F6, $F2, $F6, $EA,
    $D7, $E2, $DA, $EA, $DC, $EA, $DF, $EA, $1F, $E3, $1F, $DB, $3C, $D3, $17, $D4,
    $76, $ED, $F4, $FE, $92, $FF, $B0, $FF, $8F, $FF, $2F, $F7, $EE, $EE, $2E, $FE,
    $ED, $FD, $CD, $FD, $AD, $FD, $AE, $FD, $8F, $FD, $8F, $FD, $90, $FD, $91, $FD,
    $92, $F5, $93, $F5, $94, $F5, $B5, $F5, $D6, $F5, $D7, $FD, $F7, $FD, $FF, $FF,
    $FF, $FF, $88, $EB, $88, $EB, $49, $EB, $6A, $EB, $8A, $F3, $CB, $F3, $EB, $FB,
    $0B, $F4, $4B, $F4, $8A, $EC, $C9, $E4, $4A, $E5, $CA, $ED, $4B, $EE, $EC, $FE,
    $8D, $FF, $CD, $FF, $AD, $FF, $54, $FF, $D7, $FE, $79, $FE, $18, $FE, $B7, $FD,
    $56, $FD, $F4, $F4, $B3, $EC, $13, $DC, $F4, $DB, $15, $DC, $35, $DC, $74, $DC,
    $B3, $E4, $F3, $E4, $13, $E5, $34, $F5, $54, $F5, $75, $FD, $95, $FD, $96, $FD,
    $96, $FD, $B6, $FD, $B6, $FD, $B6, $FD, $B6, $FD, $D6, $FD, $D6, $FD, $F7, $FD,
    $F7, $FD, $17, $FE, $17, $FE, $F8, $FD, $F8, $FD, $18, $FE, $18, $FE, $38, $FE,
    $38, $F6, $59, $FE, $59, $FE, $59, $FE, $59, $FE, $59, $FE, $78, $FE, $78, $FE,
    $98, $FE, $B8, $FE, $B8, $FE, $D7, $FE, $D7, $FE, $D7, $FE, $D6, $FE, $D6, $FE,
    $F6, $FE, $F6, $FE, $F6, $FE, $F6, $FE, $F7, $FE, $17, $FF, $18, $FF, $18, $FF,
    $19, $FF, $F9, $FE, $F9, $FE, $99, $FE, $9A, $FE, $BA, $FE, $BA, $F6, $9A, $F6,
    $7A, $EE, $3B, $F6, $FB, $F5, $DB, $F5, $9B, $F5, $5A, $F5, $1A, $F5, $B9, $EC,
    $58, $EC, $F7, $E3, $96, $E3, $57, $EB, $58, $EB, $38, $EB, $F9, $E2, $FA, $E2,
    $3C, $EB, $3D, $EB, $3C, $E3, $3C, $E3, $DD, $E3, $BE, $F4, $DD, $FD, $DB, $FE,
    $58, $FF, $92, $FF, $51, $F7, $D0, $FE, $6F, $F6, $2E, $F6, $0E, $F6, $EE, $F5,
    $CF, $F5, $AF, $FD, $B0, $FD, $90, $FD, $91, $FD, $92, $FD, $93, $FD, $B4, $FD,
    $B4, $FD, $D5, $FD, $F6, $FD, $FF, $FF, $FF, $FF, $A9, $F3, $A9, $F3, $8A, $F3,
    $AB, $F3, $EB, $FB, $0C, $FC, $2C, $FC, $4C, $FC, $AC, $FC, $0C, $FD, $6C, $FD,
    $0D, $FE, $CE, $FE, $4F, $FF, $AF, $FF, $CE, $FF, $AD, $FF, $6C, $FF, $B2, $FE,
    $35, $FE, $B6, $F5, $55, $F5, $15, $F5, $D4, $EC, $72, $E4, $11, $DC, $F3, $D3,
    $F4, $DB, $35, $DC, $56, $DC, $94, $E4, $D4, $E4, $34, $ED, $54, $F5, $54, $FD,
    $75, $FD, $95, $FD, $95, $FD, $96, $FD, $B6, $FD, $B6, $FD, $B6, $FD, $D6, $FD,
    $B6, $FD, $D6, $FD, $D7, $FD, $F7, $FD, $17, $FE, $17, $FE, $17, $FE, $F8, $FD,
    $18, $FE, $18, $FE, $18, $FE, $38, $FE, $38, $F6, $59, $FE, $59, $FE, $59, $FE,
    $59, $FE, $59, $FE, $78, $FE, $98, $FE, $B8, $FE, $B8, $FE, $B8, $FE, $D7, $FE,
    $D7, $FE, $D7, $FE, $D6, $FE, $D6, $FE, $D6, $FE, $F6, $FE, $F6, $FE, $F6, $FE,
    $F6, $FE, $F7, $FE, $F8, $FE, $F8, $FE, $F9, $FE, $F9, $FE, $F9, $FE, $BA, $FE,
    $9A, $FE, $DA, $FE, $DB, $FE, $BB, $F6, $9B, $F6, $7B, $FE, $3B, $FE, $FB, $FD,
    $DC, $FD, $9B, $FD, $5B, $FD, $1B, $F5, $BA, $F4, $59, $F4, $F8, $F3, $98, $F3,
    $78, $EB, $39, $EB, $19, $EB, $1B, $EB, $1B, $EB, $3D, $EB, $5D, $EB, $5D, $E3,
    $9C, $DB, $1C, $DC, $1A, $ED, $39, $FE, $F6, $FE, $92, $FF, $B2, $FF, $31, $FF,
    $F0, $FE, $90, $FE, $4F, $F6, $0F, $F6, $CF, $F5, $AF, $FD, $B0, $FD, $90, $FD,
    $91, $FD, $92, $FD, $93, $FD, $94, $FD, $B4, $F5, $D5, $FD, $D5, $FD, $FF, $FF,
    $FF, $FF, $E9, $EB, $E9, $EB, $69, $EC, $69, $EC, $6A, $F4, $AB, $FC, $CC, $FC,
    $2C, $FD, $AC, $FD, $0C, $F6, $CD, $F6, $0E, $FF, $71, $FF, $72, $FF, $D4, $FE,
    $15, $FE, $55, $FD, $F6, $FC, $96, $FC, $75, $FC, $34, $FC, $13, $FC, $F3, $FB,
    $D3, $EB, $F2, $D3, $11, $CC, $71, $CC, $91, $D4, $92, $E4, $B2, $EC, $B3, $F4,
    $D3, $F4, $32, $F5, $53, $F5, $94, $FD, $94, $FD, $B5, $FD, $B5, $FD, $D5, $FD,
    $D5, $F5, $F6, $F5, $F6, $F5, $16, $F6, $16, $F6, $16, $F6, $17, $F6, $17, $FE,
    $18, $FE, $F8, $FD, $F8, $FD, $18, $FE, $18, $FE, $18, $FE, $38, $FE, $37, $FE,
    $57, $FE, $57, $FE, $58, $FE, $78, $FE, $78, $FE, $78, $FE, $97, $FE, $97, $F6,
    $B7, $F6, $D7, $F6, $D7, $F6, $D6, $FE, $D6, $F6, $B6, $F6, $B5, $F6, $B5, $FE,
    $B5, $FE, $B5, $FE, $D5, $FE, $D6, $FE, $D6, $FE, $D6, $FE, $D7, $FE, $D7, $FE,
    $F8, $FE, $D8, $FE, $F8, $F6, $38, $EF, $38, $EF, $F8, $FE, $D9, $FE, $B9, $FE,
    $B9, $FE, $D9, $FE, $B9, $FE, $99, $F6, $79, $F6, $39, $FE, $F9, $FD, $9A, $FD,
    $5A, $FD, $FA, $F4, $9A, $F4, $19, $FC, $B8, $F3, $99, $EB, $99, $EB, $BA, $EB,
    $99, $E3, $79, $EB, $99, $EB, $5B, $EB, $7C, $EB, $BE, $F3, $3F, $F4, $FE, $F4,
    $BD, $FD, $7B, $FE, $19, $FF, $74, $FF, $54, $FF, $13, $F7, $B2, $F6, $51, $F6,
    $31, $F6, $F0, $F5, $D0, $FD, $B0, $FD, $B1, $FD, $B1, $FD, $91, $FD, $B2, $FD,
    $B2, $FD, $D3, $FD, $F3, $FD, $FF, $FF, $FF, $FF, $29, $F4, $2A, $F4, $69, $EC,
    $69, $EC, $6A, $F4, $AB, $FC, $EC, $FC, $4D, $FD, $CD, $FD, $4D, $FE, $AD, $F6,
    $AD, $F6, $8D, $EE, $4E, $E6, $6F, $ED, $AF, $E4, $CF, $E3, $90, $DB, $B2, $E3,
    $D3, $EB, $B2, $F3, $92, $F3, $72, $EB, $92, $E3, $F2, $D3, $52, $CC, $B2, $D4,
    $D2, $D4, $F3, $EC, $F3, $F4, $F4, $FC, $14, $FD, $73, $FD, $94, $FD, $B4, $FD,
    $B4, $FD, $B5, $FD, $D5, $FD, $D5, $FD, $F6, $FD, $16, $FE, $16, $FE, $36, $F6,
    $36, $F6, $36, $F6, $37, $FE, $38, $FE, $38, $FE, $19, $FE, $F8, $FD, $18, $FE,
    $38, $FE, $38, $FE, $38, $FE, $58, $FE, $78, $FE, $78, $FE, $78, $FE, $78, $FE,
    $78, $FE, $78, $FE, $98, $FE, $B8, $FE, $B7, $F6, $B7, $F6, $B6, $F6, $D6, $F6,
    $D6, $F6, $B6, $F6, $B5, $F6, $B5, $FE, $B5, $FE, $B5, $FE, $B5, $FE, $B5, $FE,
    $B5, $FE, $B6, $FE, $D7, $FE, $D7, $FE, $D8, $FE, $D8, $FE, $F8, $F6, $38, $EF,
    $18, $EF, $F8, $FE, $D9, $FE, $B9, $FE, $B9, $FE, $D9, $FE, $D9, $FE, $B9, $FE,
    $BA, $FE, $7A, $FE, $3A, $FE, $DB, $FD, $9B, $FD, $5B, $FD, $1B, $FD, $5A, $FC,
    $3A, $FC, $FA, $FB, $BA, $EB, $99, $E3, $99, $E3, $99, $EB, $BA, $F3, $BC, $F3,
    $BD, $FB, $DE, $F3, $1E, $EC, $BD, $EC, $7C, $F5, $1A, $F6, $97, $F6, $54, $FF,
    $54, $FF, $34, $FF, $F3, $FE, $92, $FE, $51, $FE, $11, $FE, $D0, $FD, $B0, $FD,
    $B1, $FD, $B1, $FD, $91, $FD, $B2, $FD, $B2, $FD, $D3, $FD, $D3, $FD, $FF, $FF,
    $FF, $FF, $68, $F3, $68, $F3, $28, $EB, $48, $F3, $89, $F3, $EA, $F3, $4C, $FC,
    $AD, $FC, $EE, $FC, $EF, $FC, $F0, $FC, $B0, $FC, $50, $FC, $AF, $FB, $2F, $F3,
    $EF, $F2, $D0, $F2, $F0, $FA, $50, $FB, $70, $F3, $6F, $EB, $6F, $E3, $AF, $DB,
    $EF, $DB, $30, $E4, $70, $EC, $91, $F4, $D1, $F4, $F2, $FC, $32, $FD, $52, $FD,
    $73, $FD, $93, $FD, $93, $FD, $B4, $FD, $D4, $FD, $D5, $FD, $F5, $FD, $F5, $FD,
    $F5, $FD, $F6, $FD, $16, $FE, $16, $FE, $36, $F6, $36, $FE, $37, $FE, $57, $FE,
    $57, $FE, $57, $FE, $77, $FE, $77, $FE, $77, $FE, $77, $FE, $77, $FE, $77, $FE,
    $77, $FE, $77, $FE, $77, $FE, $77, $FE, $76, $FE, $76, $FE, $76, $FE, $76, $FE,
    $96, $FE, $96, $FE, $95, $FE, $95, $FE, $95, $FE, $95, $FE, $95, $FE, $95, $FE,
    $95, $FE, $95, $FE, $95, $FE, $95, $FE, $95, $FE, $96, $FE, $B6, $FE, $B7, $FE,
    $B7, $FE, $B7, $FE, $B7, $FE, $D7, $FE, $F7, $FE, $F8, $FE, $F8, $FE, $F8, $FE,
    $F8, $FE, $D8, $FE, $D8, $FE, $D9, $FE, $B8, $FE, $B9, $FE, $98, $FE, $78, $FE,
    $58, $FE, $17, $F6, $F7, $F5, $98, $FD, $39, $F5, $F8, $EC, $78, $EC, $38, $E4,
    $F9, $EB, $D9, $EB, $DA, $EB, $DB, $F3, $FB, $F3, $1C, $F4, $5C, $F4, $9C, $F4,
    $DD, $F4, $3E, $FD, $9E, $FD, $5A, $FE, $99, $FE, $B9, $FE, $D8, $FE, $B6, $FE,
    $94, $F6, $72, $F6, $52, $F6, $31, $F6, $11, $F6, $F1, $F5, $D1, $F5, $B1, $F5,
    $B2, $FD, $B2, $FD, $B2, $FD, $FF, $FF, $FF, $FF, $E6, $E2, $E6, $E2, $E7, $E2,
    $07, $EB, $48, $EB, $A9, $EB, $EA, $EB, $2B, $EC, $4C, $F4, $4D, $F4, $0D, $EC,
    $CD, $EB, $8D, $EB, $2D, $EB, $EE, $EA, $CF, $F2, $CF, $F2, $D0, $FA, $30, $F3,
    $4F, $F3, $6F, $EB, $8F, $E3, $CF, $E3, $10, $E4, $50, $E4, $91, $EC, $B1, $F4,
    $D1, $F4, $F2, $FC, $32, $FD, $52, $FD, $73, $FD, $93, $FD, $B3, $FD, $B4, $FD,
    $D4, $FD, $D5, $FD, $F5, $FD, $F5, $FD, $F5, $FD, $F6, $FD, $16, $FE, $16, $FE,
    $16, $F6, $16, $F6, $37, $FE, $37, $FE, $37, $FE, $37, $FE, $57, $FE, $77, $FE,
    $77, $FE, $77, $FE, $77, $FE, $77, $FE, $77, $FE, $57, $FE, $57, $FE, $77, $FE,
    $76, $FE, $76, $FE, $76, $FE, $76, $FE, $75, $FE, $96, $FE, $95, $FE, $94, $FE,
    $94, $FE, $94, $FE, $94, $FE, $94, $FE, $94, $FE, $94, $FE, $94, $FE, $95, $FE,
    $95, $FE, $95, $FE, $96, $FE, $96, $FE, $B6, $FE, $B7, $FE, $B7, $FE, $D7, $F6,
    $D7, $FE, $F7, $FE, $F7, $FE, $F8, $FE, $F8, $FE, $D8, $FE, $D8, $FE, $D9, $FE,
    $D9, $FE, $B9, $FE, $98, $FE, $78, $FE, $58, $FE, $38, $FE, $17, $FE, $D9, $FD,
    $7A, $FD, $59, $FD, $F9, $F4, $BA, $F4, $5A, $F4, $1A, $F4, $FB, $F3, $FC, $F3,
    $1C, $F4, $3C, $F4, $7C, $F4, $9C, $F4, $DD, $F4, $1E, $F5, $5D, $F5, $F9, $F5,
    $58, $FE, $78, $FE, $B7, $FE, $B6, $FE, $B4, $FE, $93, $F6, $72, $F6, $31, $F6,
    $11, $F6, $F1, $F5, $D1, $F5, $B1, $FD, $B2, $FD, $B2, $FD, $B2, $FD, $FF, $FF,
    $FF, $FF, $E6, $E2, $C6, $DA, $C7, $E2, $E7, $E2, $08, $E3, $28, $EB, $69, $EB,
    $8A, $EB, $8A, $F3, $6A, $F3, $4B, $EB, $2B, $EB, $0B, $EB, $0C, $EB, $2D, $F3,
    $2D, $F3, $2E, $FB, $4E, $F3, $6E, $F3, $8D, $EB, $AE, $E3, $CD, $E3, $2E, $E4,
    $6F, $E4, $B0, $EC, $D0, $EC, $10, $F5, $10, $F5, $30, $FD, $51, $FD, $71, $FD,
    $71, $FD, $B2, $F5, $B2, $FD, $D3, $FD, $D3, $FD, $D3, $FD, $F3, $FD, $F4, $FD,
    $14, $FE, $F4, $FD, $14, $FE, $15, $FE, $35, $FE, $35, $FE, $35, $FE, $35, $FE,
    $35, $FE, $35, $FE, $56, $FE, $56, $FE, $56, $FE, $56, $FE, $56, $FE, $56, $FE,
    $56, $FE, $55, $FE, $55, $FE, $75, $FE, $75, $FE, $75, $FE, $74, $FE, $74, $FE,
    $74, $FE, $74, $FE, $74, $FE, $74, $FE, $74, $FE, $74, $FE, $73, $FE, $73, $FE,
    $74, $FE, $94, $FE, $94, $FE, $74, $FE, $74, $FE, $94, $FE, $95, $FE, $95, $FE,
    $95, $FE, $96, $FE, $96, $FE, $96, $FE, $B6, $FE, $B7, $FE, $B7, $FE, $B7, $FE,
    $D7, $FE, $D8, $FE, $D8, $FE, $D8, $FE, $D8, $FE, $B8, $FE, $B8, $FE, $98, $FE,
    $78, $FE, $78, $FE, $58, $F6, $18, $FE, $D8, $FD, $D8, $FD, $99, $FD, $39, $FD,
    $F9, $FC, $99, $F4, $59, $F4, $39, $F4, $5A, $F4, $5B, $F4, $9B, $F4, $BB, $F4,
    $DB, $F4, $FC, $FC, $3C, $FD, $9A, $F5, $D9, $F5, $1A, $FE, $59, $FE, $78, $FE,
    $76, $FE, $55, $FE, $53, $FE, $33, $FE, $12, $FE, $F2, $FD, $D1, $FD, $B1, $FD,
    $B1, $FD, $B1, $FD, $B1, $FD, $FF, $FF, $FF, $FF, $E6, $E2, $C6, $DA, $C7, $E2,
    $E7, $E2, $08, $E3, $28, $E3, $49, $E3, $49, $EB, $49, $EB, $29, $E3, $2A, $EB,
    $2B, $EB, $0B, $EB, $0C, $F3, $2D, $F3, $4E, $FB, $4E, $FB, $4E, $F3, $8E, $F3,
    $AE, $F3, $EF, $EB, $2F, $EC, $6F, $EC, $B0, $EC, $F0, $F4, $10, $F5, $31, $FD,
    $30, $FD, $31, $FD, $51, $FD, $71, $FD, $71, $FD, $B2, $F5, $B2, $FD, $B3, $FD,
    $D3, $FD, $D3, $FD, $F3, $FD, $F4, $FD, $F4, $FD, $F4, $FD, $14, $FE, $15, $FE,
    $15, $F6, $35, $FE, $35, $FE, $35, $FE, $35, $FE, $35, $FE, $56, $FE, $55, $FE,
    $55, $FE, $55, $FE, $55, $FE, $55, $FE, $55, $FE, $55, $FE, $55, $FE, $55, $FE,
    $75, $FE, $75, $FE, $74, $FE, $74, $FE, $74, $FE, $74, $FE, $74, $FE, $74, $FE,
    $74, $F6, $73, $F6, $73, $F6, $73, $F6, $73, $F6, $73, $F6, $73, $F6, $74, $F6,
    $74, $F6, $74, $F6, $75, $F6, $75, $F6, $75, $FE, $75, $FE, $96, $FE, $76, $F6,
    $96, $F6, $96, $F6, $96, $FE, $97, $F6, $B7, $FE, $B7, $FE, $D7, $FE, $D8, $FE,
    $D8, $FE, $B8, $FE, $B8, $FE, $98, $FE, $78, $FE, $78, $FE, $58, $F6, $18, $FE,
    $D8, $FD, $D8, $FD, $99, $FD, $59, $FD, $3A, $FD, $FA, $FC, $BB, $FC, $7A, $FC,
    $7A, $FC, $7B, $F4, $9B, $F4, $DB, $FC, $FC, $FC, $FC, $FC, $1C, $F5, $7A, $F5,
    $B9, $F5, $D9, $F5, $38, $FE, $57, $FE, $76, $FE, $55, $FE, $53, $FE, $33, $FE,
    $32, $FE, $12, $FE, $D1, $FD, $D1, $FD, $D1, $FD, $B1, $FD, $B1, $FD, $FF, $FF,
    $FF, $FF, $06, $E3, $E5, $DA, $E7, $DA, $E7, $DA, $E7, $E2, $08, $E3, $09, $E3,
    $29, $EB, $29, $EB, $29, $EB, $2A, $F3, $4A, $F3, $4A, $F3, $6B, $F3, $8B, $EB,
    $AB, $EB, $AB, $EB, $CC, $EB, $0C, $EC, $4C, $EC, $8D, $F4, $CE, $F4, $0E, $F5,
    $2E, $F5, $4F, $F5, $6F, $F5, $6F, $FD, $6F, $FD, $8F, $FD, $90, $FD, $B0, $FD,
    $B0, $FD, $D0, $F5, $D0, $FD, $D1, $FD, $D2, $FD, $F2, $FD, $F2, $FD, $F2, $FD,
    $F2, $FD, $13, $FE, $13, $F6, $33, $FE, $33, $FE, $13, $FE, $34, $FE, $34, $FE,
    $34, $FE, $34, $FE, $54, $FE, $54, $FE, $54, $FE, $34, $FE, $34, $FE, $34, $F6,
    $13, $F6, $13, $F6, $12, $F6, $32, $F6, $32, $F6, $53, $FE, $73, $FE, $72, $FE,
    $72, $FE, $52, $FE, $52, $FE, $52, $EE, $32, $EE, $32, $EE, $32, $EE, $52, $EE,
    $52, $F6, $72, $F6, $72, $F6, $73, $F6, $73, $F6, $73, $F6, $53, $FE, $54, $FE,
    $54, $F6, $33, $F6, $33, $F6, $33, $F6, $34, $F6, $34, $F6, $34, $F6, $55, $F6,
    $76, $FE, $76, $FE, $B7, $FE, $B7, $FE, $B8, $FE, $B8, $FE, $B8, $FE, $98, $FE,
    $98, $FE, $78, $F6, $58, $F6, $57, $F6, $36, $F6, $17, $F6, $D7, $F5, $B7, $FD,
    $98, $FD, $58, $FD, $58, $FD, $18, $FD, $F9, $FC, $D9, $FC, $D9, $FC, $F9, $FC,
    $FA, $FC, $1A, $FD, $1A, $FD, $3A, $F5, $59, $F5, $79, $F5, $D9, $FD, $F8, $FD,
    $38, $FE, $37, $FE, $36, $FE, $35, $FE, $14, $FE, $F3, $FD, $F3, $FD, $F2, $FD,
    $F2, $FD, $F2, $FD, $D2, $FD, $FF, $FF, $FF, $FF, $47, $EB, $26, $E3, $08, $E3,
    $08, $E3, $08, $E3, $08, $E3, $29, $EB, $49, $EB, $4A, $F3, $6A, $F3, $4A, $F3,
    $6B, $FB, $8B, $FB, $AC, $FB, $CC, $F3, $EC, $F3, $0D, $F4, $2D, $F4, $4D, $F4,
    $8D, $F4, $CE, $FC, $0F, $FD, $4F, $FD, $4F, $F5, $8F, $FD, $90, $FD, $90, $FD,
    $B0, $FD, $B0, $FD, $B0, $FD, $D0, $FD, $D0, $FD, $F1, $FD, $F1, $FD, $D2, $FD,
    $F2, $FD, $F2, $FD, $F2, $FD, $F2, $FD, $F2, $FD, $13, $FE, $13, $F6, $33, $FE,
    $33, $FE, $13, $FE, $34, $FE, $34, $FE, $33, $FE, $34, $FE, $54, $FE, $33, $FE,
    $12, $F6, $12, $F6, $F2, $F5, $F2, $ED, $F2, $ED, $D3, $ED, $D1, $E5, $D1, $E5,
    $12, $EE, $32, $F6, $53, $FE, $72, $FE, $52, $FE, $32, $F6, $31, $F6, $11, $E6,
    $11, $E6, $F1, $E5, $F1, $E5, $F1, $E5, $11, $E6, $31, $EE, $52, $F6, $73, $F6,
    $53, $F6, $53, $EE, $32, $F6, $13, $F6, $13, $EE, $F3, $ED, $F3, $ED, $F2, $E5,
    $D3, $E5, $D3, $E5, $D3, $E5, $F3, $ED, $15, $EE, $35, $F6, $56, $F6, $77, $FE,
    $97, $FE, $98, $FE, $B8, $FE, $B8, $FE, $98, $FE, $98, $FE, $78, $F6, $57, $FE,
    $37, $FE, $17, $F6, $F7, $FD, $D8, $FD, $98, $FD, $58, $FD, $58, $FD, $39, $FD,
    $19, $FD, $F9, $FC, $F9, $FC, $FA, $FC, $1A, $FD, $1A, $FD, $3A, $FD, $3A, $F5,
    $5A, $F5, $79, $F5, $B8, $F5, $D8, $F5, $F7, $FD, $16, $FE, $15, $FE, $15, $FE,
    $14, $FE, $F3, $FD, $D3, $FD, $D2, $FD, $D2, $FD, $D2, $FD, $D1, $FD, $FF, $FF,
    $FF, $FF, $A7, $EB, $87, $E3, $88, $E3, $88, $E3, $88, $E3, $89, $E3, $A9, $E3,
    $CA, $EB, $CA, $F3, $CA, $F3, $AA, $EB, $CB, $EB, $0B, $F4, $2B, $EC, $4B, $EC,
    $8B, $EC, $AC, $EC, $CC, $EC, $CC, $F4, $ED, $F4, $4D, $FD, $6E, $FD, $8E, $FD,
    $AE, $FD, $CE, $F5, $CF, $FD, $CF, $FD, $CF, $FD, $EF, $FD, $EF, $FD, $F0, $FD,
    $F0, $FD, $10, $FE, $10, $FE, $11, $FE, $11, $FE, $11, $FE, $11, $FE, $11, $FE,
    $11, $FE, $32, $F6, $32, $FE, $32, $FE, $32, $FE, $32, $FE, $32, $FE, $32, $FE,
    $32, $FE, $12, $FE, $32, $F6, $11, $F6, $F1, $ED, $D1, $ED, $D1, $ED, $D1, $ED,
    $D0, $E5, $B0, $E5, $90, $DD, $8F, $DD, $F0, $ED, $30, $F6, $51, $FE, $51, $F6,
    $10, $EE, $F0, $ED, $F0, $E5, $10, $E6, $F0, $DD, $CF, $DD, $AF, $D5, $AF, $DD,
    $CF, $DD, $F0, $ED, $30, $F6, $52, $FE, $52, $F6, $31, $F6, $11, $EE, $F1, $E5,
    $D0, $E5, $B0, $E5, $B1, $DD, $91, $DD, $90, $DD, $70, $DD, $70, $D5, $71, $D5,
    $91, $DD, $B2, $DD, $13, $E6, $34, $F6, $56, $F6, $96, $FE, $97, $FE, $98, $FE,
    $98, $FE, $98, $FE, $77, $FE, $77, $FE, $56, $F6, $36, $F6, $16, $F6, $F6, $F5,
    $D7, $F5, $B6, $F5, $77, $F5, $77, $F5, $57, $F5, $37, $F5, $37, $F5, $18, $F5,
    $38, $FD, $39, $FD, $59, $FD, $79, $FD, $98, $FD, $98, $FD, $B8, $FD, $D7, $FD,
    $D7, $FD, $D6, $FD, $F6, $FD, $D5, $FD, $D5, $FD, $B4, $FD, $B3, $FD, $B3, $FD,
    $B2, $FD, $B2, $F5, $B2, $F5, $FF, $FF, $FF, $FF, $E8, $F3, $C8, $EB, $C9, $EB,
    $C9, $EB, $C9, $EB, $C9, $EB, $CA, $EB, $EA, $F3, $EB, $F3, $EB, $F3, $0B, $FC,
    $2C, $FC, $4C, $FC, $8C, $FC, $AC, $F4, $CC, $F4, $0D, $F5, $2D, $F5, $2D, $FD,
    $2D, $FD, $4D, $FD, $6E, $FD, $8E, $FD, $AE, $FD, $CE, $F5, $CE, $F5, $CF, $FD,
    $CF, $FD, $EF, $FD, $EF, $FD, $F0, $FD, $F0, $FD, $10, $FE, $10, $FE, $11, $FE,
    $11, $FE, $11, $FE, $11, $FE, $11, $FE, $11, $FE, $32, $F6, $32, $FE, $32, $FE,
    $32, $FE, $32, $FE, $32, $FE, $32, $FE, $32, $FE, $12, $F6, $F1, $ED, $B0, $E5,
    $B0, $E5, $B0, $E5, $D1, $ED, $F1, $ED, $92, $CD, $72, $CD, $B0, $DD, $AF, $DD,
    $F0, $ED, $30, $F6, $51, $F6, $10, $EE, $CF, $E5, $8F, $DD, $AF, $E5, $F0, $E5,
    $10, $E6, $F0, $DD, $AF, $DD, $6E, $D5, $4E, $CD, $6F, $DD, $F0, $E5, $31, $F6,
    $31, $F6, $11, $EE, $F1, $ED, $D0, $E5, $D0, $E5, $D0, $E5, $D0, $E5, $B1, $E5,
    $91, $DD, $70, $DD, $70, $D5, $4F, $CD, $30, $C5, $30, $CD, $72, $CD, $D3, $E5,
    $15, $EE, $56, $F6, $57, $FE, $77, $FE, $77, $FE, $77, $FE, $77, $FE, $77, $FE,
    $57, $FE, $36, $F6, $17, $F6, $17, $FE, $F7, $FD, $D7, $FD, $B7, $FD, $97, $FD,
    $78, $FD, $57, $FD, $38, $F5, $18, $F5, $18, $F5, $38, $FD, $38, $FD, $79, $FD,
    $98, $FD, $B9, $FD, $D8, $FD, $D8, $FD, $F7, $FD, $F6, $FD, $16, $FE, $D5, $FD,
    $B5, $FD, $B4, $FD, $93, $FD, $93, $F5, $92, $F5, $91, $F5, $91, $F5, $FF, $FF,
    $FF, $FF, $28, $EC, $27, $EC, $08, $F4, $08, $F4, $08, $EC, $29, $EC, $49, $EC,
    $4A, $EC, $4A, $EC, $6B, $EC, $8B, $F4, $AC, $F4, $CC, $F4, $EC, $F4, $0D, $F5,
    $2C, $F5, $4C, $F5, $4D, $F5, $6D, $FD, $6D, $FD, $8E, $FD, $AE, $FD, $AE, $FD,
    $CE, $FD, $EE, $FD, $EE, $FD, $EF, $FD, $0F, $FE, $EF, $FD, $EF, $FD, $F0, $FD,
    $10, $FE, $10, $FE, $F0, $F5, $10, $F6, $10, $FE, $30, $FE, $30, $FE, $51, $FE,
    $51, $FE, $51, $FE, $51, $FE, $71, $FE, $71, $FE, $51, $FE, $51, $FE, $51, $FE,
    $31, $FE, $F0, $ED, $50, $C5, $D2, $9C, $D2, $A4, $D3, $9C, $B4, $8C, $75, $7C,
    $95, $7C, $B1, $D5, $EF, $ED, $CF, $E5, $0F, $EE, $2F, $F6, $0F, $F6, $52, $BD,
    $13, $9D, $13, $9D, $F5, $94, $D5, $8C, $F2, $9C, $90, $CD, $EE, $E5, $6E, $D5,
    $2D, $C5, $4E, $CD, $AE, $DD, $8F, $DD, $F0, $AC, $2F, $8C, $CE, $83, $ED, $52,
    $CD, $52, $AD, $4A, $8C, $4A, $2D, $63, $AD, $7B, $4E, $9C, $4F, $C5, $6F, $D5,
    $2F, $CD, $0F, $C5, $0F, $C5, $30, $CD, $92, $DD, $14, $EE, $35, $F6, $55, $FE,
    $56, $FE, $56, $FE, $56, $FE, $37, $FE, $37, $FE, $37, $FE, $37, $FE, $17, $FE,
    $17, $FE, $F7, $FD, $D7, $F5, $B6, $F5, $B6, $F5, $76, $F5, $76, $F5, $56, $F5,
    $56, $F5, $77, $F5, $77, $F5, $97, $FD, $97, $FD, $B7, $FD, $D7, $FD, $F7, $FD,
    $17, $FE, $16, $FE, $16, $FE, $F5, $FD, $F5, $FD, $D4, $FD, $D3, $FD, $D2, $F5,
    $D2, $F5, $D1, $F5, $D1, $F5, $FF, $FF, $FF, $FF, $48, $F4, $48, $F4, $49, $F4,
    $29, $F4, $49, $F4, $6A, $F4, $6A, $F4, $8B, $F4, $8B, $F4, $AC, $F4, $AC, $F4,
    $CC, $F4, $EC, $F4, $0D, $F5, $0D, $F5, $2D, $F5, $4D, $F5, $4D, $F5, $6D, $FD,
    $8D, $FD, $8E, $FD, $AE, $FD, $AE, $FD, $CE, $FD, $EE, $FD, $EE, $FD, $EF, $FD,
    $0F, $FE, $EF, $FD, $EF, $FD, $F0, $FD, $10, $FE, $10, $FE, $10, $FE, $10, $F6,
    $10, $FE, $30, $FE, $30, $FE, $51, $FE, $51, $FE, $51, $FE, $51, $FE, $71, $FE,
    $71, $FE, $71, $FE, $51, $FE, $51, $FE, $D1, $E5, $B2, $94, $B2, $94, $2F, $C5,
    $8F, $DD, $10, $EE, $51, $F6, $F3, $D5, $D5, $8C, $30, $EE, $2F, $F6, $30, $F6,
    $51, $F6, $11, $DE, $35, $9D, $34, $A5, $2E, $C5, $4D, $CD, $EE, $E5, $B2, $C5,
    $F2, $6B, $91, $63, $90, $9C, $AF, $DD, $2D, $C5, $0D, $C5, $4E, $9C, $CF, $73,
    $10, $B5, $71, $CD, $B0, $D5, $B0, $D5, $91, $D5, $71, $CD, $10, $B5, $F0, $7B,
    $2E, $5B, $AC, $4A, $AC, $4A, $EE, $8B, $6F, $D5, $2F, $CD, $EE, $C4, $EF, $C4,
    $30, $CD, $93, $DD, $F4, $ED, $35, $FE, $56, $FE, $56, $FE, $36, $FE, $37, $FE,
    $37, $FE, $37, $FE, $37, $FE, $17, $FE, $17, $FE, $F7, $FD, $F7, $FD, $D7, $FD,
    $D7, $FD, $B7, $FD, $97, $F5, $77, $F5, $77, $F5, $77, $F5, $77, $FD, $97, $FD,
    $97, $FD, $B7, $FD, $D7, $FD, $F7, $FD, $F6, $FD, $F6, $FD, $F5, $FD, $F5, $FD,
    $F5, $FD, $D4, $FD, $D3, $FD, $D2, $FD, $F2, $FD, $F2, $FD, $F2, $FD, $FF, $FF,
    $FF, $FF, $A8, $F4, $88, $EC, $68, $FC, $68, $FC, $68, $FC, $89, $FC, $AA, $FC,
    $CA, $FC, $CB, $FC, $EB, $FC, $EB, $F4, $EC, $FC, $0C, $FD, $0C, $FD, $0C, $FD,
    $2D, $FD, $4D, $FD, $4D, $FD, $8D, $FD, $AE, $FD, $AE, $FD, $AE, $FD, $AE, $FD,
    $CE, $FD, $CE, $FD, $EE, $FD, $EF, $FD, $0F, $FE, $0F, $FE, $EF, $FD, $EF, $FD,
    $10, $FE, $10, $FE, $F0, $FD, $0F, $FE, $0F, $F6, $30, $FE, $30, $FE, $50, $FE,
    $51, $FE, $51, $FE, $51, $FE, $71, $FE, $71, $FE, $71, $FE, $71, $FE, $F1, $DD,
    $53, $7C, $B3, $94, $2E, $CD, $2D, $CD, $AE, $DD, $0F, $EE, $50, $FE, $70, $FE,
    $D3, $CD, $50, $FE, $50, $FE, $70, $F6, $50, $F6, $37, $95, $18, $8D, $4E, $CD,
    $0C, $C5, $2D, $CD, $CE, $E5, $50, $F6, $72, $BD, $91, $63, $70, $63, $0F, $B5,
    $2D, $CD, $0C, $C5, $AD, $AC, $EE, $E5, $4F, $F6, $90, $FE, $90, $FE, $90, $FE,
    $90, $FE, $90, $FE, $70, $FE, $70, $F6, $91, $CD, $31, $84, $0E, $53, $AD, $4A,
    $2D, $63, $0E, $C5, $2E, $CD, $CD, $BC, $EE, $C4, $30, $D5, $D1, $E5, $12, $F6,
    $54, $FE, $34, $FE, $34, $FE, $16, $FE, $16, $FE, $16, $FE, $16, $FE, $16, $FE,
    $16, $FE, $16, $FE, $16, $FE, $F6, $FD, $F6, $FD, $F6, $FD, $D6, $F5, $B6, $F5,
    $B6, $F5, $B6, $F5, $B6, $F5, $97, $FD, $B7, $FD, $B7, $FD, $D6, $FD, $F6, $FD,
    $F5, $FD, $F4, $F5, $F4, $F5, $D3, $FD, $F2, $FD, $D2, $FD, $D1, $FD, $F0, $FD,
    $F0, $FD, $0F, $FE, $0F, $FE, $FF, $FF, $FF, $FF, $C8, $F4, $A8, $F4, $68, $FC,
    $68, $FC, $89, $FC, $A9, $FC, $CA, $FC, $CA, $FC, $EB, $FC, $EB, $FC, $0C, $FD,
    $0C, $FD, $2D, $FD, $2D, $FD, $2D, $FD, $4D, $FD, $4D, $FD, $6D, $FD, $8D, $FD,
    $AE, $FD, $AE, $FD, $AE, $FD, $AE, $FD, $CE, $FD, $CE, $FD, $EE, $FD, $EF, $FD,
    $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD, $0F, $FE, $F0, $FD, $F0, $FD, $0F, $FE,
    $0F, $F6, $30, $F6, $30, $FE, $30, $FE, $50, $FE, $51, $FE, $51, $FE, $71, $FE,
    $71, $FE, $71, $FE, $71, $FE, $B3, $94, $54, $74, $2F, $C5, $0C, $C5, $0D, $C5,
    $8E, $DD, $0F, $EE, $50, $FE, $70, $FE, $F4, $CD, $70, $FE, $50, $FE, $4F, $F6,
    $D5, $BD, $38, $95, $56, $A5, $2D, $C5, $EB, $BC, $0C, $C5, $AD, $DD, $2E, $F6,
    $30, $EE, $12, $74, $90, $63, $2F, $8C, $2C, $CD, $EB, $C4, $2C, $CD, $CE, $E5,
    $2F, $F6, $70, $FE, $70, $FE, $70, $FE, $70, $FE, $70, $FE, $70, $FE, $91, $FE,
    $91, $FE, $71, $F6, $D2, $9C, $2F, $5B, $ED, $52, $0E, $5B, $2F, $C5, $EE, $C4,
    $AD, $BC, $EE, $C4, $91, $DD, $F2, $ED, $14, $FE, $34, $FE, $34, $FE, $F6, $FD,
    $F6, $FD, $F6, $FD, $16, $FE, $16, $FE, $16, $FE, $16, $FE, $16, $FE, $F6, $FD,
    $F6, $FD, $F6, $FD, $F6, $FD, $D6, $FD, $D6, $FD, $D6, $FD, $D6, $FD, $B7, $FD,
    $B7, $FD, $D7, $FD, $D6, $FD, $F6, $FD, $D5, $F5, $D4, $F5, $D4, $F5, $D3, $F5,
    $D2, $F5, $D2, $FD, $D1, $F5, $D0, $F5, $EF, $F5, $0F, $F6, $0F, $F6, $FF, $FF,
    $FF, $FF, $C7, $F4, $C7, $F4, $A8, $FC, $A8, $FC, $A9, $FC, $C9, $FC, $C9, $FC,
    $E9, $FC, $EA, $FC, $EA, $FC, $0B, $FD, $2B, $FD, $2C, $FD, $2C, $FD, $4C, $FD,
    $4D, $FD, $4D, $FD, $6D, $FD, $8D, $FD, $8D, $FD, $8D, $FD, $AE, $FD, $AD, $FD,
    $AE, $FD, $CE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EF, $FD,
    $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD, $0F, $FE, $0F, $FE, $0F, $FE, $0F, $FE,
    $2F, $FE, $30, $FE, $50, $FE, $50, $FE, $50, $FE, $50, $FE, $D2, $DD, $74, $7C,
    $54, $7C, $4D, $D5, $EC, $C4, $CB, $C4, $4D, $D5, $CE, $E5, $0F, $F6, $4F, $FE,
    $31, $EE, $4F, $FE, $4F, $FE, $6F, $FE, $F9, $B5, $59, $95, $96, $AD, $4C, $D5,
    $EB, $C4, $EC, $C4, $4D, $D5, $CE, $ED, $2F, $F6, $D3, $94, $90, $63, $70, $5B,
    $2C, $CD, $EC, $C4, $2C, $CD, $CD, $DD, $2E, $F6, $6F, $FE, $6F, $FE, $6F, $FE,
    $6F, $FE, $6F, $FE, $6F, $FE, $90, $FE, $90, $FE, $90, $FE, $70, $F6, $F3, $9C,
    $0E, $5B, $0E, $53, $CE, $7B, $4D, $CD, $CD, $BC, $ED, $C4, $4F, $D5, $F1, $ED,
    $32, $FE, $52, $FE, $52, $FE, $13, $F6, $33, $FE, $14, $FE, $14, $FE, $14, $FE,
    $14, $FE, $15, $FE, $15, $FE, $F5, $FD, $F5, $FD, $F5, $FD, $F5, $FD, $F5, $FD,
    $F5, $FD, $F5, $FD, $F5, $FD, $D5, $FD, $D5, $FD, $F5, $FD, $F4, $F5, $F4, $F5,
    $F3, $F5, $D2, $F5, $D2, $F5, $F2, $FD, $D2, $FD, $D1, $FD, $D0, $FD, $D0, $FD,
    $EF, $FD, $EE, $FD, $EF, $FD, $FF, $FF, $FF, $FF, $E8, $FC, $C7, $F4, $A8, $FC,
    $A8, $FC, $A9, $FC, $C9, $FC, $C9, $FC, $E9, $FC, $EA, $FC, $EA, $FC, $0B, $FD,
    $0B, $FD, $2C, $FD, $2C, $FD, $2C, $FD, $4C, $FD, $4D, $FD, $6D, $FD, $8D, $FD,
    $8D, $FD, $8D, $FD, $AE, $FD, $AD, $FD, $AD, $FD, $CE, $FD, $CE, $FD, $EE, $FD,
    $EE, $F5, $EE, $F5, $EE, $FD, $EE, $FD, $EE, $FD, $EF, $FD, $EF, $FD, $EF, $FD,
    $EF, $FD, $0F, $FE, $0F, $FE, $0F, $FE, $2F, $FE, $2F, $FE, $2F, $F6, $50, $FE,
    $50, $FE, $50, $FE, $B4, $C5, $B5, $84, $54, $7C, $4D, $D5, $EC, $C4, $AB, $BC,
    $EC, $C4, $6D, $DD, $CE, $ED, $0D, $F6, $2E, $FE, $4E, $FE, $4E, $FE, $6F, $FE,
    $5B, $BE, $FB, $AD, $D9, $AD, $8D, $DD, $2C, $CD, $EC, $C4, $2C, $CD, $8D, $DD,
    $EE, $ED, $33, $AD, $90, $63, $70, $5B, $2C, $CD, $0C, $C5, $4C, $D5, $EE, $E5,
    $4F, $F6, $6F, $FE, $6F, $FE, $6F, $FE, $6F, $FE, $6F, $FE, $6F, $FE, $6F, $FE,
    $6F, $FE, $6F, $FE, $90, $FE, $31, $EE, $53, $84, $2F, $5B, $2E, $5B, $EE, $BC,
    $ED, $C4, $ED, $C4, $2F, $D5, $D1, $ED, $32, $F6, $52, $FE, $32, $F6, $33, $FE,
    $33, $FE, $14, $FE, $14, $FE, $14, $FE, $14, $FE, $14, $FE, $14, $FE, $F5, $FD,
    $F5, $FD, $F5, $FD, $F5, $FD, $F5, $FD, $F5, $FD, $D4, $FD, $D4, $FD, $D5, $FD,
    $D5, $FD, $D5, $FD, $F4, $F5, $D3, $F5, $D3, $F5, $D2, $F5, $D2, $F5, $D2, $F5,
    $D1, $FD, $D1, $FD, $D0, $FD, $CF, $FD, $CF, $FD, $EE, $FD, $EE, $FD, $FF, $FF,
    $FF, $FF, $E7, $FC, $C7, $F4, $C9, $F4, $C8, $EC, $C9, $F4, $E9, $F4, $E9, $F4,
    $E9, $F4, $E9, $FC, $0A, $FD, $0A, $FD, $0A, $FD, $2B, $FD, $2B, $FD, $4C, $F5,
    $6C, $F5, $8D, $F5, $8D, $F5, $8D, $FD, $8D, $FD, $8D, $FD, $8D, $FD, $AD, $FD,
    $AD, $FD, $AD, $FD, $CD, $FD, $CD, $FD, $ED, $F5, $ED, $F5, $ED, $F5, $EE, $FD,
    $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $0F, $FE,
    $0F, $FE, $0F, $FE, $2F, $FE, $2F, $FE, $2F, $FE, $4F, $FE, $D6, $BD, $36, $95,
    $54, $7C, $30, $B5, $2C, $CD, $CB, $BC, $CB, $BC, $0B, $CD, $6C, $DD, $AD, $E5,
    $ED, $ED, $0D, $F6, $2E, $F6, $2E, $FE, $BA, $D6, $9C, $BE, $7C, $B6, $CF, $DD,
    $6C, $DD, $2B, $CD, $2B, $CD, $6C, $DD, $AD, $E5, $33, $AD, $90, $63, $6F, $63,
    $2C, $CD, $0C, $CD, $6D, $D5, $EE, $ED, $4F, $FE, $6F, $FE, $6F, $FE, $6F, $FE,
    $6F, $FE, $6E, $F6, $6E, $F6, $4F, $FE, $4F, $FE, $6F, $FE, $6F, $FE, $6F, $FE,
    $93, $C5, $B0, $6B, $4F, $5B, $8E, $9C, $0D, $C5, $EC, $C4, $4E, $CD, $F0, $E5,
    $31, $EE, $71, $F6, $51, $F6, $51, $F6, $51, $F6, $51, $F6, $32, $F6, $32, $F6,
    $12, $FE, $F3, $FD, $F3, $FD, $F3, $FD, $F3, $FD, $F3, $FD, $F3, $FD, $F3, $FD,
    $F3, $FD, $D3, $FD, $F3, $FD, $D3, $FD, $D2, $FD, $F2, $FD, $F2, $FD, $F2, $F5,
    $F1, $F5, $F1, $F5, $D1, $FD, $B1, $FD, $B1, $FD, $B1, $FD, $B0, $FD, $B0, $FD,
    $B0, $FD, $B0, $FD, $B0, $FD, $FF, $FF, $FF, $FF, $E7, $F4, $C7, $F4, $C9, $F4,
    $C9, $F4, $E9, $F4, $09, $F5, $09, $F5, $09, $F5, $0A, $FD, $0A, $FD, $0A, $FD,
    $0A, $FD, $2B, $FD, $2B, $FD, $4C, $F5, $6C, $F5, $8D, $F5, $8D, $F5, $8D, $FD,
    $8D, $FD, $8D, $FD, $8D, $FD, $AD, $FD, $AD, $FD, $AD, $FD, $AD, $FD, $CD, $FD,
    $CD, $F5, $ED, $F5, $ED, $F5, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD,
    $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $0F, $FE, $0F, $FE, $2F, $F6, $2F, $FE,
    $2F, $FE, $2F, $FE, $14, $D6, $98, $A5, $B5, $84, $B4, $8C, $4E, $D5, $0B, $CD,
    $EB, $C4, $CB, $C4, $0B, $CD, $2C, $D5, $4C, $DD, $8C, $E5, $CD, $ED, $0D, $F6,
    $94, $EE, $1D, $D7, $1A, $B6, $55, $A5, $CE, $E5, $8C, $E5, $6C, $DD, $8C, $DD,
    $AD, $E5, $D2, $9C, $70, $63, $0E, $84, $2C, $CD, $2C, $CD, $8D, $DD, $2E, $F6,
    $4F, $FE, $6F, $FE, $6F, $FE, $6F, $FE, $6E, $F6, $6E, $F6, $6E, $F6, $4F, $FE,
    $4F, $FE, $4F, $FE, $6F, $FE, $6F, $FE, $11, $DE, $53, $7C, $70, $5B, $EF, $83,
    $0D, $C5, $EC, $C4, $4E, $D5, $F0, $E5, $51, $EE, $71, $F6, $51, $F6, $51, $F6,
    $51, $F6, $51, $F6, $32, $F6, $12, $F6, $12, $F6, $F3, $FD, $F3, $FD, $F3, $FD,
    $F3, $FD, $F3, $FD, $F3, $FD, $F3, $FD, $F3, $FD, $D3, $FD, $F3, $FD, $D3, $FD,
    $D2, $FD, $F2, $FD, $F2, $FD, $F2, $F5, $F1, $F5, $F1, $FD, $F1, $FD, $D1, $FD,
    $D1, $FD, $B1, $FD, $B1, $FD, $B0, $FD, $B0, $FD, $B0, $FD, $B0, $FD, $FF, $FF,
    $FF, $FF, $07, $F5, $E6, $F4, $E7, $F4, $E7, $F4, $E8, $F4, $08, $F5, $09, $F5,
    $09, $FD, $09, $F5, $0A, $F5, $0A, $FD, $2A, $F5, $2B, $FD, $4B, $FD, $4B, $FD,
    $6C, $F5, $6C, $FD, $6C, $FD, $6C, $FD, $6D, $FD, $6D, $FD, $8D, $FD, $8D, $FD,
    $AD, $FD, $AD, $FD, $AD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD,
    $CD, $FD, $ED, $FD, $ED, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD,
    $EE, $FD, $EF, $FD, $0F, $FE, $EE, $FD, $0F, $FE, $0F, $FE, $10, $F6, $F8, $B5,
    $57, $9D, $75, $7C, $D4, $94, $4E, $CD, $2C, $D5, $EB, $CC, $EB, $C4, $EB, $CC,
    $EB, $CC, $2B, $D5, $6C, $DD, $CC, $ED, $0D, $F6, $B4, $EE, $98, $AD, $95, $84,
    $F4, $94, $90, $CD, $EC, $ED, $EC, $ED, $CD, $E5, $32, $74, $70, $5B, $4D, $9C,
    $0A, $CD, $4B, $D5, $CC, $E5, $2D, $F6, $2D, $FE, $4E, $FE, $4E, $FE, $4E, $FE,
    $6E, $FE, $6F, $FE, $6F, $FE, $4E, $FE, $4E, $FE, $4F, $FE, $4F, $FE, $4F, $FE,
    $2F, $F6, $94, $8C, $70, $63, $0F, $84, $0C, $CD, $ED, $C4, $4E, $D5, $EF, $ED,
    $30, $FE, $50, $FE, $50, $FE, $51, $FE, $51, $FE, $31, $F6, $31, $F6, $31, $F6,
    $31, $F6, $31, $F6, $31, $F6, $11, $F6, $11, $F6, $11, $FE, $11, $FE, $11, $FE,
    $11, $FE, $F1, $FD, $F1, $FD, $10, $F6, $10, $F6, $10, $F6, $11, $F6, $11, $F6,
    $11, $F6, $F0, $FD, $F0, $F5, $D0, $F5, $F0, $FD, $D0, $FD, $D0, $FD, $CF, $FD,
    $AF, $FD, $AF, $FD, $AF, $FD, $FF, $FF, $FF, $FF, $07, $F5, $E6, $F4, $E7, $F4,
    $E7, $F4, $E8, $F4, $E8, $F4, $09, $F5, $09, $FD, $09, $FD, $0A, $FD, $0A, $FD,
    $2A, $F5, $2B, $FD, $4B, $F5, $4B, $F5, $4B, $F5, $6C, $F5, $6C, $FD, $6C, $FD,
    $6C, $FD, $6D, $FD, $8D, $FD, $8D, $FD, $AD, $FD, $AD, $FD, $AD, $FD, $CD, $FD,
    $CD, $FD, $CD, $FD, $CD, $FD, $CD, $F5, $CD, $FD, $ED, $FD, $ED, $FD, $ED, $FD,
    $ED, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD,
    $EE, $FD, $EE, $FD, $0F, $FE, $10, $EE, $D8, $B5, $57, $9D, $95, $84, $B6, $84,
    $32, $AD, $50, $C5, $4C, $D5, $2C, $D5, $0B, $CD, $0B, $CD, $4B, $D5, $AC, $ED,
    $0D, $F6, $2D, $FE, $2E, $EE, $91, $C5, $32, $AD, $33, $A5, $52, $AD, $0D, $EE,
    $8F, $CD, $B1, $6B, $4F, $5B, $0B, $C5, $4B, $D5, $8C, $DD, $EC, $F5, $2D, $FE,
    $2D, $FE, $2D, $F6, $0E, $F6, $2E, $F6, $2E, $FE, $4E, $FE, $4E, $FE, $4E, $FE,
    $4E, $FE, $4E, $FE, $4E, $FE, $4F, $FE, $4F, $FE, $B4, $8C, $91, $63, $4F, $94,
    $0C, $CD, $2D, $CD, $8E, $DD, $EF, $F5, $30, $FE, $50, $FE, $50, $FE, $51, $FE,
    $51, $FE, $51, $FE, $31, $F6, $31, $F6, $31, $F6, $31, $F6, $31, $F6, $11, $F6,
    $11, $F6, $11, $FE, $11, $FE, $11, $FE, $F1, $FD, $F1, $FD, $F1, $FD, $10, $F6,
    $10, $F6, $10, $F6, $11, $F6, $11, $F6, $10, $F6, $F0, $FD, $F0, $F5, $D0, $F5,
    $D0, $F5, $D0, $FD, $CF, $FD, $AF, $FD, $AF, $FD, $8F, $FD, $8F, $FD, $FF, $FF,
    $FF, $FF, $05, $F5, $E5, $F4, $E7, $F4, $07, $F5, $E7, $F4, $07, $F5, $08, $F5,
    $09, $FD, $29, $FD, $29, $FD, $2A, $FD, $2A, $F5, $2A, $F5, $2A, $F5, $2B, $F5,
    $4B, $F5, $4B, $F5, $6B, $F5, $6C, $FD, $6C, $FD, $6C, $FD, $8C, $FD, $8C, $FD,
    $AC, $FD, $AD, $FD, $AD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD,
    $CD, $FD, $CD, $FD, $ED, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CE, $FD,
    $CE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $0E, $FE,
    $EF, $F5, $B4, $C5, $57, $9D, $D6, $84, $D6, $84, $F7, $8C, $18, $8D, $56, $A5,
    $6B, $DD, $4A, $DD, $4A, $DD, $8B, $ED, $EC, $F5, $2C, $FE, $2C, $FE, $2C, $FE,
    $2C, $FE, $2C, $FE, $2C, $FE, $2C, $FE, $D0, $A4, $4F, $5B, $0D, $8C, $4A, $D5,
    $6A, $DD, $CB, $ED, $2C, $F6, $4C, $FE, $2C, $FE, $0C, $F6, $EB, $ED, $0D, $F6,
    $2D, $F6, $4D, $FE, $4D, $FE, $4E, $FE, $4E, $FE, $4E, $FE, $4E, $FE, $4E, $FE,
    $2E, $FE, $94, $84, $B1, $6B, $8F, $A4, $2C, $CD, $4D, $D5, $AE, $E5, $0F, $EE,
    $4F, $FE, $4F, $FE, $4F, $FE, $4F, $FE, $4F, $FE, $50, $FE, $50, $FE, $30, $FE,
    $30, $FE, $30, $FE, $30, $FE, $10, $FE, $10, $FE, $11, $FE, $11, $FE, $11, $FE,
    $11, $FE, $11, $FE, $11, $FE, $F0, $FD, $F0, $FD, $F0, $FD, $F0, $FD, $F0, $FD,
    $F0, $FD, $F0, $FD, $F0, $FD, $CF, $FD, $AF, $FD, $AF, $FD, $AF, $FD, $8E, $FD,
    $8E, $FD, $8E, $FD, $8E, $FD, $FF, $FF, $FF, $FF, $05, $F5, $E5, $F4, $E7, $F4,
    $E7, $F4, $E7, $F4, $07, $F5, $08, $FD, $29, $FD, $29, $FD, $2A, $FD, $2A, $FD,
    $2A, $FD, $2A, $F5, $2A, $F5, $2B, $F5, $4B, $F5, $4B, $F5, $4B, $F5, $6C, $FD,
    $6C, $FD, $6C, $FD, $8C, $FD, $8C, $FD, $AC, $FD, $AC, $FD, $AD, $FD, $AD, $FD,
    $AD, $FD, $CD, $F5, $CD, $F5, $CD, $F5, $CD, $F5, $CD, $FD, $CD, $FD, $CD, $FD,
    $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $EE, $FD,
    $EE, $FD, $EE, $FD, $EE, $FD, $ED, $FD, $CD, $FD, $AD, $F5, $8E, $E5, $71, $BD,
    $13, $A5, $F6, $8C, $17, $8D, $38, $95, $6C, $E5, $4B, $DD, $4B, $DD, $AB, $E5,
    $EC, $ED, $0C, $F6, $0C, $F6, $2C, $FE, $2C, $FE, $2C, $FE, $0C, $FE, $CD, $E5,
    $D1, $6B, $6F, $63, $2B, $CD, $6A, $DD, $CB, $E5, $0C, $F6, $0C, $FE, $6D, $D5,
    $0C, $F6, $EB, $E5, $AB, $DD, $CB, $E5, $EB, $ED, $2D, $F6, $4D, $FE, $4E, $FE,
    $4E, $FE, $4E, $FE, $4E, $FE, $2E, $FE, $90, $CD, $53, $7C, $D2, $6B, $0D, $BD,
    $4D, $CD, $8D, $DD, $EE, $ED, $0F, $F6, $4F, $F6, $4F, $FE, $4F, $FE, $2F, $FE,
    $2F, $FE, $2F, $FE, $2F, $FE, $30, $FE, $30, $FE, $30, $F6, $30, $F6, $31, $FE,
    $10, $FE, $11, $FE, $11, $FE, $11, $FE, $11, $FE, $11, $FE, $11, $FE, $F0, $FD,
    $F0, $FD, $F0, $FD, $F0, $FD, $F0, $FD, $F0, $FD, $D0, $FD, $D0, $FD, $CF, $FD,
    $AF, $FD, $AF, $FD, $8F, $FD, $6E, $FD, $6E, $FD, $6E, $FD, $8E, $FD, $FF, $FF,
    $FF, $FF, $04, $F5, $04, $F5, $E5, $F4, $E6, $F4, $06, $F5, $07, $FD, $27, $FD,
    $28, $FD, $28, $FD, $29, $FD, $29, $FD, $29, $FD, $2A, $FD, $2A, $F5, $2A, $F5,
    $4A, $F5, $4B, $F5, $4B, $F5, $6B, $FD, $6B, $FD, $6B, $FD, $6B, $FD, $8C, $FD,
    $8C, $FD, $AC, $FD, $AC, $FD, $AC, $FD, $AC, $FD, $AC, $F5, $AC, $F5, $AC, $F5,
    $AC, $F5, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD,
    $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $EC, $FD, $CD, $ED,
    $CC, $F5, $8B, $ED, $4B, $E5, $4A, $DD, $2A, $DD, $4A, $E5, $4B, $DD, $35, $9D,
    $29, $DD, $29, $DD, $4A, $DD, $A9, $ED, $EA, $F5, $0A, $FE, $0A, $FE, $2A, $FE,
    $2A, $FE, $2A, $FE, $0A, $F6, $90, $94, $70, $63, $8B, $A4, $69, $DD, $A9, $E5,
    $EA, $F5, $0A, $FE, $2A, $FE, $CD, $B4, $EA, $F5, $A9, $E5, $49, $DD, $49, $DD,
    $8A, $E5, $CA, $ED, $0A, $F6, $ED, $ED, $0D, $EE, $0D, $F6, $0D, $F6, $EC, $F5,
    $12, $A5, $33, $74, $8F, $9C, $4C, $DD, $8D, $E5, $CD, $ED, $0E, $FE, $2E, $FE,
    $2E, $FE, $4E, $FE, $4E, $FE, $2E, $FE, $2E, $FE, $2E, $FE, $2E, $FE, $2F, $FE,
    $0E, $FE, $0F, $FE, $0F, $FE, $10, $FE, $0F, $FE, $10, $FE, $10, $FE, $10, $FE,
    $10, $FE, $10, $FE, $10, $FE, $F0, $FD, $F0, $FD, $F0, $FD, $F0, $FD, $F0, $FD,
    $CF, $FD, $CF, $FD, $CF, $FD, $CF, $FD, $CE, $FD, $AE, $FD, $8D, $FD, $6D, $FD,
    $6D, $FD, $6D, $FD, $8D, $FD, $FF, $FF, $FF, $FF, $05, $F5, $04, $F5, $E5, $F4,
    $E6, $F4, $06, $F5, $07, $FD, $27, $FD, $28, $FD, $28, $FD, $29, $FD, $29, $FD,
    $29, $FD, $2A, $FD, $4A, $F5, $4A, $F5, $4B, $F5, $4B, $F5, $4B, $F5, $6B, $FD,
    $6B, $FD, $6B, $FD, $6B, $FD, $6C, $FD, $8C, $FD, $AC, $FD, $AC, $F5, $AC, $F5,
    $AC, $F5, $AC, $F5, $AC, $F5, $AC, $F5, $AC, $F5, $AC, $F5, $AD, $FD, $CD, $FD,
    $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $FD, $CD, $F5, $CD, $F5, $CD, $FD,
    $CC, $FD, $CC, $FD, $CC, $FD, $71, $CD, $AC, $F5, $4B, $ED, $0A, $DD, $C9, $D4,
    $C9, $CC, $C9, $CC, $ED, $BC, $14, $9D, $C9, $CC, $E8, $D4, $29, $DD, $89, $ED,
    $CA, $F5, $0A, $FE, $0A, $FE, $0A, $FE, $0A, $FE, $EA, $F5, $2D, $C5, $D1, $6B,
    $4C, $9C, $69, $DD, $A9, $E5, $E9, $F5, $0A, $FE, $2A, $F6, $2A, $F6, $8E, $9C,
    $E9, $F5, $89, $E5, $28, $D5, $28, $D5, $49, $DD, $8A, $E5, $AA, $E5, $CB, $E5,
    $CB, $E5, $CC, $E5, $CC, $E5, $50, $BD, $94, $84, $51, $84, $4C, $D5, $AD, $E5,
    $ED, $ED, $0E, $EE, $2E, $FE, $2E, $F6, $2E, $F6, $2E, $F6, $2E, $F6, $2E, $FE,
    $2E, $FE, $2E, $FE, $0E, $FE, $0E, $FE, $0E, $FE, $0F, $FE, $0F, $FE, $0F, $FE,
    $0F, $FE, $EF, $FD, $EF, $FD, $F0, $FD, $F0, $FD, $F0, $FD, $F0, $FD, $F0, $FD,
    $D0, $FD, $D0, $FD, $D0, $FD, $CF, $FD, $CF, $FD, $CF, $FD, $CF, $FD, $AF, $FD,
    $AE, $FD, $8E, $FD, $8D, $FD, $6D, $FD, $6D, $FD, $8D, $FD, $8D, $FD, $FF, $FF,
    $FF, $FF, $04, $F5, $04, $F5, $05, $F5, $05, $F5, $05, $F5, $26, $FD, $26, $FD,
    $27, $FD, $47, $FD, $28, $FD, $28, $FD, $48, $F5, $49, $FD, $49, $FD, $49, $F5,
    $49, $F5, $4A, $FD, $4A, $FD, $4B, $FD, $4B, $FD, $6B, $FD, $6B, $FD, $6B, $FD,
    $8B, $FD, $8C, $FD, $AC, $FD, $8C, $FD, $8C, $FD, $AC, $F5, $AC, $F5, $AC, $F5,
    $AC, $F5, $AC, $F5, $AC, $FD, $AC, $F5, $AC, $F5, $AC, $F5, $CC, $FD, $CC, $FD,
    $CC, $FD, $AC, $FD, $AB, $FD, $AB, $FD, $CB, $FD, $AB, $FD, $AB, $FD, $32, $B5,
    $AB, $F5, $4A, $ED, $E9, $DC, $C8, $CC, $A7, $CC, $C7, $CC, $CD, $B4, $F2, $A4,
    $C7, $D4, $E8, $D4, $28, $E5, $A9, $F5, $C8, $FD, $E9, $FD, $E9, $FD, $E9, $FD,
    $E9, $FD, $8B, $DD, $F0, $7B, $4C, $94, $67, $E5, $87, $ED, $C8, $F5, $E9, $FD,
    $09, $FE, $08, $FE, $08, $FE, $B1, $6B, $CC, $B4, $88, $E5, $28, $DD, $28, $D5,
    $48, $DD, $68, $DD, $88, $E5, $6A, $DD, $8A, $E5, $8A, $ED, $4E, $CD, $B4, $8C,
    $B2, $94, $8C, $E5, $CC, $ED, $CD, $F5, $ED, $FD, $0D, $FE, $0D, $FE, $0E, $FE,
    $0E, $FE, $0E, $FE, $0E, $FE, $0E, $FE, $EE, $FD, $0E, $FE, $EE, $FD, $EE, $FD,
    $0F, $FE, $0F, $FE, $0F, $FE, $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD,
    $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD,
    $EE, $FD, $EE, $F5, $EE, $F5, $CE, $F5, $CD, $F5, $CD, $F5, $CC, $F5, $AC, $F5,
    $AC, $F5, $CC, $F5, $CC, $FD, $FF, $FF, $FF, $FF, $04, $F5, $04, $F5, $05, $F5,
    $05, $F5, $05, $F5, $25, $F5, $26, $F5, $27, $FD, $27, $FD, $28, $FD, $28, $FD,
    $48, $F5, $49, $FD, $49, $FD, $49, $F5, $49, $F5, $4A, $FD, $4A, $FD, $4B, $FD,
    $4B, $FD, $6B, $FD, $6B, $FD, $6B, $FD, $6B, $FD, $8C, $FD, $AC, $FD, $8C, $F5,
    $8C, $FD, $AC, $F5, $AC, $F5, $AC, $F5, $AC, $F5, $AC, $F5, $AC, $F5, $AC, $F5,
    $AC, $F5, $AC, $F5, $AC, $F5, $AC, $FD, $AC, $FD, $AC, $F5, $AB, $F5, $AB, $F5,
    $AB, $F5, $AB, $FD, $AB, $FD, $33, $B5, $D5, $8C, $B5, $84, $B5, $84, $95, $7C,
    $95, $7C, $B6, $84, $D7, $84, $0F, $B5, $28, $E5, $48, $E5, $69, $ED, $A8, $ED,
    $C8, $FD, $C8, $FD, $C8, $FD, $E8, $FD, $A9, $ED, $F0, $7B, $4C, $9C, $87, $ED,
    $A8, $ED, $C8, $F5, $E8, $FD, $08, $FE, $08, $FE, $08, $FE, $AB, $DD, $33, $7C,
    $B1, $63, $2F, $8C, $EB, $BC, $88, $E5, $88, $E5, $88, $ED, $88, $ED, $AA, $E5,
    $4D, $CD, $10, $AD, $B4, $8C, $30, $BD, $CC, $ED, $CC, $ED, $EC, $ED, $ED, $FD,
    $0D, $FE, $ED, $F5, $ED, $F5, $ED, $F5, $EE, $FD, $0E, $FE, $0E, $FE, $EE, $FD,
    $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EE, $FD, $EF, $FD, $0F, $FE, $EF, $FD,
    $EF, $FD, $EF, $FD, $0F, $FE, $0F, $FE, $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD,
    $EF, $FD, $EF, $FD, $EF, $FD, $EF, $FD, $EE, $FD, $EE, $F5, $EE, $F5, $CE, $F5,
    $ED, $F5, $CD, $F5, $CD, $F5, $CD, $FD, $CD, $FD, $ED, $FD, $ED, $FD, $FF, $FF,
    $FF, $FF, $24, $FD, $03, $F5, $04, $F5, $04, $F5, $05, $F5, $05, $FD, $25, $FD,
    $26, $FD, $46, $FD, $47, $FD, $47, $FD, $48, $FD, $48, $FD, $48, $FD, $49, $FD,
    $49, $FD, $49, $FD, $49, $FD, $6A, $FD, $6A, $FD, $4A, $FD, $6A, $FD, $6B, $FD,
    $6B, $FD, $8B, $FD, $8B, $FD, $8C, $FD, $8C, $FD, $AB, $FD, $AB, $FD, $AB, $FD,
    $AB, $FD, $AB, $FD, $AB, $FD, $AB, $FD, $AA, $FD, $AB, $FD, $AB, $FD, $AB, $FD,
    $AA, $FD, $AA, $FD, $AA, $FD, $AA, $FD, $AA, $FD, $A9, $FD, $A9, $FD, $75, $AD,
    $37, $9D, $16, $95, $16, $95, $D6, $8C, $B6, $84, $D6, $84, $D6, $84, $2E, $BD,
    $68, $F5, $A8, $F5, $A8, $F5, $C8, $FD, $C8, $FD, $C7, $FD, $C7, $FD, $A8, $F5,
    $4F, $8C, $8C, $AC, $87, $F5, $87, $F5, $C7, $F5, $C7, $FD, $E7, $FD, $E8, $FD,
    $E8, $FD, $E8, $FD, $AC, $E5, $10, $AD, $CE, $AC, $6F, $94, $10, $7C, $D2, $6B,
    $50, $84, $6F, $94, $8F, $9C, $D0, $A4, $0F, $AD, $6D, $CD, $EA, $F5, $EA, $F5,
    $CA, $FD, $EB, $FD, $EB, $FD, $EB, $FD, $EC, $FD, $EC, $FD, $ED, $FD, $ED, $FD,
    $EE, $FD, $ED, $FD, $EE, $FD, $CE, $FD, $CE, $FD, $CE, $FD, $CE, $FD, $CE, $FD,
    $EE, $FD, $EE, $FD, $0F, $FE, $0E, $FE, $0E, $FE, $0E, $FE, $0E, $FE, $0E, $FE,
    $0E, $FE, $2E, $FE, $2E, $FE, $2E, $F6, $2E, $F6, $2E, $F6, $2E, $F6, $2E, $F6,
    $2D, $F6, $2D, $F6, $2D, $F6, $4D, $F6, $4D, $F6, $4D, $F6, $4C, $F6, $4C, $F6,
    $4C, $F6, $4C, $F6, $4C, $F6, $FF, $FF, $FF, $FF, $24, $FD, $03, $F5, $04, $F5,
    $04, $F5, $05, $F5, $05, $FD, $25, $FD, $26, $FD, $46, $FD, $47, $FD, $47, $FD,
    $48, $FD, $48, $FD, $48, $FD, $49, $FD, $49, $FD, $49, $FD, $49, $FD, $4A, $FD,
    $4A, $FD, $4A, $FD, $4A, $FD, $6B, $FD, $6B, $FD, $8B, $FD, $8B, $F5, $8B, $FD,
    $8B, $FD, $8B, $FD, $8B, $FD, $8B, $FD, $AB, $FD, $AB, $FD, $AB, $FD, $AB, $F5,
    $AA, $F5, $AA, $F5, $AA, $F5, $AA, $F5, $AA, $F5, $AA, $FD, $A9, $FD, $A9, $FD,
    $A9, $FD, $A9, $FD, $A9, $FD, $92, $C5, $8D, $E5, $89, $FD, $88, $F5, $68, $FD,
    $88, $FD, $88, $FD, $88, $FD, $A8, $FD, $A8, $FD, $A7, $FD, $A8, $FD, $C8, $FD,
    $C8, $FD, $C7, $FD, $69, $E5, $4F, $94, $2A, $CD, $A7, $FD, $A7, $FD, $A7, $F5,
    $C7, $F5, $C7, $FD, $C7, $FD, $C8, $FD, $C8, $FD, $C8, $FD, $6D, $D5, $8B, $DD,
    $E8, $FD, $C8, $FD, $C8, $FD, $E8, $FD, $E8, $FD, $E8, $FD, $E8, $FD, $E9, $FD,
    $E9, $FD, $E9, $FD, $E9, $FD, $EA, $FD, $EA, $FD, $EA, $FD, $EB, $FD, $CB, $FD,
    $CB, $FD, $CC, $FD, $CC, $FD, $CC, $FD, $CD, $FD, $CD, $FD, $AD, $FD, $CE, $FD,
    $CE, $FD, $CE, $FD, $CE, $FD, $CE, $FD, $EE, $FD, $EE, $FD, $EE, $F5, $0E, $FE,
    $0F, $FE, $0E, $FE, $0E, $FE, $0E, $FE, $0E, $FE, $0E, $FE, $2E, $FE, $2E, $F6,
    $2E, $F6, $4E, $F6, $4E, $F6, $6F, $FE, $8E, $FE, $8F, $FE, $8E, $FE, $8E, $FE,
    $AE, $FE, $AE, $FE, $AD, $FE, $8D, $FE, $8D, $FE, $8D, $FE, $8D, $FE, $FF, $FF,
    $FF, $FF, $04, $FD, $04, $F5, $04, $FD, $04, $FD, $04, $F5, $04, $FD, $25, $FD,
    $25, $FD, $45, $FD, $46, $FD, $46, $FD, $47, $FD, $47, $FD, $47, $FD, $48, $FD,
    $48, $FD, $48, $FD, $49, $FD, $49, $FD, $49, $FD, $49, $FD, $49, $FD, $6A, $FD,
    $6A, $F5, $8A, $FD, $8A, $FD, $8A, $FD, $8A, $FD, $8A, $FD, $89, $FD, $89, $FD,
    $AA, $FD, $AA, $FD, $A9, $FD, $A9, $FD, $A9, $FD, $A9, $FD, $A9, $FD, $A8, $FD,
    $A8, $FD, $A8, $FD, $A8, $FD, $88, $FD, $88, $FD, $88, $FD, $6B, $ED, $6B, $E5,
    $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD,
    $87, $FD, $87, $FD, $87, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD,
    $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $C8, $FD, $A8, $FD,
    $A8, $FD, $C8, $FD, $8B, $DD, $C8, $FD, $C8, $FD, $C8, $FD, $C8, $FD, $C8, $FD,
    $C8, $FD, $C8, $FD, $C8, $FD, $C7, $FD, $C7, $FD, $C8, $FD, $C8, $FD, $C8, $FD,
    $C8, $FD, $C9, $FD, $C9, $FD, $C9, $FD, $CA, $FD, $CA, $FD, $CA, $FD, $CB, $FD,
    $CB, $FD, $AB, $F5, $AB, $F5, $AC, $FD, $CC, $F5, $CC, $FD, $ED, $F5, $ED, $F5,
    $ED, $F5, $ED, $F5, $0D, $F6, $0D, $F6, $2D, $F6, $2D, $F6, $4D, $F6, $4D, $F6,
    $6D, $F6, $6E, $FE, $6E, $FE, $AE, $FE, $CE, $FE, $CE, $FE, $CE, $FE, $EE, $FE,
    $0E, $FF, $0E, $FF, $0E, $FF, $0D, $FF, $0D, $FF, $0D, $FF, $0C, $FF, $EC, $FE,
    $EC, $FE, $CC, $FE, $CC, $FE, $FF, $FF, $FF, $FF, $04, $FD, $04, $F5, $04, $F5,
    $04, $FD, $04, $FD, $04, $FD, $25, $FD, $25, $FD, $45, $FD, $26, $FD, $46, $FD,
    $47, $FD, $47, $FD, $47, $FD, $48, $FD, $48, $FD, $48, $FD, $48, $FD, $49, $FD,
    $49, $FD, $49, $FD, $49, $FD, $6A, $FD, $6A, $F5, $8A, $FD, $8A, $FD, $8A, $FD,
    $8A, $FD, $8A, $F5, $89, $F5, $89, $FD, $89, $FD, $89, $FD, $A9, $FD, $A9, $FD,
    $A9, $FD, $A8, $FD, $A8, $FD, $88, $F5, $A8, $FD, $A8, $FD, $A8, $FD, $87, $F5,
    $87, $F5, $87, $F5, $87, $F5, $87, $FD, $87, $FD, $87, $F5, $87, $F5, $87, $FD,
    $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $A7, $FD,
    $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD,
    $A7, $FD, $A7, $FD, $C8, $FD, $A8, $FD, $A8, $FD, $C8, $FD, $C8, $FD, $C8, $FD,
    $C8, $FD, $C8, $FD, $C8, $FD, $A7, $F5, $A7, $F5, $A7, $F5, $C8, $FD, $A7, $FD,
    $A7, $FD, $A7, $FD, $A7, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A9, $FD, $A9, $FD,
    $A9, $FD, $AA, $FD, $AA, $FD, $AA, $FD, $AA, $F5, $AA, $F5, $AA, $F5, $8B, $F5,
    $AC, $F5, $AC, $F5, $CC, $F5, $CC, $F5, $ED, $F5, $0D, $F6, $2D, $F6, $2D, $F6,
    $4E, $F6, $6E, $FE, $6E, $FE, $8E, $FE, $AF, $FE, $AF, $FE, $CF, $FE, $EF, $FE,
    $0F, $FF, $0F, $FF, $0F, $FF, $0F, $FF, $0E, $FF, $0E, $FF, $0E, $FF, $0D, $FF,
    $0D, $FF, $0D, $FF, $EC, $FE, $EC, $FE, $EC, $FE, $EC, $FE, $EC, $FE, $FF, $FF,
    $FF, $FF, $05, $FD, $04, $F5, $04, $F5, $04, $F5, $04, $F5, $04, $FD, $25, $FD,
    $25, $FD, $25, $FD, $45, $FD, $46, $FD, $46, $FD, $46, $FD, $46, $FD, $47, $FD,
    $47, $FD, $47, $FD, $47, $FD, $48, $FD, $48, $F5, $68, $FD, $68, $FD, $68, $FD,
    $68, $FD, $89, $FD, $89, $FD, $89, $FD, $88, $FD, $88, $F5, $88, $F5, $88, $F5,
    $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $87, $FD, $86, $FD,
    $86, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $86, $FD, $86, $FD, $87, $FD,
    $87, $FD, $87, $FD, $86, $F5, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD,
    $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD,
    $87, $FD, $87, $FD, $87, $FD, $A7, $FD, $A7, $FD, $A8, $FD, $A8, $FD, $A8, $FD,
    $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A7, $FD, $A7, $FD,
    $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD,
    $A7, $FD, $A7, $F5, $A7, $F5, $A6, $F5, $A6, $F5, $C7, $F5, $C7, $F5, $C7, $F5,
    $C7, $F5, $C7, $F5, $C7, $F5, $C8, $F5, $E8, $F5, $E9, $F5, $29, $F6, $2A, $F6,
    $6A, $FE, $6B, $FE, $8B, $FE, $AC, $FE, $CD, $FE, $CD, $FE, $ED, $FE, $ED, $FE,
    $ED, $FE, $ED, $FE, $0D, $FF, $0D, $FF, $0D, $FF, $0D, $FF, $0D, $FF, $0D, $FF,
    $0C, $FF, $0C, $FF, $0C, $FF, $0C, $FF, $0B, $FF, $0B, $FF, $0B, $FF, $0B, $FF,
    $0B, $FF, $0B, $FF, $0B, $FF, $FF, $FF, $FF, $FF, $05, $F5, $04, $F5, $04, $F5,
    $04, $F5, $04, $F5, $04, $FD, $25, $FD, $25, $FD, $25, $FD, $25, $FD, $46, $FD,
    $46, $FD, $46, $FD, $46, $FD, $47, $FD, $47, $FD, $47, $FD, $47, $FD, $48, $FD,
    $48, $F5, $48, $F5, $68, $FD, $68, $FD, $68, $FD, $68, $F5, $89, $FD, $89, $F5,
    $88, $F5, $88, $F5, $88, $F5, $88, $F5, $87, $F5, $87, $F5, $87, $F5, $87, $FD,
    $87, $FD, $86, $F5, $86, $F5, $86, $F5, $86, $F5, $86, $FD, $86, $FD, $A6, $FD,
    $A6, $FD, $A6, $FD, $A6, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $87, $FD, $87, $FD,
    $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD,
    $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $A7, $FD,
    $A7, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD,
    $A8, $FD, $A8, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $C7, $FD, $C7, $FD,
    $C7, $FD, $C7, $FD, $A7, $FD, $C7, $FD, $C7, $FD, $C7, $FD, $C7, $FD, $A6, $F5,
    $C7, $F5, $C7, $F5, $E7, $F5, $E8, $F5, $E8, $F5, $E8, $F5, $E8, $F5, $08, $FE,
    $29, $FE, $2A, $FE, $4A, $FE, $6B, $FE, $8B, $FE, $AC, $FE, $CC, $FE, $CD, $FE,
    $ED, $FE, $ED, $FE, $ED, $FE, $ED, $FE, $ED, $FE, $ED, $FE, $ED, $FE, $ED, $FE,
    $ED, $FE, $ED, $FE, $ED, $FE, $ED, $FE, $0C, $FF, $0C, $FF, $0C, $FF, $0C, $FF,
    $0B, $FF, $0B, $FF, $EB, $FE, $EA, $FE, $EA, $FE, $EA, $FE, $EA, $FE, $FF, $FF,
    $FF, $FF, $05, $F5, $E5, $F4, $E4, $F4, $E4, $F4, $05, $F5, $05, $FD, $25, $FD,
    $25, $FD, $45, $FD, $45, $FD, $45, $FD, $45, $FD, $46, $FD, $46, $FD, $46, $FD,
    $46, $FD, $46, $FD, $46, $FD, $47, $FD, $67, $FD, $47, $FD, $67, $FD, $67, $FD,
    $87, $F5, $87, $F5, $87, $F5, $87, $F5, $87, $F5, $87, $F5, $86, $F5, $86, $F5,
    $A6, $F5, $86, $F5, $A6, $FD, $86, $FD, $86, $FD, $86, $FD, $A6, $FD, $A5, $FD,
    $A5, $FD, $A5, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD,
    $A6, $FD, $A6, $FD, $A6, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD, $87, $FD,
    $87, $FD, $87, $FD, $87, $FD, $88, $FD, $88, $FD, $88, $FD, $88, $FD, $88, $FD,
    $88, $FD, $88, $FD, $88, $FD, $88, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD,
    $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $C7, $FD, $C7, $FD,
    $C7, $FD, $C7, $FD, $C7, $FD, $C8, $FD, $C7, $FD, $C7, $FD, $C7, $FD, $C7, $FD,
    $E6, $FD, $E6, $FD, $06, $FE, $06, $FE, $06, $FE, $26, $FE, $46, $FE, $46, $FE,
    $46, $FE, $46, $FE, $66, $FE, $66, $FE, $87, $FE, $87, $FE, $A7, $FE, $A8, $FE,
    $C9, $FE, $C9, $FE, $EA, $FE, $CA, $FE, $EB, $FE, $EB, $FE, $EB, $F6, $EC, $F6,
    $EC, $F6, $0C, $F7, $0C, $FF, $0C, $FF, $0C, $FF, $0C, $FF, $0C, $FF, $EC, $FE,
    $0B, $FF, $0B, $FF, $0B, $FF, $EB, $FE, $EA, $FE, $EA, $FE, $E9, $F6, $C9, $FE,
    $C9, $FE, $C9, $FE, $E9, $FE, $FF, $FF, $FF, $FF, $E5, $F4, $E5, $F4, $E4, $F4,
    $E4, $F4, $04, $F5, $05, $FD, $25, $FD, $25, $FD, $45, $FD, $45, $FD, $45, $FD,
    $45, $FD, $46, $FD, $46, $FD, $46, $FD, $46, $FD, $46, $FD, $46, $FD, $47, $FD,
    $67, $FD, $47, $FD, $67, $FD, $67, $FD, $87, $F5, $87, $F5, $87, $F5, $87, $F5,
    $87, $F5, $87, $F5, $86, $F5, $86, $F5, $A6, $F5, $86, $F5, $86, $F5, $A6, $FD,
    $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD,
    $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A6, $FD, $A7, $FD,
    $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $A7, $FD, $88, $FD,
    $A8, $FD, $A8, $FD, $A8, $FD, $88, $FD, $88, $FD, $88, $FD, $88, $FD, $A8, $FD,
    $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD, $A8, $FD,
    $C8, $FD, $C8, $FD, $C7, $FD, $C7, $FD, $C7, $FD, $C7, $FD, $C7, $FD, $C8, $FD,
    $C8, $FD, $C7, $FD, $C7, $FD, $C7, $FD, $E7, $FD, $07, $FE, $06, $FE, $26, $FE,
    $46, $FE, $66, $FE, $67, $FE, $67, $FE, $67, $FE, $67, $FE, $87, $FE, $87, $FE,
    $87, $FE, $87, $FE, $A7, $FE, $A8, $FE, $A8, $FE, $A9, $FE, $C9, $F6, $CA, $FE,
    $CA, $F6, $EB, $F6, $EB, $F6, $EB, $F6, $EB, $F6, $EC, $F6, $EC, $F6, $EC, $F6,
    $EC, $F6, $EB, $FE, $EB, $FE, $EB, $FE, $EB, $FE, $EB, $FE, $EB, $FE, $EA, $F6,
    $EA, $F6, $CA, $F6, $C9, $F6, $C9, $F6, $C9, $F6, $C9, $FE, $E9, $FE, $00, $00) ;


Var
 c : Word;
Begin

{----------16 bit mode----------}

Command16($3000, LCD_ExectimeGfx); // Addressing Mode Set

DlPortWritePortUchar(LCD_Port,26+Light);
Raw ($43, LCD_ExectimeGfx); // X
Raw (1, LCD_ExectimeGfx);
Raw (132, LCD_ExectimeGfx);

Raw ($42, LCD_ExectimeGfx); // Y
Raw (2, LCD_ExectimeGfx);
Raw (131, LCD_ExectimeGfx);

DlPortWritePortUchar(LCD_Port,27+Light); // write data

for c := SizeOf(LogoData) downto 1 do Raw (LogoData[c], LCD_ExectimeGfx);

Command ($51, LCD_ExectimeGfx); // Display ON
Sleep(2000);
Command ($50, LCD_ExectimeGfx); // Display OFF

{-----------8 bit mode-----------}

Command16($3040, LCD_ExectimeGfx); // Addressing Mode Set

End;

{-------------------------------------------------------}

Procedure LCD_Customize(SymData : TSymbolInfo);
Begin
End;

{-------------------------------------------------------}

End.

